@@ -6,7 +6,8 @@ from os.path import split, basename
 def find_path ():
     for path in sys.path:
 	(head, tail) = split (path)
-	if tail == 'site-packages':
+        # Forcing python path to be used as /usr/lib instead of /usr/local/lib
+	if tail == 'site-packages' and path.find ('local') == -1:
 	    base = basename (head)
 	    print path
 	    #print base + '/' + tail
