@@ -19,9 +19,9 @@
 
 """Provides the interface to the AT-SPI Registry."""
 
-__id__        = "$Id: atspi.py,v 1.3 2007-09-03 11:34:55 nagappan Exp $"
-__version__   = "$Revision: 1.3 $"
-__date__      = "$Date: 2007-09-03 11:34:55 $"
+__id__        = "$Id: atspi.py,v 1.4 2008-01-30 05:55:17 nagappan Exp $"
+__version__   = "$Revision: 1.4 $"
+__date__      = "$Date: 2008-01-30 05:55:17 $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -46,7 +46,10 @@ ORBit.load_typelib("Accessibility")
 #   http://bugzilla.gnome.org/show_bug.cgi?id=342614
 #   http://mail.gnome.org/archives/orbit-list/2005-December/msg00001.html
 #
-ORBit.CORBA.ORB_init(orb_id="orbit-io-thread")
+try:
+    ORBit.CORBA.ORB_init (orb_id="orbit-io-thread")
+except:
+    ORBit.CORBA.ORB_init ()
 
 import Accessibility
 import Accessibility__POA
