@@ -30,6 +30,9 @@ import os
 import sys
 import time
 
+# Let us not register our application under at-spi application list
+os.environ ['GTK_MODULES'] = ''
+
 try:
     import pyatspi as atspi, Accessibility
 except ImportError:
@@ -38,7 +41,7 @@ except ImportError:
 
 from ldtplib.ldtplibutils import *
 
-ldtpDebug = os.getenv ('LDTP_DEBUG') # Enable debugging
+_ldtpDebug = os.getenv ('LDTP_DEBUG') # Enable debugging
 
 class objInst:
     table = 0
@@ -422,7 +425,7 @@ class appmap:
             if relationNames is not None and relationNames != '':
                 name = relationNames
                 label = 'label_by'
-        #if ldtpDebug and ldtpDebug == '2':
+        #if _ldtpDebug and _ldtpDebug == '2':
         #    print '%s* %s "%s": %s' % ('\t', roleName, name, description)
         objectInfo = self.getObjectInfo (accessible, parentName)
         if objectInfo is not None and role != Accessibility.ROLE_APPLICATION:
@@ -434,44 +437,49 @@ class appmap:
             if name != 'unnamed' and re.sub ("(?i) +", "", name) != '':
                 strippedStr = escapeChars (name, False)
                 own_name = objectInfo.prefix + strippedStr
+                try:
+                    tmpName = own_name.encode ('utf-8')
+                except UnicodeDecodeError:
+                    own_name = unicode (own_name, 'utf-8').encode ('utf-8')
                 if flag:
                     if self.applicationmap != {} and own_name in self.applicationmap and forceReScan == False:
-                        if ldtpDebug:
+                        if _ldtpDebug:
                             print 'has_key', own_name
                         # Since the window info is already in appmap, don't process further
                         return
                     cur_win = window (objectInfo.objType, name, parentName, accessible.getIndexInParent ())
-                    if ldtpDebug:
+                    if _ldtpDebug:
                         print 'Window:',  own_name,  cur_win,  type (own_name),  type (cur_win),  own_name in self.applicationmap,  forceReScan
                     if own_name in self.applicationmap and forceReScan:
                         del self.applicationmap [own_name]
-                    if ldtpDebug:
+                    if _ldtpDebug:
                         print 'Window:',  own_name,  cur_win,  type (own_name),  type (cur_win),  own_name in self.applicationmap,  forceReScan
                     self.applicationmap [own_name] = cur_win
                     self.hashmap = cur_win.children
                 #else:
                 #    if self.hashmap and own_name in self.hashmap:
                 #        own_name = self.get_non_conflicting_name (own_name)
-                #    if ldtpDebug and self.hashmap:
+                #    if _ldtpDebug and self.hashmap:
                 #        assert own_name not in self.hashmap, ('Name Conflict in Hashmap. ' + \
                 #                                              own_name + 'already present\n' + foo)
                 #    self.hashmap [own_name] = widget (objectInfo.objType, name, parentName, accessible.getIndexInParent ())
                 if self.hashmap and own_name in self.hashmap:
                     own_name = self.get_non_conflicting_name (own_name)
-                if ldtpDebug and self.hashmap:
+                if _ldtpDebug and self.hashmap:
                     assert own_name not in self.hashmap, ('Name Conflict in Hashmap. ' + \
                                                           own_name + 'already present\n' + foo)
                 self.hashmap [own_name] = widget (objectInfo.objType, name, parentName, accessible.getIndexInParent ())
-                if ldtpDebug and ldtpDebug == '2':
-                    print own_name  + '={class=' + objectInfo.objType + ',' + \
-                          label + '=' + name + ',child_index=' + str (accessible.getIndexInParent ()) + \
-                          ',parent=' + parentName + '}'
+                # if _ldtpDebug and _ldtpDebug == '2':
+                #     print u"%s={class=%s, %s=%s, child_index=%d, parent=%s}" % (own_name, objectInfo.objType,
+                #                                                                 label, name,
+                #                                                                 accessible.getIndexInParent (),
+                #                                                                 parentName)
                 parentName = own_name
             else:
                 own_name = objectInfo.prefix + str (objectInfo.instIndex)
                 if flag:
                     if self.applicationmap != {} and own_name in self.applicationmap:
-                        if ldtpDebug:
+                        if _ldtpDebug:
                             print 'has_key', own_name
                         # Since the window info is already in appmap, don't process further
                         return
@@ -480,9 +488,9 @@ class appmap:
                     self.hashmap = cur_win.children
                 else:
                     self.hashmap [own_name] = widget (objectInfo.objType, parentName, accessible.getIndexInParent ())
-                if ldtpDebug and ldtpDebug == '2':
-                    print own_name + '={class=' + objectInfo.objType + ',child_index='  +\
-                          str (accessible.getIndexInParent ()) + ',parent=' + parentName + '}'
+                if _ldtpDebug and _ldtpDebug == '2':
+                    print "%s={class=%s, child_index=%d, parent=%s}" % (own_name, objectInfo.objType, \
+                          accessible.getIndexInParent (), parentName)
                 parentName = own_name
         for i in range (accessible.childCount):
             child = accessible.getChildAtIndex (i)
@@ -493,8 +501,15 @@ class appmap:
                    childRole == Accessibility.ROLE_ALERT or childRole == Accessibility.ROLE_FONT_CHOOSER or \
                    childRole == Accessibility.ROLE_FILE_CHOOSER:
                 self.objectInst.reset ()
-            #time.sleep (1.0 / pow (10, 2))
-            self.dumpTree (child, parentName)
+            # time.sleep (1.0 / pow (10, 2))
+            try:
+                self.dumpTree (child, parentName)
+            except:
+                if _ldtpDebug:
+                    if hasattr (traceback, 'format_exc'):
+                        print traceback.format_exc ()
+                    else:
+                        print traceback.print_exc ()
             child.unref ()
 
     def isRoleWindowType (self, _role):
@@ -528,7 +543,7 @@ class appmap:
                _role == Accessibility.ROLE_FILE_CHOOSER:
             _windowType = 'dlg'
         else:
-            if ldtpDebug:
+            if _ldtpDebug:
                 print 'Not a window type'
             return None
         if _windowName and _windowName != '':
@@ -596,7 +611,7 @@ class appmap:
                 self.hierarchy = '%(objtype)s:%(index)d;%(hierarchy)s' % \
                                  {'objtype' : objectInfo.objType, 'index' : accessible.getIndexInParent (), 'hierarchy' : self.hierarchy}
         else:
-            if ldtpDebug:
+            if _ldtpDebug:
                 print 'Unknown objectInfo'
         _parent = accessible.parent
         if _parent is None:
@@ -654,19 +669,22 @@ class appmap:
     def getChildWindowHandle (self, accessible,  name):
         if accessible is None:
             return None
-        if ldtpDebug:
+        if _ldtpDebug:
             print 'childCount',  accessible.childCount
         for i in range (0, accessible.childCount):
             try:
                 _app = accessible.getChildAtIndex (i)
             except:
-                if ldtpDebug:
-                    print traceback.print_exc ()
+                if _ldtpDebug:
+                    if hasattr (traceback, 'format_exc'):
+                        print traceback.format_exc ()
+                    else:
+                        print traceback.print_exc ()
                 continue
             if _app is None:
                 continue
             _role = _app.getRole ()
-            if ldtpDebug:
+            if _ldtpDebug:
                 print 'Role: ',  _app.getRoleName (),  name
                 if _app.name != None:
                     print '_app.name',  _app.name,  self.getWinNameAppmapFormat (_app.name,  _role)
@@ -714,22 +732,25 @@ class appmap:
             try:
                 _app = _desktop.getChildAtIndex (i)
             except:
-                if ldtpDebug:
-                    print traceback.print_exc ()
+                if _ldtpDebug:
+                    if hasattr (traceback, 'format_exc'):
+                        print traceback.format_exc ()
+                    else:
+                        print traceback.print_exc ()
                 continue
             if _app is None:
                 continue
             _name = ''
             if _app.name is not None and _app.name != "":
-                if ldtpDebug:
+                if _ldtpDebug:
                     print 'DEBUG _app.name, _app.getRoleName',  _app.name,  _app.getRoleName ()
                 _name = self.getWinNameAppmapFormat (_app.name,  _app.getRole ())
-                if ldtpDebug:
+                if _ldtpDebug:
                     print '_name',  _name
             else:
                 _app.unref ()
                 continue
-            if ldtpDebug:
+            if _ldtpDebug:
                 print 'appName',  appName,  _name,  _app.name
             if _name != None and re.search (appName,  _name) != None or \
                 re.search (appName,  _app.name) != None:
