@@ -24,18 +24,31 @@
 #
 #############################################################################
 
-import socket, os, struct, time, traceback
-import threading, re, thread, select
-import sys, logging, logging.config
+import os
+import re
+import sys
+import time
+import socket
+import struct
+import thread
+import select
+import logging
+import commands
+import traceback
+import threading
+import logging.config
 from xml.sax import saxutils
 
+# Let us not register our application under at-spi application list
+os.environ ['GTK_MODULES'] = ''
+
 try:
     import pyatspi as atspi, Accessibility
 except ImportError:
     import atspi
     import Accessibility
 
-ldtpDebug = os.getenv ('LDTP_DEBUG')
+_ldtpDebug = os.getenv ('LDTP_DEBUG')
 
 # General functions
 class command:
@@ -78,7 +91,7 @@ class command:
     SELECTPOPUPMENU = 36
     SELECTITEM = 37
     SELECTTEXTITEM = 38
-    ISMENUITEMENABLED = 39
+    MENUITEMENABLED = 39
     SELECTMENUITEM = 40
     SELECTTAB = 41
     VERIFYPUSHBUTTON = 42
@@ -133,7 +146,7 @@ class command:
     VERIFYUNCHECKROW = 91
     VERIFYVISIBLEBUTTONCOUNT = 92
     VERIFYBUTTONCOUNT = 93
-    GETEVENTCOUNT = 94
+    VERIFYTABNAME = 94
     DOUBLECLICKROW = 95
     GETTABLEROWINDEX = 96
     GETCHARCOUNT = 97
@@ -189,7 +202,9 @@ class command:
     GUITIMEOUT = 147
     OBJTIMEOUT = 148
     GETCHILD = 149
-    LASTCOMMAND = 150
+    GETTABNAME = 150
+    DOUBLECLICKROWINDEX = 151
+    LASTCOMMAND = 153
 
 class state:
     INVALID = Accessibility.STATE_INVALID
@@ -205,36 +220,46 @@ class state:
     EXPANDED = Accessibility.STATE_EXPANDED
     FOCUSABLE = Accessibility.STATE_FOCUSABLE
     FOCUSED = Accessibility.STATE_FOCUSED
-    HORIZONTAL = Accessibility.STATE_HORIZONTAL
-    ICONIFIED = Accessibility.STATE_ICONIFIED
-    MODAL = Accessibility.STATE_MODAL
-    MULTI_LINE = Accessibility.STATE_MULTI_LINE
-    MULTISELECTABLE = Accessibility.STATE_MULTISELECTABLE
-    OPAQUE = Accessibility.STATE_OPAQUE
-    PRESSED = Accessibility.STATE_PRESSED
-    RESIZABLE = Accessibility.STATE_RESIZABLE
-    SELECTABLE = Accessibility.STATE_SELECTABLE
-    SELECTED = Accessibility.STATE_SELECTED
-    SENSITIVE = Accessibility.STATE_SENSITIVE
-    SHOWING = Accessibility.STATE_SHOWING
-    SINGLE_LINE = Accessibility.STATE_SINGLE_LINE
-    STALE = Accessibility.STATE_STALE
-    TRANSIENT = Accessibility.STATE_TRANSIENT
-    VERTICAL = Accessibility.STATE_VERTICAL
-    VISIBLE = Accessibility.STATE_VISIBLE
-    MANAGES_DESCENDANTS = Accessibility.STATE_MANAGES_DESCENDANTS
-    INDETERMINATE = Accessibility.STATE_INDETERMINATE
-    LAST_DEFINED = Accessibility.STATE_LAST_DEFINED
+    # FIXME: Dirty hack
+    # this is due to a mismatch between CSPI
+    # and pyatspi accessibility state
+    __addValue = 0
     try:
-        TRUNCATED = Accessibility.STATE_TRUNCATED
-        REQUIRED = Accessibility.STATE_REQUIRED
-        INVALID_ENTRY = Accessibility.STATE_INVALID_ENTRY
-        SUPPORTS_AUTOCOMPLETION = Accessibility.STATE_SUPPORTS_AUTOCOMPLETION
-        SELECTABLE_TEXT = Accessibility.STATE_SELECTABLE_TEXT
-        IS_DEFAULT = Accessibility.STATE_IS_DEFAULT
-        VISISTED = Accessibility.STATE_VISITED
+        # This does not exist in AT-CSPI - GNOME 2.20
+        HAS_TOOLTIP = Accessibility.STATE_HAS_TOOLTIP
+        __addValue = -1
     except:
-        if ldtpDebug is not None:
+        pass
+    HORIZONTAL = Accessibility.STATE_HORIZONTAL + __addValue
+    ICONIFIED = Accessibility.STATE_ICONIFIED + __addValue
+    MODAL = Accessibility.STATE_MODAL + __addValue
+    MULTI_LINE = Accessibility.STATE_MULTI_LINE + __addValue
+    MULTISELECTABLE = Accessibility.STATE_MULTISELECTABLE + __addValue
+    OPAQUE = Accessibility.STATE_OPAQUE + __addValue
+    PRESSED = Accessibility.STATE_PRESSED + __addValue
+    RESIZABLE = Accessibility.STATE_RESIZABLE + __addValue
+    SELECTABLE = Accessibility.STATE_SELECTABLE + __addValue
+    SELECTED = Accessibility.STATE_SELECTED + __addValue
+    SENSITIVE = Accessibility.STATE_SENSITIVE + __addValue
+    SHOWING = Accessibility.STATE_SHOWING + __addValue
+    SINGLE_LINE = Accessibility.STATE_SINGLE_LINE + __addValue
+    STALE = Accessibility.STATE_STALE + __addValue
+    TRANSIENT = Accessibility.STATE_TRANSIENT + __addValue
+    VERTICAL = Accessibility.STATE_VERTICAL + __addValue
+    VISIBLE = Accessibility.STATE_VISIBLE + __addValue
+    MANAGES_DESCENDANTS = Accessibility.STATE_MANAGES_DESCENDANTS + __addValue
+    INDETERMINATE = Accessibility.STATE_INDETERMINATE + __addValue
+    LAST_DEFINED = Accessibility.STATE_LAST_DEFINED + __addValue
+    try:
+        TRUNCATED = Accessibility.STATE_TRUNCATED + __addValue
+        REQUIRED = Accessibility.STATE_REQUIRED + __addValue
+        INVALID_ENTRY = Accessibility.STATE_INVALID_ENTRY + __addValue
+        SUPPORTS_AUTOCOMPLETION = Accessibility.STATE_SUPPORTS_AUTOCOMPLETION + __addValue
+        SELECTABLE_TEXT = Accessibility.STATE_SELECTABLE_TEXT + __addValue
+        IS_DEFAULT = Accessibility.STATE_IS_DEFAULT + __addValue
+        VISISTED = Accessibility.STATE_VISITED + __addValue
+    except:
+        if _ldtpDebug is not None:
             print 'New roles'
         pass
 
@@ -417,6 +442,11 @@ class LdtpErrorCode:
     SET_OBJ_TIMEOUT_FAILED = -1175
     UNABLE_TO_GET_DEVICE = -1176
     UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE = -1177
+    UNABLE_TO_GET_PAGE_TAB_NAME = -1178
+    UNABLE_TO_VERIFY_PAGE_TAB_NAME = -1179
+    CHECK_BOX_STATE_NOT_ENABLED = -1180
+    ERROR_PUSH_BUTTON_STATE_NOT_ENABLED = -1181
+    ERROR_TOGGLE_BUTTON_STATE_NOT_ENABLED = -1182
 
 class XmlTags:
     XML_HEADER                   = "<?xml version=\"1.0\" encoding=\"utf-8\"?>"
@@ -461,6 +491,73 @@ class ConnectionLost (Exception):
     def __str__ (self):
         return repr (self.value)
 
+def startLdtpExecutionEngine ():
+    _display = os.getenv ('DISPLAY')
+    
+    if _display == None:
+        raise LdtpExecutionError ('Missing DISPLAY environment variable. Running in text mode ?')    
+
+    if _ldtpDebug:
+        commands.getstatusoutput ('mkdir -p /tmp/ldtp-$USER')
+
+    _mainSock = None
+    _socketPath = '/tmp/ldtp-' + os.getenv ('USER') + '-' + _display
+    
+    _ldtpUseTcp = False
+    _ldtpServerAddr = None
+    _ldtpServerPort = None
+    if os.environ.has_key("LDTP_SERVER_ADDR"):
+        _ldtpServerAddr = os.environ["LDTP_SERVER_ADDR"]
+        if os.environ.has_key("LDTP_SERVER_PORT"):
+            _ldtpServerPort = int (os.environ["LDTP_SERVER_PORT"])
+        else:
+            _ldtpServerPort = 23456
+        _ldtpUseTcp = True
+
+    try:
+        # Create a client socket
+        _mainSock = None
+        if _ldtpUseTcp:
+            _mainSock = socket.socket (socket.AF_INET, socket.SOCK_STREAM)
+        else:
+            _mainSock = socket.socket (socket.AF_UNIX, socket.SOCK_STREAM)
+    except socket.error,msg:
+        if _ldtpUseTcp:
+            raise LdtpExecutionError ('Error while creating socket  ' + str (msg))
+        else:
+            raise LdtpExecutionError ('Error while creating UNIX socket  ' + str (msg))    
+    
+    # Let us retry connecting to the server for 3 times
+    _retryCount = 0
+
+    while True:
+        try:
+            try:
+                # Connect to server socket
+                if _ldtpUseTcp:
+                    _mainSock.connect((_ldtpServerAddr, _ldtpServerPort))
+                else:
+                    _mainSock.connect (_socketPath)
+                return _mainSock, _ldtpUseTcp
+            except TypeError:
+                raise ConnectionLost ('Environment LDTP_AUTH_SOCK variable not set')
+        except socket.error, msg:
+            if _retryCount == 3:
+                raise ConnectionLost ('Could not establish connection ' + str (msg))
+            _retryCount += 1
+            #If we are not trying to connect to a remote server then we can attempt to
+            #startup the ldtp server and then try to re-connect to it.
+            if not _ldtpUseTcp:
+                _pid = os.fork ()
+                if _pid == 0:
+                    try:
+                        os.execvpe ('ldtp', [''], os.environ)
+                    except OSError:
+                        raise LdtpExecutionError ('ldtp executable not in PATH')
+                else:
+                    # Let us wait for 1 second, let the server starts
+                    time.sleep (1)
+
 def getText (nodelist):
     rc = ""
     for node in nodelist:
@@ -489,106 +586,121 @@ def waitnanoseconds (nanoSeconds = 30000.0):
 
 # Send given packet to server
 def sendpacket (msg):
-	flag = False
-	try:
-		timedelay = os.getenv ('LDTP_DELAY_CMD')
-		_sendLck.acquire ()
-		if timedelay != None:
-			try:
-				# Delay each command by 'timedelay' seconds
-				time.sleep (int (timedelay))
-			except IndexError:
-				# Default to 5 seconds delay if LDTP_DELAY_CMD
-				# env variable is set
-				time.sleep (5)
-		flag = True
-		# Get client socket fd based on thread id
-		client = sockFdPool.get (threading.currentThread ())
-		
-		# Encode the message in UTF-8 so we don't break on extended
-		# characters in the application GUIs
-		buf = msg.encode ('utf8')
-		
-		# Pack length (integer value) in network byte order
-		msglen = struct.pack ('!i', len (buf))
-		# Send message length
-		client.send (msglen)
-		# Send message
-		client.send (buf)
-		if ldtpDebug != None and ldtpDebug == '2':
-			print 'Send packet', buf
-		#_sendLck.release ()
-	except socket.error, msg:
-		raise LdtpExecutionError ('Server aborted')
-	except:
-                if ldtpDebug:
+    flag = False
+    try:
+        try:
+            timedelay = os.getenv ('LDTP_DELAY_CMD')
+            _sendLck.acquire ()
+            if timedelay != None:
+                try:
+                    # Delay each command by 'timedelay' seconds
+                    time.sleep (int (timedelay))
+                except IndexError:
+                    # Default to 5 seconds delay if LDTP_DELAY_CMD
+                    # env variable is set
+                    time.sleep (5)
+            flag = True
+            # Get client socket fd based on thread id
+            client = sockFdPool.get (threading.currentThread ())
+            if client is None:
+                _mainSock, _ldtpUseTcp = startLdtpExecutionEngine ()
+                client = sockFdPool [threading.currentThread ()] = _mainSock
+
+            # Encode the message in UTF-8 so we don't break on extended
+            # characters in the application GUIs
+            buf = msg.encode ('utf8')
+			
+            # Pack length (integer value) in network byte order
+            msglen = struct.pack ('!i', len (buf))
+            # Send message length
+            client.send (msglen)
+            # Send message
+            client.send (buf)
+            if _ldtpDebug != None and _ldtpDebug == '2':
+                print 'Send packet', buf
+            #_sendLck.release ()
+        except socket.error, msg:
+            _mainSock, _ldtpUseTcp = startLdtpExecutionEngine ()
+            sockFdPool [threading.currentThread ()] = _mainSock
+            raise LdtpExecutionError ('Server aborted')
+        except:
+            if hasattr (traceback, 'format_exc'):
+                if _ldtpDebug:
+                    print traceback.format_exc ()
+                raise LdtpExecutionError (str (traceback.format_exc ()))
+            else:
+                if _ldtpDebug:
                     print traceback.print_exc ()
                 raise LdtpExecutionError (str (traceback.print_exc ()))
-        finally:
-		if flag:
-			# Reason for using the flag:
-			# 'Do not call this method when the lock is unlocked.'
-			_sendLck.release ()
-                        flag = False
+    finally:
+        if flag:
+            # Reason for using the flag:
+            # 'Do not call this method when the lock is unlocked.'
+            _sendLck.release ()
+            flag = False
 
 def recvpacket (peek_flag = 0, sockfd = None):
-	flag = False
-	try:
-		_recvLck.acquire ()
-		flag = True
-		client = None
-		# Get client socket fd based on thread id
-		if sockfd == None:
-			client = sockFdPool.get (threading.currentThread ())
-		else:
-			client = sockfd
-		_responsePacket = None
-		client.settimeout (5.0)
-		# Hardcoded 4 bytes, as the server sends 4 bytes as packet length
-		data = client.recv (4, peek_flag)
-		if data == '' or data == None:
-			if flag == True:
-				# Reason for using the flag:
-				# 'Do not call this method when the lock is unlocked.'
-				_recvLck.release ()
-                                flag = False
-			return None
-		_packetSize, = struct.unpack('!i', data)
-		if peek_flag == 0 and ldtpDebug != None and ldtpDebug == '2':
-			print 'Received packet size', _packetSize
-		# MSG_PEEK
-                # This flag causes the receive operation to return data from the beginning
-		# of the receive queue without removing that data from  the  queue.
-		# Thus, a subsequent receive call will return the same data.
+    flag = False
+    try:
+        try:
+            _recvLck.acquire ()
+            flag = True
+            client = None
+            # Get client socket fd based on thread id
+            if sockfd is None:
+                client = sockFdPool.get (threading.currentThread ())
+            else:
+                client = sockfd
+            _responsePacket = None
+            client.settimeout (5.0)
+            # Hardcoded 4 bytes, as the server sends 4 bytes as packet length
+            data = client.recv (4, peek_flag)
+            if data == '' or data == None:
+                if flag == True:
+                    # Reason for using the flag:
+                    # 'Do not call this method when the lock is unlocked.'
+                    _recvLck.release ()
+                    flag = False
+                return None
+            _packetSize, = struct.unpack('!i', data)
+            if peek_flag == 0 and _ldtpDebug != None and _ldtpDebug == '2':
+                print 'Received packet size', _packetSize
+            # MSG_PEEK
+            # This flag causes the receive operation to return data from the beginning
+            # of the receive queue without removing that data from  the  queue.
+            # Thus, a subsequent receive call will return the same data.
 
-		if peek_flag != 0:
-			# MSG_PEEK
-			_responsePacket = client.recv (4 + _packetSize, peek_flag)
-		else:
-			_responsePacket = client.recv (_packetSize, peek_flag)
-		if peek_flag != 0:
-			_pattern = re.compile ('\<\?xml')
-			_searchObj = re.search (_pattern, _responsePacket)
-			_finalPacket = _responsePacket[_searchObj.start () :]
-			_responsePacket = _finalPacket
-		#_recvLck.release ()
-		if peek_flag == 0 and ldtpDebug != None and ldtpDebug == '2':
-			print 'Received response Packet', _responsePacket
-		return _responsePacket
-	except struct.error, msg:
-		raise LdtpExecutionError ('Invalid packet length ' + str (msg))
-	except socket.timeout:
-		#if ldtpDebug != None and ldtpDebug == '2':
-		#	print 'Timeout'
-		return ''
-	except:
-		raise LdtpExecutionError ('Error while receiving packet ' + str (traceback.print_exc ()))
-        finally:
-		if flag:
-			# Reason for using the flag:
-			# 'Do not call this method when the lock is unlocked.'
-			_recvLck.release ()
-                        flag = False
+            if peek_flag != 0:
+                # MSG_PEEK
+                _responsePacket = client.recv (4 + _packetSize, peek_flag)
+            else:
+                _responsePacket = client.recv (_packetSize, peek_flag)
+                if _ldtpDebug != None and _ldtpDebug == '2':
+                    print 'Received response Packet', _responsePacket
+            if peek_flag != 0:
+                _pattern = re.compile ('\<\?xml')
+                _searchObj = re.search (_pattern, _responsePacket)
+                _finalPacket = _responsePacket[_searchObj.start () :]
+                _responsePacket = _finalPacket
+                # _recvLck.release ()
+                return _responsePacket
+        except struct.error, msg:
+            raise LdtpExecutionError ('Invalid packet length ' + str (msg))
+        except socket.timeout:
+            # if _ldtpDebug != None and _ldtpDebug == '2':
+            #	print 'Timeout'
+            return ''
+        except:
+            if hasattr (traceback, 'format_exc'):
+                raise LdtpExecutionError ('Error while receiving packet ' + str (traceback.format_exc ()))
+            else:
+                raise LdtpExecutionError ('Error while receiving packet ' + str (traceback.print_exc ()))
+    finally:
+        if flag:
+            # Reason for using the flag:
+            # 'Do not call this method when the lock is unlocked.'
+            _recvLck.release ()
+            flag = False
 
 def getErrorMessage (errorCode, args):
     msg = None
@@ -947,10 +1059,14 @@ def getErrorMessage (errorCode, args):
     elif errorCode == LdtpErrorCode.UNABLE_TO_GET_DEVICE:
         msg = "Unable to get device control"
     elif errorCode == LdtpErrorCode.UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE:
-        msg = "Unable to get child with provided role";
+        msg = "Unable to get child with provided role"
+    elif errorCode == LdtpErrorCode.UNABLE_TO_GET_PAGE_TAB_NAME:
+        msg = "Unable to get page tab name"
+    elif errorCode == LdtpErrorCode.UNABLE_TO_VERIFY_PAGE_TAB_NAME:
+        msg = "Unable to verify page tab name"
     else:
-        msg = "Error code not found";
-    return msg;
+        msg = "Error code not found"
+    return msg
 
 LDTP_LOG_TESTSTART = 61
 LDTP_LOG_TESTEND   = 62
@@ -1028,72 +1144,72 @@ class LdtpLogRecord (logging.LogRecord):
     as an additional attribute
     """
     def __init__ (self, name, level, pathname, lineno, msg, args, exc_info):
-	    if level == LDTP_LOG_LOGSTARTTAG:
-		    msg = '<' + saxutils.escape (msg) + '>'
-	    elif level == LDTP_LOG_LOGSTOPTAG:
-		    msg = '</' + saxutils.escape (msg) + '>'
-	    elif level == LDTP_LOG_GROUPSTART:
-		    msg = '<group name=\"' + saxutils.escape (msg) + '\">'
-	    elif level == LDTP_LOG_GROUPEND:
-		    msg = '</group>'
-	    elif level == LDTP_LOG_CATEGORYSTART:
-		    msg = '<category name=\"' + saxutils.escape (msg) + '\">'
-	    elif level == LDTP_LOG_CATEGORYEND:
-		    msg = '</category>'
-	    elif level == LDTP_LOG_SCRIPTSTART:
-		    msg = '<script name=\"' + saxutils.escape (msg) + '\">'
-	    elif level == LDTP_LOG_SCRIPTEND:
-		    msg = '</script>'
-	    elif level == LDTP_LOG_TESTSTART:
-		    msg = '<test name=\"' + saxutils.escape (msg) + '\">'
-	    elif level == LDTP_LOG_TESTEND:
-		    msg = '</test>'
-	    elif level == LDTP_LOG_BEGIN:
-		    msg = '<testsuite name=\"' + saxutils.escape (msg) + '\">'
-	    elif level == LDTP_LOG_END:
-		    msg = '</testsuite>'
-	    elif level == LDTP_LOG_PASS:
-		    msg = '<pass>1</pass>'
-	    elif level == LDTP_LOG_FAIL:
-		    msg = '<pass>0</pass>'
-	    elif level == LDTP_LOG_GROUPSSTATUS:
-		    msg = '<groupsstatus ' + saxutils.escape (msg) + '></groupsstatus>'
-	    elif level == LDTP_LOG_CATEGORYSTATUS:
-		    msg = '<categorystatus ' + saxutils.escape (msg) + '></categorystatus>'
-	    elif level == LDTP_LOG_TIMEINFO:
-		    msg = '<timeinfo ' + saxutils.escape (msg) + '></timeinfo>'
-	    elif level == LDTP_LOG_TOTALTIMEINFO:
-		    msg = '<totaltimeinfo ' + saxutils.escape (msg) + '></totaltimeinfo>'
-	    else:
-		    msg = '<' + logging.getLevelName (level) +'>' + saxutils.escape (msg) + '</' + logging.getLevelName (level) + '>'
-	    if sys.version_info [0] >= 3 or (sys.version_info [0] >= 2 and sys.version_info [1] >= 5):
-		    logging.LogRecord.__init__ (self, name, level, pathname, lineno, msg, args, exc_info, None)
-	    else:
-		    logging.LogRecord.__init__ (self, name, level, pathname, lineno, msg, args, exc_info)
+        if level == LDTP_LOG_LOGSTARTTAG:
+            msg = '<' + saxutils.escape (msg) + '>'
+        elif level == LDTP_LOG_LOGSTOPTAG:
+            msg = '</' + saxutils.escape (msg) + '>'
+        elif level == LDTP_LOG_GROUPSTART:
+            msg = '<group name=\"' + saxutils.escape (msg) + '\">'
+        elif level == LDTP_LOG_GROUPEND:
+            msg = '</group>'
+        elif level == LDTP_LOG_CATEGORYSTART:
+            msg = '<category name=\"' + saxutils.escape (msg) + '\">'
+        elif level == LDTP_LOG_CATEGORYEND:
+            msg = '</category>'
+        elif level == LDTP_LOG_SCRIPTSTART:
+            msg = '<script name=\"' + saxutils.escape (msg) + '\">'
+        elif level == LDTP_LOG_SCRIPTEND:
+            msg = '</script>'
+        elif level == LDTP_LOG_TESTSTART:
+            msg = '<test name=\"' + saxutils.escape (msg) + '\">'
+        elif level == LDTP_LOG_TESTEND:
+            msg = '</test>'
+        elif level == LDTP_LOG_BEGIN:
+            msg = '<testsuite name=\"' + saxutils.escape (msg) + '\">'
+        elif level == LDTP_LOG_END:
+            msg = '</testsuite>'
+        elif level == LDTP_LOG_PASS:
+            msg = '<pass>1</pass>'
+        elif level == LDTP_LOG_FAIL:
+            msg = '<pass>0</pass>'
+        elif level == LDTP_LOG_GROUPSSTATUS:
+            msg = '<groupsstatus ' + saxutils.escape (msg) + '></groupsstatus>'
+        elif level == LDTP_LOG_CATEGORYSTATUS:
+            msg = '<categorystatus ' + saxutils.escape (msg) + '></categorystatus>'
+        elif level == LDTP_LOG_TIMEINFO:
+            msg = '<timeinfo ' + saxutils.escape (msg) + '></timeinfo>'
+        elif level == LDTP_LOG_TOTALTIMEINFO:
+            msg = '<totaltimeinfo ' + saxutils.escape (msg) + '></totaltimeinfo>'
+        else:
+            msg = '<' + logging.getLevelName (level) +'>' + saxutils.escape (msg) + '</' + logging.getLevelName (level) + '>'
+        if sys.version_info [0] >= 3 or (sys.version_info [0] >= 2 and sys.version_info [1] >= 5):
+            logging.LogRecord.__init__ (self, name, level, pathname, lineno, msg, args, exc_info, None)
+        else:
+            logging.LogRecord.__init__ (self, name, level, pathname, lineno, msg, args, exc_info)
 
 if sys.version_info [0] >= 3 or (sys.version_info [0] >= 2 and sys.version_info [1] >= 5):
-	def makeRecord (self, name, level, fn, lno, msg, args, exc_info, func = None, extra = None):
-		if type (level) != int and len (msg) == 0:
-			exc_info = args
-			args = msg
-			msg = lno
-			lno = fn
-			fn = level
-			level = name
-			name = logging.getLogger ('XML').name
-		return LdtpLogRecord (name, level, fn, lno, msg, args, exc_info)
+    def makeRecord (self, name, level, fn, lno, msg, args, exc_info, func = None, extra = None):
+        if type (level) != int and len (msg) == 0:
+            exc_info = args
+            args = msg
+            msg = lno
+            lno = fn
+            fn = level
+            level = name
+            name = logging.getLogger ('XML').name
+            return LdtpLogRecord (name, level, fn, lno, msg, args, exc_info)
 else:
-	def makeRecord (name, level, fn, lno, msg, args, exc_info, func = None, extra = None):
-		if type (level) != int and len (msg) == 0:
-			exc_info = args
-			args = msg
-			msg = lno
-			lno = fn
-			fn = level
-			level = name
-			name = logging.getLogger ('XML').name
-		return LdtpLogRecord (name, level, fn, lno, msg, args, exc_info)
-
+    def makeRecord (name, level, fn, lno, msg, args, exc_info, func = None, extra = None):
+        if type (level) != int and len (msg) == 0:
+            exc_info = args
+            args = msg
+            msg = lno
+            lno = fn
+            fn = level
+            level = name
+            name = logging.getLogger ('XML').name
+            return LdtpLogRecord (name, level, fn, lno, msg, args, exc_info)
+        
 class LdtpLogger (logging.Logger):
     """
     Logger subclass that uses CustomLogRecord as its LogRecord class
@@ -1102,43 +1218,48 @@ class LdtpLogger (logging.Logger):
         logging.Logger.__init__ (self, name, level)
 
 def startInternalLog (logFileName, fileOverWrite, loggerCode):
-	try:
-		logging.setLoggerClass (LdtpLogger)
-		logger = logging.getLogger (loggerCode)
-                xmlhdlr = None
-		xmlLogMode = 'w'
-		if fileOverWrite == 0:
-			xmlLogMode = 'a'
-		try:
-			if logFileName [0] == "~":
-				logFileName = os.path.expanduser (logFileName)
-			elif logFileName [0] == ".":
-				logFileName = os.path.abspath (logFileName)
-			xmlhdlr = logging.FileHandler (logFileName, xmlLogMode)
-			logger.addHandler (xmlhdlr)
-			logger.setLevel (logging.WARNING)
-			logger.makeRecord = makeRecord
-			if fileOverWrite == 1:
-				logger.log (LDTP_LOG_LOGSTARTTAG, 'ldtp')
-		except IOError:
-                    if ldtpDebug is not None:
-                        print traceback.print_exc ()
-                    return None, None
-		if xmlhdlr == None:
-                    # If xmlhdlr handler is not created, then let us enable this
-                    logger.manager.emittedNoHandlerWarning = 1
-		return logger, xmlhdlr
-	except:
-            if ldtpDebug is not None:
+    try:
+        logging.setLoggerClass (LdtpLogger)
+        logger = logging.getLogger (loggerCode)
+        xmlhdlr = None
+        xmlLogMode = 'w'
+        if fileOverWrite == 0:
+            xmlLogMode = 'a'
+        try:
+            if logFileName [0] == "~":
+                logFileName = os.path.expanduser (logFileName)
+            elif logFileName [0] == ".":
+                logFileName = os.path.abspath (logFileName)
+            xmlhdlr = logging.FileHandler (logFileName, xmlLogMode)
+            logger.addHandler (xmlhdlr)
+            logger.setLevel (logging.WARNING)
+            logger.makeRecord = makeRecord
+            if fileOverWrite == 1:
+                logger.log (LDTP_LOG_LOGSTARTTAG, 'ldtp')
+        except IOError:
+            if _ldtpDebug is not None:
+                if hasattr (traceback, 'format_exc'):
+                    print traceback.format_exc ()
+                else:
+                    print traceback.print_exc ()
+                return None, None
+        if xmlhdlr == None:
+            # If xmlhdlr handler is not created, then let us enable this
+            logger.manager.emittedNoHandlerWarning = 1
+        return logger, xmlhdlr
+    except:
+        if _ldtpDebug is not None:
+            if hasattr (traceback, 'format_exc'):
+                print traceback.format_exc ()
+            else:
                 print traceback.print_exc ()
-            return None, None
+        return None, None
 
 def isPriority (priority, givenPriority):
-	regexp = re.compile ('\A' + priority, re.IGNORECASE)
-	if regexp.search (givenPriority) == None:
-		return False
-	else:
-		return True
+    regexp = re.compile ('\A' + priority, re.IGNORECASE)
+    if regexp.search (givenPriority) == None:
+        return False
+    return True
 
 def internalLog (message, priority, logger):
     if logger == None:
@@ -1223,9 +1344,6 @@ def escapeChars (str2escape, escapeDot = True):
         str2escape = re.sub ("(?i)\.+", "", str2escape)
         str2escape = re.sub ("(?i)_+", "", str2escape)
         str2escape = re.sub ("(?i):+", "", str2escape)
-    # Dialog Save As... (Gedit Save As dialog box ends with 3 dots)
-    # with at-spi call, we get them as single unicode char
-    str2escape = re.sub (u"(?i)\u2026+", "...", str2escape.decode ('utf-8'))
     return str2escape
 
 def escapeChar (str2escape, char):
