@@ -27,7 +27,7 @@
 
 __author__ = "Nagappan A"
 __maintainer__ = "Nagappan A"
-__version__ = "1.0.0"
+__version__ = "1.2.0"
 
 import re
 import os
@@ -98,7 +98,10 @@ class record:
             self.registry.start ()
         except:
             if _ldtpDebug and _ldtpDebug == '3':
-                print traceback.print_exc ()
+                if hasattr (traceback, 'format_exc'):
+                    print traceback.format_exc ()
+                else:
+                    print traceback.print_exc ()
             pass
 
     def doesWindowExist (self, name):
@@ -118,7 +121,10 @@ class record:
                 _app = _desktop.getChildAtIndex (i)
             except:
                 if _ldtpDebug:
-                    print traceback.print_exc ()
+                    if hasattr (traceback, 'format_exc'):
+                        print traceback.format_exc ()
+                    else:
+                        print traceback.print_exc ()
                 continue
             if _app is None:
                 continue
@@ -147,7 +153,10 @@ class record:
         try:
             return self.getObjectNameDebug (name)
         except:
-            print traceback.print_exc ()
+            if hasattr (traceback, 'format_exc'):
+                print traceback.format_exc ()
+            else:
+                print traceback.print_exc ()
             return ''
 
     def getObjectNameDebug (self, name):
@@ -205,7 +214,10 @@ class record:
                         self.appmap.dumpTree (_accessible,  name,  True)
                     except:
                         if _ldtpDebug:
-                            print traceback.print_exc ()
+                            if hasattr (traceback, 'format_exc'):
+                                print traceback.format_exc ()
+                            else:
+                                print traceback.print_exc ()
                     _accessible.unref ()
                     i = 1
                     _parent = _windowName
@@ -332,7 +344,10 @@ class record:
                                                               self.timeElapsed ())
                     self.__pckt.sendpacket (_xml)
             except:
-                print traceback.print_exc ()
+                if hasattr (traceback, 'format_exc'):
+                    print traceback.format_exc ()
+                else:
+                    print traceback.print_exc ()
 
     def nameChangeListenerCallback (self, event):
         _role = event.source.getRole ()
@@ -357,7 +372,10 @@ class record:
                                                               self.timeElapsed ())
                     self.__pckt.sendpacket (_xml)
             except:
-                print traceback.print_exc ()
+                if hasattr (traceback, 'format_exc'):
+                    print traceback.format_exc ()
+                else:
+                    print traceback.print_exc ()
 
     def registerWindowListener (self):
         eventTypes = [
@@ -379,7 +397,10 @@ class record:
         try:
             self.globalListenerCallbackDebug (event)
         except:
-            print traceback.print_exc ()
+            if hasattr (traceback, 'format_exc'):
+                print traceback.format_exc ()
+            else:
+                print traceback.print_exc ()
 
     def globalListenerCallbackDebug (self, event):
         if event.type == 'object:state-changed:defunct' or \
@@ -830,7 +851,10 @@ class record:
                     else:
                         return
                 except AttributeError:
-                    print traceback.print_exc ()
+                    if hasattr (traceback, 'format_exc'):
+                        print traceback.format_exc ()
+                    else:
+                        print traceback.print_exc ()
                     accessible = atspi.Accessible.makeAccessible (event.source)
                     if accessible and accessible.state.count (Accessibility.STATE_VISIBLE) and \
                            accessible.state.count (Accessibility.STATE_EDITABLE) and \
@@ -874,7 +898,10 @@ class record:
                     _text = _text._narrow (Accessibility.Text)
                 except:
                     _text = None
-                    print traceback.print_exc ()
+                    if hasattr (traceback, 'format_exc'):
+                        print traceback.format_exc ()
+                    else:
+                        print traceback.print_exc ()
                 if _text:
                     _count = -1
                     if str (event.type).startswith ('object:text-changed:insert'):
@@ -1114,7 +1141,10 @@ def start (pckt = None):
         stop ()
         raise
     except:
-        print traceback.print_exc ()
+        if hasattr (traceback, 'format_exc'):
+            print traceback.format_exc ()
+        else:
+            print traceback.print_exc ()
         stop ()
 
 # To stop recording, just call this function once
