@@ -50,6 +50,28 @@ get_check_box_state (Accessible *object)
 		return FALSE; // Unchecked state
 }
 
+static gboolean
+is_check_box_enabled (Accessible *object)
+{
+	AccessibleStateSet *state;
+
+	if (!object)
+		return FALSE;
+	if (wait_till_object_state_contains (object, CHECK_BOX, NULL) == -1) {
+		LDTPErrorCode error;
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), NULL);
+		return FALSE;
+	}
+	state = Accessible_getStateSet (object);
+
+	/* Verifies it is enabled or not */
+	if (AccessibleStateSet_contains (state, SPI_STATE_ENABLED) == TRUE)
+		return TRUE;
+	else
+		return FALSE;
+}
+
 static LDTPErrorCode
 check_check_box (Accessible *object, FILE *log_fp)
 {
@@ -180,20 +202,25 @@ check_box_main (LDTPClientContext* cctxt, int command)
 		error = check_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	case LDTP_CMD_UNCHECK:
-		error =  uncheck_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
+		error = uncheck_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
+		break;
+	case LDTP_CMD_STATEENABLED:
+		if (is_check_box_enabled (cctxt->gui_handle->handle))
+			error = LDTP_ERROR_SUCCESS;
+		else
+			error = LDTP_ERROR_CHECK_BOX_STATE_NOT_ENABLED;
 		break;
 	case LDTP_CMD_CLICK:
-		error =  click (cctxt->gui_handle->handle, cctxt->log_fp);
+		error = click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	case LDTP_CMD_VERIFYCHECK:
-		error =  verify_check_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
+		error = verify_check_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	case LDTP_CMD_VERIFYUNCHECK:
-		error =  verify_uncheck_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
+		error = verify_uncheck_check_box (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	default:
-		error =  LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
