@@ -30,6 +30,24 @@
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
+static LDTPErrorCode
+is_menu_item_enabled (Accessible *object, FILE *log_fp)
+{
+	SPIBoolean enabled;
+	AccessibleStateSet *state;
+
+	state = Accessible_getStateSet (object);
+	enabled = AccessibleStateSet_contains (state, SPI_STATE_ENABLED);
+	if (enabled) 
+		return LDTP_ERROR_SUCCESS;
+	else {
+		LDTPErrorCode error;
+		error = LDTP_ERROR_MENU_ITEM_STATE_DISABLED;
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+		return error;
+	}
+}
+
 /*
   Get the state of given object
 */
@@ -59,7 +77,7 @@ click (Accessible *object, FILE *log_fp)
 	AccessibleAction *action;
 	
 	if (wait_till_object_state_contains (object, CHECK_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -68,9 +86,9 @@ click (Accessible *object, FILE *log_fp)
 	flag = AccessibleAction_doAction (action, 0);
 	Accessible_unref (action);
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_CLICK_FAILED);
+		return LDTP_ERROR_CLICK_FAILED;
 }
 
 static LDTPErrorCode
@@ -80,7 +98,7 @@ check_check_menu_item (Accessible *object, FILE *log_fp)
 	AccessibleAction *action;
 
 	if (wait_till_object_state_contains (object, CHECK_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -94,16 +112,16 @@ check_check_menu_item (Accessible *object, FILE *log_fp)
 		flag = AccessibleAction_doAction (action, 0); //check
 		Accessible_unref (action);
 		if (flag)
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		else {
-			error =  (LDTP_ERROR_CHECK_ACTION_FAILED);
+			error = LDTP_ERROR_CHECK_ACTION_FAILED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
 	}
 	else
 		log_msg (LDTP_LOG_WARNING, "Check Menu Item is already checked", log_fp);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -113,7 +131,7 @@ uncheck_check_menu_item (Accessible *object, FILE *log_fp)
 	AccessibleAction *action;
 
 	if (wait_till_object_state_contains (object, CHECK_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -124,34 +142,34 @@ uncheck_check_menu_item (Accessible *object, FILE *log_fp)
 		flag = AccessibleAction_doAction (action, 0); //uncheck
 		Accessible_unref (action); 
 		if (flag)
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		else {
-			error =  (LDTP_ERROR_UNCHECK_ACTION_FAILED);
+			error = LDTP_ERROR_UNCHECK_ACTION_FAILED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
 	}
 	else
 		log_msg (LDTP_LOG_WARNING, "Check Menu Item is not checked", log_fp);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
 verify_menu_check (Accessible *object)
 {
 	if (get_check_menu_state (object))
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_STATE_UNCHECKED);
+		return LDTP_ERROR_STATE_UNCHECKED;
 }
 
 static LDTPErrorCode
 verify_menu_uncheck (Accessible *object)
 {
 	if (get_check_menu_state (object) == FALSE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_STATE_CHECKED);
+		return LDTP_ERROR_STATE_CHECKED;
 }
 
 LDTPErrorCode
@@ -168,6 +186,9 @@ check_menu_item_main (LDTPClientContext* cctxt, int command)
 	case LDTP_CMD_CLICK:
 		error = click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
+	case LDTP_CMD_MENUITEMENABLED:
+		error = is_menu_item_enabled (cctxt->gui_handle->handle, cctxt->log_fp);
+		break;
 	case LDTP_CMD_SELECTMENUITEM:
 		error = click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
@@ -178,8 +199,7 @@ check_menu_item_main (LDTPClientContext* cctxt, int command)
 		error = verify_menu_uncheck (cctxt->gui_handle->handle);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
