@@ -62,7 +62,7 @@ register_window_creation_event (LDTPClientContext* cctxt, LDTPErrorCode* err)
 		*err = LDTP_ERROR_ARGUMENT_NULL;
 
 	if (!event_notifier)
-		event_notifier = g_hash_table_new (&g_str_hash, &g_str_equal);
+		event_notifier = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, NULL);
 
 	g_hash_table_insert (event_notifier, g_strdup ((gchar *)cctxt->req->context), cctxt);
 	*err = LDTP_ERROR_SUCCESS;
@@ -368,33 +368,37 @@ static void
 add_matching_item_to_list (gpointer key, gpointer value, gpointer list)
 {
 	MatchingList *list_item = list;
-	gchar *tmp = NULL;
-	gchar *data = NULL;
+	gchar *tmp   = NULL;
+	gchar *data  = NULL;
 	gchar *label = NULL;
+	gchar *tmp_label = NULL;
 	gchar *escaped_xml_data = NULL;
         if (!key || !value || !list)
                 return;
 	data = list_item->data;
-	if (ldtp_debug)
-		g_print ("key: %s\n", (gchar *) key);
+	if (ldtp_debug && data)
+		g_print ("key: %s - %s\n", (gchar *) key, data);
 	/*
-	  list_item->role == NULL, let us add all of the entries to the list
+	  list_item->role == NULL ? then, let us add all of the entries to the list
 	*/
 	if (list_item->role == NULL || g_hash_table_find (value, is_role_matching, list_item->role)) {
 		label = get_property (value, "label_by", NULL);
 		if (!label)
 			label = get_property (value, "label", NULL);
-		if (!label)
-			escaped_xml_data = escape_xml_character (key);
-		else {
+		if (!label) {
+			tmp_label = g_strdup (key);
+		} else {
 			if (g_utf8_strchr (label, -1, '_')) {
 				tmp = escape_character (label, '_');
-				escaped_xml_data = escape_xml_character (tmp);
+				tmp_label = g_strdup (tmp);
 				g_free (tmp);
-			} else
-				escaped_xml_data = escape_xml_character (label);
+			} else {
+				tmp_label = g_strdup (label);
+			}
 		}
-		if (list_item->name && g_utf8_collate (label, list_item->name) != 0)
+		if (list_item->name && tmp_label &&
+		    (g_utf8_collate (tmp_label, list_item->name) != 0 ||
+		     g_pattern_match_simple (list_item->name, tmp_label) == FALSE)) {
 			/*
 			  If name is not NULL and its label doesn't match, name, then
 			  let us not include in the list
@@ -402,13 +406,20 @@ add_matching_item_to_list (gpointer key, gpointer value, gpointer list)
 			  name = Find, role = push_button in gedit application, just get,
 			  the label is Find and role type is push_button.
 			*/
+			if (tmp_label)
+				g_free (tmp_label);
 			return;
+		}
+		if (tmp_label) {
+			g_free (tmp_label);
+			tmp_label = NULL;
+		}
+		escaped_xml_data = escape_xml_character (key);
 		if (data) {
 			tmp = g_strdup_printf ("%s<OBJECT>%s</OBJECT>", data, escaped_xml_data);
 			g_free (data);
 			data = tmp;
-		}
-		else
+		} else
 			data = g_strdup_printf ("<OBJECT>%s</OBJECT>", escaped_xml_data);
 		g_free (escaped_xml_data);
 		list_item->data = data;
@@ -683,6 +694,33 @@ remove_app_list_table (gpointer key, gpointer value, gpointer user_data)
 	return TRUE;
 }
 
+static void
+update_context_name (LDTPClientContext* cctxt)
+{
+	char *window_name = NULL;
+	gboolean flag = FALSE;
+	if (!cctxt)
+		return;
+	if (cctxt->req && cctxt->req->context) {
+		Accessible *context_handle = NULL;
+		context_handle = get_window_handle (NULL, cctxt->req->context, &window_name, &flag);
+		if (context_handle) {
+			char *name = Accessible_getName (context_handle);
+
+			if (name) {
+				if (g_utf8_collate (name, "")) {
+					g_free (cctxt->req->context);
+					cctxt->req->context = g_strdup (name);
+				}
+				SPI_freeString (name);
+			}
+			Accessible_unref (context_handle);
+		}
+	}
+	if (window_name)
+		g_free (window_name);
+}
+
 static void
 handle_request (LDTPClientContext* cctxt, 
 		Packet* pckt, LDTPErrorCode* err)
@@ -706,7 +744,6 @@ handle_request (LDTPClientContext* cctxt,
 		*err = LDTP_ERROR_INVALID_COMMAND;
 		return;
 	}
-	sleep (1);
 	switch (ldtp_req->command) {
 	case LDTP_CMD_SETLOCALE:
 		if (cctxt->locale_lang)
@@ -889,6 +926,7 @@ handle_request (LDTPClientContext* cctxt,
 	}
 
 	case LDTP_CMD_GUIEXIST:
+		update_context_name (cctxt);
 		ldtp_gui_gui_exist (cctxt, err);
 		return;
 
@@ -913,14 +951,17 @@ handle_request (LDTPClientContext* cctxt,
 		return;
 
 	case LDTP_CMD_WAITTILLGUIEXIST:
+		update_context_name (cctxt);
 		ldtp_gui_wait_till_gui_exist (cctxt, err);
 		return;
 
 	case LDTP_CMD_WAITTILLGUINOTEXIST:
+		update_context_name (cctxt);
 		ldtp_gui_wait_till_gui_not_exist (cctxt, err);
 		return;
 
 	case LDTP_CMD_DOESMENUITEMEXIST:
+	case LDTP_CMD_MENUITEMENABLED:
 	case LDTP_CMD_MENUCHECK:
 	case LDTP_CMD_MENUUNCHECK:
 	case LDTP_CMD_VERIFYMENUCHECK:
@@ -928,40 +969,13 @@ handle_request (LDTPClientContext* cctxt,
 	case LDTP_CMD_SELECTMENUITEM:
 		if (g_utf8_strchr (ldtp_req->component, -1, ';')) {
 			gchar **token = NULL;
-			token = g_strsplit (ldtp_req->component, ";", 2);
+			token = g_strsplit (ldtp_req->component, ";", 2); // If 1 is specified to 3rd arg, the result is not correct
 			gchar *tmp = token [1];
 			cctxt->req->arg_list = g_slist_append (cctxt->req->arg_list, 
 							       g_strdup (tmp));
 			g_free (ldtp_req->component);
 			ldtp_req->component = g_strdup (token [0]);
 			g_strfreev (token);
-
-			/*
-			char *token = NULL;
-			char *rest_token = NULL;
-			char *rest_params = NULL;
-
-			token = strtok (g_strdup ((gchar *)ldtp_req->component), ";");
-			if (!token)
-				break;
-			
-			g_free (ldtp_req->component);
-			ldtp_req->component = g_strdup (token);
-			rest_token = strtok (NULL, ";");
-			while (rest_token) {
-				if (!rest_params)
-					rest_params  = g_strdup (rest_token);
-				else {
-					rest_params = g_strconcat (rest_params,
-								   ";",
-								   rest_token,
-								   NULL);
-				}
-				rest_token = strtok (NULL, ";");
-			}
-			cctxt->req->arg_list = g_slist_append (cctxt->req->arg_list, 
-							       rest_params);
-			*/
 		}
 		break;
 
@@ -1021,7 +1035,8 @@ handle_request (LDTPClientContext* cctxt,
 				g_print ("%s\n", ldtp_error_get_message (*err));
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
 			}
-			g_hash_table_foreach_remove (table, remove_app_list_table, NULL);
+			//g_hash_table_foreach_remove (table, remove_app_list_table, NULL);
+			g_hash_table_destroy (table);
 		}
 		else {
 			*err = LDTP_ERROR_UNABLE_TO_GET_APPLICATION_LIST;
@@ -1077,6 +1092,7 @@ handle_request (LDTPClientContext* cctxt,
 		char *data = NULL;
 		GHashTable *ht = NULL;
 
+		update_context_name (cctxt);
 		if (!cctxt->req->context) {
 			*err = LDTP_ERROR_ARGUMENT_NULL;
 			g_print ("%s\n", ldtp_error_get_message (*err));
@@ -1092,11 +1108,11 @@ handle_request (LDTPClientContext* cctxt,
                                 return;
                         }
 		}
-		ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+		ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 		if (!ht) {
 			update_cur_window_appmap_handle (cctxt,
 							 err);
-			ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+			ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 			if (*err != LDTP_ERROR_SUCCESS) {
 				g_print ("Unable to update context: %s in appmap", (char *)cctxt->req->context);
 				return;
@@ -1138,15 +1154,18 @@ handle_request (LDTPClientContext* cctxt,
 	}
 	case LDTP_CMD_GETCHILD: {
 		char *data = NULL;
-		char *name = cctxt->req->component;
+		char *name = g_strdup (cctxt->req->component);
 		char *role = NULL;
 		MatchingList list;
 		GHashTable *context_ht = NULL;
 
+		update_context_name (cctxt);
 		if (!cctxt->req->context) {
 			*err = LDTP_ERROR_ARGUMENT_NULL;
 			g_print ("%s %s %d\n", ldtp_error_get_message (*err), __FILE__, __LINE__);
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+			if (name)
+				g_free (name);
 			return;
 		}
 		if (!cctxt->app_map) {
@@ -1155,16 +1174,20 @@ handle_request (LDTPClientContext* cctxt,
                         ldtp_gui_free_gui_handle (accessible);
                         if (*err != LDTP_ERROR_SUCCESS) {
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+				if (name)
+					g_free (name);
                                 return;
                         }
 		}
-		context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+		context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 		if (!context_ht) {
 			update_cur_window_appmap_handle (cctxt,
 							 err);
-			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 			if (*err != LDTP_ERROR_SUCCESS) {
 				g_print ("Unable to update context: %s in appmap", (char *)cctxt->req->context);
+				if (name)
+					g_free (name);
 				return;
 			}
 		}
@@ -1173,6 +1196,8 @@ handle_request (LDTPClientContext* cctxt,
 			*err = LDTP_ERROR_UNABLE_TO_GET_CONTEXT_HANDLE;
 			g_print ("%s\n", ldtp_error_get_message (*err));
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+			if (name)
+				g_free (name);
 			return;
 		}
 		role = g_slist_nth_data (cctxt->req->arg_list, 0);
@@ -1194,19 +1219,19 @@ handle_request (LDTPClientContext* cctxt,
 				if (ldtp_debug)
 					g_print ("LIST: %s\n", tmp);
 				cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
-			}
-			else {
+			} else {
 				g_free (cctxt->resp->data);
 				*err = LDTP_ERROR_UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE;
 				g_print ("%s\n", ldtp_error_get_message (*err));
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
 			}
-		}
-		else {
+		} else {
 			*err = LDTP_ERROR_UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE;
 			g_print ("%s\n", ldtp_error_get_message (*err));
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
 		}
+		if (name)
+			g_free (name);
 		return;
 	}
 	case LDTP_CMD_GETOBJECTINFO: {
@@ -1214,6 +1239,7 @@ handle_request (LDTPClientContext* cctxt,
 		GHashTable *context_ht = NULL;
 		GHashTable *component_ht = NULL;
 
+		update_context_name (cctxt);
 		if (!cctxt->req->context || !cctxt->req->component) {
 			*err = LDTP_ERROR_ARGUMENT_NULL;
 			g_print ("%s\n", ldtp_error_get_message (*err));
@@ -1229,11 +1255,11 @@ handle_request (LDTPClientContext* cctxt,
                                 return;
                         }
 		}
-		context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+		context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 		if (!context_ht) {
 			update_cur_window_appmap_handle (cctxt,
 							 err);
-			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 			if (*err != LDTP_ERROR_SUCCESS) {
 				g_print ("Unable to update context: %s in appmap", (char *)cctxt->req->context);
 				return;
@@ -1246,15 +1272,15 @@ handle_request (LDTPClientContext* cctxt,
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
 			return;
 		}
-		component_ht = get_object_def (context_ht, (char *)cctxt->req->component, cctxt->log_fp, FALSE);
+		component_ht = get_object_def (context_ht, (char *)cctxt->req->component, NULL, cctxt->log_fp, FALSE);
 		if (!component_ht) {
 			update_cur_window_appmap_handle (cctxt,
 							 err);
 			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context,
-						     cctxt->log_fp, TRUE);
+						     NULL, cctxt->log_fp, TRUE);
 			if (context_ht)
 				component_ht = get_object_def (context_ht, (char *)cctxt->req->component,
-							       cctxt->log_fp, FALSE);
+							       NULL, cctxt->log_fp, FALSE);
 			if (!component_ht) {
 				g_print ("Unable to find component\n");
 				*err = LDTP_ERROR_UNABLE_TO_GET_COMPONENT_HANDLE;
@@ -1297,6 +1323,7 @@ handle_request (LDTPClientContext* cctxt,
 		GHashTable *context_ht = NULL;
 		GHashTable *component_ht = NULL;
 
+		update_context_name (cctxt);
 		if (!cctxt->req->context || !cctxt->req->component) {
 			*err =  LDTP_ERROR_ARGUMENT_NULL;
 			g_print ("%s\n", ldtp_error_get_message (*err));
@@ -1312,11 +1339,11 @@ handle_request (LDTPClientContext* cctxt,
                                 return;
                         }
 		}
-		context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+		context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 		if (!context_ht) {
 			update_cur_window_appmap_handle (cctxt,
 							 err);
-			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, cctxt->log_fp, TRUE);
+			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 			if (*err != LDTP_ERROR_SUCCESS) {
 				g_print ("Unable to update context: %s in appmap", (char *)cctxt->req->context);
 				return;
@@ -1330,15 +1357,15 @@ handle_request (LDTPClientContext* cctxt,
 			return;
 		}
 		component_ht = get_object_def (context_ht, (char *)cctxt->req->component,
-					       cctxt->log_fp, FALSE);
+					       NULL, cctxt->log_fp, FALSE);
 		if (!component_ht) {
 			update_cur_window_appmap_handle (cctxt,
 							 err);
 			context_ht = get_object_def (cctxt->app_map, (char *)cctxt->req->context,
-						     cctxt->log_fp, TRUE);
+						     NULL, cctxt->log_fp, TRUE);
 			if (context_ht)
 				component_ht = get_object_def (context_ht, (char *)cctxt->req->component,
-							       cctxt->log_fp, TRUE);
+							       NULL, cctxt->log_fp, TRUE);
 			if (!component_ht) {
 				g_print ("Unable to find component\n");
 				*err = LDTP_ERROR_UNABLE_TO_GET_COMPONENT_HANDLE;
@@ -1362,6 +1389,7 @@ handle_request (LDTPClientContext* cctxt,
 	}
 	}
 
+	update_context_name (cctxt);
 	/* 
 	   1)  Get the Accessible object corresponding to "component-name".
 	   2)  Get the class-id and
@@ -1391,6 +1419,7 @@ handle_request (LDTPClientContext* cctxt,
 		return;
 	}
 
+	//sleep (1);
 	switch (cctxt->gui_handle->class_id) {
 	case SPI_ROLE_COMBO_BOX:
 		*err = combo_box_main (cctxt, cctxt->req->command);
@@ -1528,7 +1557,7 @@ handle_request (LDTPClientContext* cctxt,
 			break;
 		}
 		*err = LDTP_ERROR_ROLE_NOT_IMPLEMENTED;
-		g_print ("Role not implemented: %s %d", __FILE__, __LINE__);
+		g_print ("Role not implemented: %s %d\n", __FILE__, __LINE__);
 		break;
 	}
 
@@ -1542,7 +1571,7 @@ handle_request (LDTPClientContext* cctxt,
 void *
 handle_client (void *ptr)
 {
-	int* sock_fd = (int *)ptr;
+	int sock_fd = ptr;
 	char* packet = NULL;
 	char* tmpptr = NULL;
 	uint32_t packet_len;
@@ -1565,13 +1594,13 @@ handle_client (void *ptr)
 	ldtp_request_init (cctxt->req);
 	cctxt->resp = g_new0 (LDTPResponse, 1);
 	cctxt->resp->data = NULL;
-	cctxt->sock_fd = *sock_fd;
+	cctxt->sock_fd = sock_fd;
 	cctxt->log_fp = NULL;
 	cctxt->locale_set = FALSE;
 
 	while (1) {
 		packet_len = 0;
-		ldtp_read_sizet (*sock_fd, &packet_len, &status);
+		ldtp_read_sizet (sock_fd, &packet_len, &status);
 		if (status != LDTP_ERROR_SUCCESS) {
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (status), cctxt->log_fp);
 			goto error;
@@ -1594,7 +1623,7 @@ handle_client (void *ptr)
 		while (pckt_len > 0) {
 			g_print ("i = %d\n", i);
 			pckt_len = pckt_len > 512 ? 512 : pckt_len;
-			ldtp_read_data (*sock_fd, packet, pckt_len, 
+			ldtp_read_data (sock_fd, packet, pckt_len, 
 					&bytes_read, &status);
 			if (status != LDTP_ERROR_SUCCESS) {
 				/*
@@ -1620,7 +1649,7 @@ handle_client (void *ptr)
 		packet = tmpptr;
 
 		if (packet)
-			g_print ("Received packet [%s] through %d\n", packet, *sock_fd);
+			g_print ("Received packet [%s] through %d\n", packet, sock_fd);
 
 		pckt = g_new0 (Packet, 1);
 		pckt->packet = packet;
@@ -1659,11 +1688,25 @@ handle_client (void *ptr)
 			g_free (cctxt->resp->data);
 			cctxt->resp->data = NULL;
 		}
+		if (cctxt->parent_name) {
+			g_free (cctxt->parent_name);
+			cctxt->parent_name = NULL;
+		}
 		cctxt->resp->data_len = 0;
+		if (cctxt->req)
+			ldtp_request_free (cctxt->req, 0);
+		if (cctxt->window_name) {
+			g_free (cctxt->window_name);
+			cctxt->window_name = NULL;
+		}
 	}
  error:
 	g_print ("handle_client: error:\n");
 	cctxt->resp->resp_status = status;
+	if (cctxt->parent_name) {
+		g_free (cctxt->parent_name);
+		cctxt->parent_name = NULL;
+	}
 	if (cctxt->window_name) {
 		g_free (cctxt->window_name);
 		cctxt->window_name = NULL;
@@ -1688,14 +1731,13 @@ handle_client (void *ptr)
 	pthread_mutex_lock (&cb_mutex);
 	unregister_window_creation_event (cctxt, &status);
 
-	close_connection (*sock_fd);
+	if (cctxt && cctxt->req)
+		ldtp_request_free (cctxt->req, 0);
+	close_connection (sock_fd);
 
 	if (packet)
 		g_free (packet);
 
-	if (sock_fd)
-		g_free (sock_fd);
-
 	if (pckt)
 		g_free (pckt);
 	if (cctxt->app_handle) {
@@ -1712,7 +1754,7 @@ handle_client (void *ptr)
 		g_print ("Removed %d entries from client context hash table\n", count);
 	}
 
-	ldtp_appmap_free (cctxt->app_map);
+	//ldtp_appmap_free (cctxt->app_map);
 	if (cctxt && cctxt->resp)
 		status = cctxt->resp->resp_status;
 	else
