@@ -41,15 +41,15 @@ click (Accessible *object, FILE *log_fp)
   
 	if (wait_till_object_state_contains (object, COMBO_BOX, log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", log_fp);
-		return  (LDTP_ERROR_CLICK_FAILED);
+		return LDTP_ERROR_CLICK_FAILED;
 	}
 	action = Accessible_getAction (object);
 	flag = AccessibleAction_doAction (action, 0);
 	Accessible_unref (action);
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_CLICK_FAILED);
+		return LDTP_ERROR_CLICK_FAILED;
 }
 
 static gboolean 
@@ -78,7 +78,7 @@ hide_list (Accessible *object, FILE *log_fp)
 
 	if (wait_till_object_state_contains (object, COMBO_BOX, log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", log_fp);
-		return  (LDTP_ERROR_HIDELIST_FAILED);
+		return LDTP_ERROR_HIDELIST_FAILED;
 	}
 
         type = get_child_object_type (object);
@@ -90,7 +90,7 @@ hide_list (Accessible *object, FILE *log_fp)
 			*/
                         log_msg (LDTP_LOG_WARNING, "List already in hidden state", log_fp);
                         Accessible_unref (hide_object);
-                        return  (LDTP_ERROR_SUCCESS);
+                        return LDTP_ERROR_SUCCESS;
                 }
 
                 action = Accessible_getAction (hide_object);
@@ -107,7 +107,7 @@ hide_list (Accessible *object, FILE *log_fp)
 			*/
                         log_msg (LDTP_LOG_WARNING, "Menu already in hidden state", log_fp);
                         Accessible_unref (hide_object);
-                        return  (LDTP_ERROR_SUCCESS);
+                        return LDTP_ERROR_SUCCESS;
                 }
 
                 action = Accessible_getAction (object);
@@ -118,9 +118,9 @@ hide_list (Accessible *object, FILE *log_fp)
                 Accessible_unref (hide_object);
         }
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_HIDELIST_FAILED);
+		return LDTP_ERROR_HIDELIST_FAILED;
 }	
 
 static LDTPErrorCode
@@ -134,7 +134,7 @@ show_list (Accessible *object, FILE *log_fp)
 	if (wait_till_object_state_contains (object, COMBO_BOX, log_fp) != 0) {
 		g_print ("Not all combo box object properties enabled\n");
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", log_fp);
-		return  (LDTP_ERROR_SHOWLIST_FAILED);
+		return LDTP_ERROR_SHOWLIST_FAILED;
 	}
 
         type = get_child_object_type (object);
@@ -147,7 +147,7 @@ show_list (Accessible *object, FILE *log_fp)
 			*/
                         log_msg (LDTP_LOG_WARNING, "List already in visible state", log_fp);
                         Accessible_unref (show_object);
-                        return  (LDTP_ERROR_SUCCESS);
+                        return LDTP_ERROR_SUCCESS;
                 }
                 action = Accessible_getAction (show_object);
 		if (action) {
@@ -165,7 +165,7 @@ show_list (Accessible *object, FILE *log_fp)
 			*/
                         log_msg (LDTP_LOG_WARNING, "Menu already in visible state", log_fp);
                         Accessible_unref (show_object);
-                        return  (LDTP_ERROR_SUCCESS);
+                        return LDTP_ERROR_SUCCESS;
                 }
                 action = Accessible_getAction (object);
                 if (action) {
@@ -176,9 +176,9 @@ show_list (Accessible *object, FILE *log_fp)
        }
 	g_print ("Flag: %d\n", flag);
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_SHOWLIST_FAILED);
+		return LDTP_ERROR_SHOWLIST_FAILED;
 }
 
 static LDTPErrorCode
@@ -196,7 +196,7 @@ select_item (LDTPClientContext* cctxt)
 	if (wait_till_object_state_contains (object, COMBO_BOX, cctxt->log_fp) != 0) {
 		g_print ("Not all combo box object properties enabled\n");
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", cctxt->log_fp);
-		return  (LDTP_ERROR_SELECTITEM_FAILED);
+		return LDTP_ERROR_SELECTITEM_FAILED;
 	}
   
 	type = get_child_object_type (object);
@@ -211,7 +211,7 @@ select_item (LDTPClientContext* cctxt)
 			if (error != LDTP_ERROR_SUCCESS) {
 				g_print ("Combo box SelectItem action failed\n");
 				log_msg (LDTP_LOG_CAUSE, "Combo box SelectItem action failed", cctxt->log_fp);
-				return  (LDTP_ERROR_SELECTITEM_FAILED);
+				return LDTP_ERROR_SELECTITEM_FAILED;
 			}
 		}
 		text = get_text_handle (object);
@@ -221,18 +221,18 @@ select_item (LDTPClientContext* cctxt)
 			Accessible_unref (text);
 			cctxt->gui_handle->handle = object;
 			if (error == LDTP_ERROR_SUCCESS)
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 		}
 		g_print ("Combo box select verify action failed\n");
 		log_msg (LDTP_LOG_CAUSE, "Combo box select verify action failed", cctxt->log_fp);
-		return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+		return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 	} else if (type == SPI_ROLE_MENU) {
 		menu_object = get_menu_handle (object);
 		if (menu_object == NULL) {
 			g_sprintf (msg, "Combobox: %s item does not exist\n",
 				   (char *)cctxt->req->arg_list->data);
 			log_msg (LDTP_LOG_CAUSE, msg, cctxt->log_fp);
-			return  (LDTP_ERROR_ITEM_NOT_FOUND);
+			return LDTP_ERROR_ITEM_NOT_FOUND;
 		}
 		count = Accessible_getChildCount (menu_object);
 		for (i = 0; i < count; i++) {
@@ -260,9 +260,9 @@ select_item (LDTPClientContext* cctxt)
 					if (error != LDTP_ERROR_SUCCESS) {
 						g_print ("Combo Box: SelectItem action failed\n");
 						log_msg (LDTP_LOG_CAUSE, "Combo Box: SelectItem action failed", cctxt->log_fp);
-						return  (LDTP_ERROR_SELECTITEM_FAILED);
+						return LDTP_ERROR_SELECTITEM_FAILED;
 					} else {
-						return  (LDTP_ERROR_SUCCESS);
+						return LDTP_ERROR_SUCCESS;
 					}
 				}
 				g_free (tmp);
@@ -275,11 +275,11 @@ select_item (LDTPClientContext* cctxt)
 		g_sprintf (msg, "Combobox: %s item does not exist\n",
 			   (char *)cctxt->req->arg_list->data);
 		log_msg (LDTP_LOG_CAUSE, msg, cctxt->log_fp);
-		return  (LDTP_ERROR_ITEM_NOT_FOUND);
+		return LDTP_ERROR_ITEM_NOT_FOUND;
 	}
 	g_print ("Verify combo box click child type is unidentified\n");
 	log_msg (LDTP_LOG_CAUSE, "Verify combo box click child type is unidentified", cctxt->log_fp);
-	return  (LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED);
+	return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 }
 
 static LDTPErrorCode 
@@ -299,11 +299,11 @@ capture_to_file (Accessible *object, char *file_name, FILE *log_fp)
 		fp = fopen ("comboboxitem.lst", "w");
 	if (fp == NULL) {
 		log_msg (LDTP_LOG_CAUSE, "Combo box: Cannot open output file", log_fp);
-		return  (LDTP_ERROR_FILECAPTURE_FAILED_OPEN_OUTPUT_FILE);
+		return LDTP_ERROR_FILECAPTURE_FAILED_OPEN_OUTPUT_FILE;
 	}
 	if (wait_till_object_state_contains (object, COMBO_BOX, log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Combo Box: SelectItem action failed", log_fp);
-		return  (LDTP_ERROR_SELECTITEM_FAILED);
+		return LDTP_ERROR_SELECTITEM_FAILED;
 	}
   
 	type = get_child_object_type (object);
@@ -324,8 +324,7 @@ capture_to_file (Accessible *object, char *file_name, FILE *log_fp)
 			}
 		}
 		Accessible_unref (child);
-	}
-	else if (type == SPI_ROLE_MENU) {
+	} else if (type == SPI_ROLE_MENU) {
 		menu_object = get_menu_handle (object);
 		if (menu_object) {
 			count = Accessible_getChildCount (menu_object);
@@ -343,14 +342,13 @@ capture_to_file (Accessible *object, char *file_name, FILE *log_fp)
 				Accessible_unref (menu_object);
 			}
 		}
-	}
-	else {
+	} else {
 		fclose (fp);
 		log_msg (LDTP_LOG_CAUSE, "Verify combo box click child type is unidentified", log_fp);
-		return  (LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED);
+		return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 	}
 	fclose (fp);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -362,7 +360,7 @@ select_index (LDTPClientContext* cctxt)
 
 	if (wait_till_object_state_contains (object, COMBO_BOX, cctxt->log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", cctxt->log_fp);
-		return  (LDTP_ERROR_SELECTINDEX_FAILED);
+		return LDTP_ERROR_SELECTINDEX_FAILED;
 	}
 
 	child = get_list_handle (object);
@@ -373,17 +371,16 @@ select_index (LDTPClientContext* cctxt)
 		cctxt->gui_handle->handle = object;
 		if (error != LDTP_ERROR_SUCCESS) {
 			log_msg (LDTP_LOG_CAUSE, "Combo Box: SelectIndex action failed", cctxt->log_fp);
-			error =  (LDTP_ERROR_SELECTINDEX_FAILED);
+			error = LDTP_ERROR_SELECTINDEX_FAILED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 			return error;
 		}
-	}
-	else {
-		error =  (LDTP_ERROR_SELECTINDEX_FAILED);
+	} else {
+		error = LDTP_ERROR_SELECTINDEX_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -395,16 +392,16 @@ set_text_value (LDTPClientContext* cctxt)
 
 	if (wait_till_object_state_contains (object, COMBO_BOX, cctxt->log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", cctxt->log_fp);
-		return  (LDTP_ERROR_SETTEXTVALUE_FAILED);
+		return LDTP_ERROR_SETTEXTVALUE_FAILED;
 	}
 	if (!cctxt->req->arg_list->data) {
-		error =  (LDTP_ERROR_SETTEXTVALUE_FAILED);
+		error = LDTP_ERROR_SETTEXTVALUE_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		return error;
 	}
 	text_obj = get_text_handle (object);
 	if (!text_obj) {
-		error =  (LDTP_ERROR_SETTEXTVALUE_FAILED);
+		error = LDTP_ERROR_SETTEXTVALUE_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		return error;
 	}
@@ -414,18 +411,18 @@ set_text_value (LDTPClientContext* cctxt)
 		Accessible_unref (text_obj);
 		cctxt->gui_handle->handle = object;
 		log_msg (LDTP_LOG_CAUSE, "Combo Box: SetTextValue action failed during setting", cctxt->log_fp);
-		return  (LDTP_ERROR_SETTEXTVALUE_FAILED);
+		return LDTP_ERROR_SETTEXTVALUE_FAILED;
 	}
 	error = text_main (cctxt, LDTP_CMD_VERIFYSETTEXT);
 	if (error != LDTP_ERROR_SUCCESS) {
 		Accessible_unref (text_obj);
 		cctxt->gui_handle->handle = object;
 		log_msg (LDTP_LOG_CAUSE, "Combo Box: SetTextValue verify action failed during verifying", cctxt->log_fp);
-		return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+		return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 	}
 	Accessible_unref (text_obj);
 	cctxt->gui_handle->handle = object;
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -438,10 +435,7 @@ verify_drop_down (Accessible *object, FILE *log_fp)
   
 	if (wait_till_object_state_contains (object, COMBO_BOX, log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", log_fp);
-		/* Varadhan
-		   is it so?
-		*/
-		return  (LDTP_ERROR_CLICK_FAILED);
+		return LDTP_ERROR_CLICK_FAILED;
 	}
 
 	child_type = get_child_object_type (object);
@@ -453,10 +447,10 @@ verify_drop_down (Accessible *object, FILE *log_fp)
 			Accessible_unref (child_object);
 			if (focused == 0) {
 				log_msg (LDTP_LOG_CAUSE, "Verify Combo box list child is not focused", log_fp);
-				return  (LDTP_ERROR_CHILD_NOT_FOCUSSED);
+				return LDTP_ERROR_CHILD_NOT_FOCUSSED;
 			}
 			else
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 		}
 	}
 	else if (child_type == SPI_ROLE_MENU) {
@@ -468,17 +462,17 @@ verify_drop_down (Accessible *object, FILE *log_fp)
 			Accessible_unref (child_object);
 			if ((showing == 0) && (visible == 0)) {
 				log_msg (LDTP_LOG_CAUSE, "Verify combo box menu child is not showing", log_fp);
-				return  (LDTP_ERROR_MENU_NOT_VISIBLE);
+				return LDTP_ERROR_MENU_NOT_VISIBLE;
 			}
 			else
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 		}
 	}
 	else {	  
 		log_msg (LDTP_LOG_CAUSE, "Verify combo box click child type is unidentified", log_fp);
-		return  (LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED);
+		return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 	}
-	return  (LDTP_ERROR_VERIFY_DROPDOWN_FAILED);
+	return LDTP_ERROR_VERIFY_DROPDOWN_FAILED;
 }
 
 static LDTPErrorCode
@@ -493,7 +487,7 @@ verify_hide_list (Accessible *object, FILE *log_fp)
   
 	if (wait_till_object_state_contains (object, COMBO_BOX, log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", log_fp);
-		return  (LDTP_ERROR_CLICK_FAILED);
+		return LDTP_ERROR_CLICK_FAILED;
 	}
 
 	child_type = get_child_object_type (object);
@@ -505,9 +499,9 @@ verify_hide_list (Accessible *object, FILE *log_fp)
 			Accessible_unref (child_object);
 			if (focused == TRUE) {
 				log_msg (LDTP_LOG_CAUSE, "Verify Combo box list child is focused", log_fp);
-				return  (LDTP_ERROR_CHILD_IN_FOCUS);
+				return LDTP_ERROR_CHILD_IN_FOCUS;
 			}
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		}
 	}
 	else if (child_type == SPI_ROLE_MENU) {
@@ -522,13 +516,13 @@ verify_hide_list (Accessible *object, FILE *log_fp)
 				   Are we checking for visibility or invisibility?
 				*/
 				log_msg (LDTP_LOG_CAUSE, "Verify combo box menu child is showing & visible", log_fp);
-				return  (LDTP_ERROR_MENU_VISIBLE);
+				return LDTP_ERROR_MENU_VISIBLE;
 			}
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		}
 	}
 	log_msg (LDTP_LOG_CAUSE, "Verify combo box hidelist child type is unidentified", log_fp);
-	return  (LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED);
+	return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 }
 
 static LDTPErrorCode 
@@ -536,10 +530,10 @@ verify_show_list (Accessible *object, FILE *log_fp)
 {
 	if (verify_drop_down (object, log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Verify combo box showlist action failed", log_fp);
-		return  (LDTP_ERROR_VERIFY_SHOWLIST_FAILED);
+		return LDTP_ERROR_VERIFY_SHOWLIST_FAILED;
 	}
 	else
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 }	    	 
 
 static LDTPErrorCode
@@ -555,7 +549,7 @@ verify_set_text_value (LDTPClientContext* cctxt)
 		if (wait_till_object_state_contains (object, COMBO_BOX, cctxt->log_fp) != 0) {
 			g_print ("Verify Combo box SetTextValue action failed\n");
 			log_msg (LDTP_LOG_CAUSE, "Verify Combo box SetTextValue action failed", cctxt->log_fp);
-			return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+			return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 		}
 		text_object = get_text_handle (object);
 		if (text_object) {
@@ -566,14 +560,14 @@ verify_set_text_value (LDTPClientContext* cctxt)
 			if (error != LDTP_ERROR_SUCCESS) {
 				g_print ("Verify Combo box SetTextValue action failed\n");
 				log_msg (LDTP_LOG_CAUSE, "Verify Combo box SetTextValue action failed", cctxt->log_fp);
-				return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+				return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 			}
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		}
 		else {
 			g_print ("Verify Combo box SetTextValue child object is NULL\n");
 			log_msg (LDTP_LOG_CAUSE, "Verify Combo box SetTextValue child object is NULL", cctxt->log_fp);
-			return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+			return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 		}
 	} else if (child_type == SPI_ROLE_MENU) {
 		gboolean flag = FALSE;
@@ -587,14 +581,14 @@ verify_set_text_value (LDTPClientContext* cctxt)
 			SPI_freeString (name);
 		}
 		if (flag)
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		else {
 			g_print ("Ldtp error verify settextvalue failed\n");
-			return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+			return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 		}
 	}
 	g_print ("Object type not matched: Ldtp error verify settextvalue failed\n");
-	return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
+	return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 }
 
 static LDTPErrorCode
@@ -607,9 +601,9 @@ verify_select_item (LDTPClientContext* cctxt)
 	if (error != LDTP_ERROR_SUCCESS) {
 		g_print ("verify combo box select action failed\n");
 		log_msg (LDTP_LOG_CAUSE, "verify combo box select action failed", cctxt->log_fp);
-		return  (LDTP_ERROR_VERIFY_ITEM_FAILED);
+		return LDTP_ERROR_VERIFY_ITEM_FAILED;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -622,7 +616,7 @@ combo_select_index (LDTPClientContext* cctxt, int index)
   
 	if (wait_till_object_state_contains (object, COMBO_BOX, cctxt->log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", cctxt->log_fp);
-		return  (LDTP_ERROR_SELECTITEM_FAILED);
+		return LDTP_ERROR_SELECTITEM_FAILED;
 	}
 
 	type = get_child_object_type (object);
@@ -641,10 +635,10 @@ combo_select_index (LDTPClientContext* cctxt, int index)
 					Accessible_unref (child);
 					if (error != LDTP_ERROR_SUCCESS) {
 						log_msg (LDTP_LOG_CAUSE, "Combo Box: SelectItem action failed", cctxt->log_fp);
-						return  (LDTP_ERROR_SELECTITEM_FAILED);
+						return LDTP_ERROR_SELECTITEM_FAILED;
 					}
 					else
-						return  (LDTP_ERROR_SUCCESS);
+						return LDTP_ERROR_SUCCESS;
 				}
 			}// if
 			else
@@ -655,13 +649,13 @@ combo_select_index (LDTPClientContext* cctxt, int index)
 		   Varadhan
 		   FIXME: Item does not exist or action failed? 
 		*/
-		return  (LDTP_ERROR_SELECTITEM_FAILED);
+		return LDTP_ERROR_SELECTITEM_FAILED;
 	}
 	/* Varadhan
 	   FIXME: More specific error should be returned 
 	*/
 	log_msg (LDTP_LOG_CAUSE, "Verify combo box click child type is unidentified", cctxt->log_fp);
-	return  (LDTP_ERROR_SELECTITEM_FAILED);
+	return LDTP_ERROR_SELECTITEM_FAILED;
 }
 
 static LDTPErrorCode
@@ -676,7 +670,7 @@ get_text_value (LDTPClientContext* cctxt)
   
 	if (wait_till_object_state_contains (object, COMBO_BOX, cctxt->log_fp) != 0) {
 		log_msg (LDTP_LOG_CAUSE, "Not all combo box object properties enabled", cctxt->log_fp);
-		return  (LDTP_ERROR_GETTEXTVALUE_FAILED);
+		return LDTP_ERROR_GETTEXTVALUE_FAILED;
 	}
 
 	type = get_child_object_type (object);
@@ -710,18 +704,18 @@ get_text_value (LDTPClientContext* cctxt)
 				log_msg (LDTP_LOG_CAUSE, 
 					 "Combo box gettextvalue action failed",
 					 cctxt->log_fp);
-				return  (LDTP_ERROR_GETTEXTVALUE_FAILED);
+				return LDTP_ERROR_GETTEXTVALUE_FAILED;
 			}
 			cctxt->resp->data_len = g_utf8_strlen (cctxt->req->arg_list->data, -1);
 			cctxt->resp->data = g_strdup (cctxt->req->arg_list->data);
 			cctxt->req->arg_list = g_slist_remove (cctxt->req->arg_list->data, cctxt->resp->data);
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		}
 		else {
 			log_msg (LDTP_LOG_CAUSE, 
 				 "Combo box gettextvalue  action failed",
 				 cctxt->log_fp);
-			return  (LDTP_ERROR_GETTEXTVALUE_FAILED);
+			return LDTP_ERROR_GETTEXTVALUE_FAILED;
 		}
 	}
 	else if (type == SPI_ROLE_MENU) {
@@ -731,11 +725,11 @@ get_text_value (LDTPClientContext* cctxt)
 		cctxt->resp->data_len = AccessibleText_getCharacterCount (child);
 		SPI_freeString (item);
 		Accessible_unref (child);
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	}
 	else {
 		log_msg (LDTP_LOG_CAUSE, "Combo box child type is unidentified", cctxt->log_fp);
-		return  (LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED);
+		return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 	}
 }
 
@@ -799,8 +793,7 @@ combo_box_main (LDTPClientContext* cctxt, int command)
                 error = device_main (cctxt, command);
                 break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
