@@ -38,7 +38,7 @@ mouse_left_click (Accessible *object, FILE *log_fp)
 	AccessibleCoordType screen_cood = SPI_COORD_TYPE_SCREEN;
 	SPIBoolean flag;
 	long int xpos, ypos;
-	xpos=ypos=0;
+	xpos = ypos = 0;
 
 	if (Accessible_isComponent (object)) {
 		AccessibleComponent *accessible_component;
@@ -158,6 +158,10 @@ get_key_value (gchar *keyval)
 								  {'{', 34}, {'}', 35}, {':', 47},
 								  {'\"',48}, {'~', 49}, {'|', 51},
 								  {'<', 59}, {'>', 60}, {'\?', 61}};
+	/*
+	  PrtScrn: http://gentoo-wiki.com/TIP_Make_a_Screenshot_with_PrintScreen_Key
+	  xmodmap -pke | grep -i print
+	*/
 	static struct NonPrint_Key_Synth NonPrint_Key_Synth_Vals[] = {{"escape", 9}, {"esc", 9}, {"backspace", 22},
 								      {"bksp", 22}, {"ctrl", 37}, {"windowskey", 115},
 								      {"tab", 23}, {"return", 36}, {"enter", 36},
@@ -173,7 +177,7 @@ get_key_value (gchar *keyval)
 								      {"F1", 67}, {"F2", 68}, {"F3", 69}, {"F4", 70},
 								      {"F5", 71}, {"F6", 72}, {"F7", 73}, {"F8", 74},
 								      {"F9", 75}, {"F10", 76}, {"F11", 95}, {"F12", 96},
-								      {NULL, 0}};
+								      {"prtscrn", 111}, {NULL, 0}};
 	struct KeyValue return_val; /* will contain the return values */
 	gint index;
 
@@ -332,7 +336,6 @@ generate_keyboard_sequence (char *input_string, FILE *log_fp)
 					error = LDTP_ERROR_UNABLE_TO_ENTER_KEY;
 					goto error;
 				}
-
 			}
 			index = history_index;
 		}
