@@ -40,10 +40,10 @@ toggle (Accessible *object, FILE *log_fp)
 	flag = AccessibleAction_doAction (action, 0);
 	Accessible_unref (action);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_TOGGLE_ACTION_FAILED);
+		error = LDTP_ERROR_TOGGLE_ACTION_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -59,10 +59,10 @@ invoke_menu (Accessible *object, FILE *log_fp)
 	flag = AccessibleAction_doAction (action, 1);
 	Accessible_unref (action);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_TOGGLE_ACTION_FAILED);
+		error = LDTP_ERROR_TOGGLE_ACTION_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -84,7 +84,7 @@ embedded_component_main (LDTPClientContext* cctxt, int command)
 		error = device_main (cctxt, command);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
