@@ -73,10 +73,10 @@ right_click (Accessible *object, FILE *log_fp)
 
 	if (flag) {
 		g_print ("Right click on icon: success\n");
-		error =  (LDTP_ERROR_SUCCESS);
+		error = LDTP_ERROR_SUCCESS;
 	}
 	else {
-		error =  (LDTP_ERROR_RIGHT_CLICK_FAILED);
+		error = LDTP_ERROR_RIGHT_CLICK_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	}
 	return error;
@@ -91,8 +91,7 @@ icon_main (LDTPClientContext* cctxt, int command)
 		error = right_click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	default:
-		error = ( (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED));
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
