@@ -49,17 +49,16 @@ select_item (Accessible *object, char *item_name, FILE *log_fp)
 			if (child) {
 				name = Accessible_getName (child);
 #ifdef ENABLE_LOCALIZE
-				if (g_utf8_collate (name, _(item_name)) == 0)
+				if (g_utf8_collate (name, _(item_name)) == 0) {
 #else
-					if (g_utf8_collate (name, item_name) == 0)
+					if (g_utf8_collate (name, item_name) == 0) {
 #endif
-						{
-							flag = TRUE;
-							g_print ("Child name: %s\n", name);
-							SPI_freeString (name);
-							Accessible_unref (child);
-							break;
-						}
+						flag = TRUE;
+						g_print ("Child name: %s\n", name);
+						SPI_freeString (name);
+						Accessible_unref (child);
+						break;
+					}
 				SPI_freeString (name);
 				Accessible_unref (child);
 			}
@@ -73,9 +72,9 @@ select_item (Accessible *object, char *item_name, FILE *log_fp)
 		Accessible_unref (selection);
 		g_print ("Selected: %s\n", item_name);
 		if (flag == TRUE)
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_SELECT_LAYERED_PANE_ITEM);
+	error = LDTP_ERROR_UNABLE_TO_SELECT_LAYERED_PANE_ITEM;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -106,9 +105,9 @@ right_click (Accessible *object, FILE *log_fp)
 	flag = AccessibleAction_doAction (action, 1);
 	Accessible_unref (action);
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
-		error =  (LDTP_ERROR_RIGHT_CLICK_FAILED);
+		error = LDTP_ERROR_RIGHT_CLICK_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -121,7 +120,6 @@ layered_pane_main (LDTPClientContext* cctxt, int command)
 	switch (command) {
 	case LDTP_CMD_SELECTITEM: {
 		char *item_name = NULL;
-
 		item_name = cctxt->req->arg_list->data;
 		error = select_item (cctxt->gui_handle->handle, item_name, cctxt->log_fp);
 		break;
@@ -130,8 +128,7 @@ layered_pane_main (LDTPClientContext* cctxt, int command)
 		error = right_click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	default:
-		error = ( (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED));
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
