@@ -37,19 +37,19 @@
 extern gboolean ldtp_debug;
 static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 
-static char*
-read_delimiter (int fd, char delimit)
+static gchar*
+read_delimiter (int fd, gchar delimit)
 {
 	int len = 128;
 	int size = 0;
-	char ch;
-	char *data = NULL;
+	gchar ch;
+	gchar *data = NULL;
 
 	while (read (fd, &ch, 1) > 0) {
 		if (!data)
-			data = (char *) malloc (sizeof (char)*len);
+			data = (gchar *) malloc (sizeof (gchar)*len);
 		if (size%len == 0)
-			data = (char *) realloc (data, sizeof (char)*len+size+1);
+			data = (gchar *) realloc (data, sizeof (gchar)*len+size+1);
 		data[size++] = ch;
 		if (data[0] == '\n' || ch == delimit || (size && data[size - 1] == ']')) {
 			if (data[0] != '\n' && read (fd, &ch, 1) > 0) {
@@ -58,7 +58,7 @@ read_delimiter (int fd, char delimit)
 				 */
 			}
 			if (size%len == 0)
-				data = (char *) realloc (data, sizeof (char)+size+1);
+				data = (gchar *) realloc (data, sizeof (gchar)+size+1);
 			data[size] = '\0';
 			return data;
 		}
@@ -67,11 +67,11 @@ read_delimiter (int fd, char delimit)
 }
 
 static void
-add_child_attributes (char *cur_entry, GHashTable *cur_context_table)
+add_child_attributes (gchar *cur_entry, GHashTable *cur_context_table)
 {
-	char *token = NULL;
+	gchar *token = NULL;
 	int offset;
-	char *component = NULL;
+	gchar *component = NULL;
 	    
 	token = strtok (strdup (cur_entry), "=");
 	if (token)
@@ -79,14 +79,14 @@ add_child_attributes (char *cur_entry, GHashTable *cur_context_table)
 	    
 	offset = strlen (component) + 1;
 	if (cur_entry[offset] == '{') {
-		char *end = strstr (cur_entry, "}");
+		gchar *end = strstr (cur_entry, "}");
 		if (end) {
-			char *key, *value;
-			char *all_attributes;
+			gchar *key, *value;
+			gchar *all_attributes;
 			GHashTable *hash_attributes;
 			int len = (end - cur_entry) - (offset+1);
 	 
-			all_attributes = (char *) malloc (sizeof (char) * len + 1);
+			all_attributes = (gchar *) malloc (sizeof (gchar) * len + 1);
 			strncpy (all_attributes, (cur_entry + offset + 1), len);
 			all_attributes[len] = '\0';
 
@@ -96,8 +96,8 @@ add_child_attributes (char *cur_entry, GHashTable *cur_context_table)
 			hash_attributes = g_hash_table_new (&g_str_hash, &g_str_equal);
 			key = strtok (strdup (all_attributes), "=");
 			while (key) {
-				char *hash_key;
-				char *hash_value;
+				gchar *hash_key;
+				gchar *hash_value;
 				hash_key = g_strdup (key);
 				value = strtok (NULL, ",");
 				hash_value = g_strdup (value);
@@ -114,25 +114,28 @@ add_child_attributes (char *cur_entry, GHashTable *cur_context_table)
 }
 
 void
-print_attributes (char *key, char *value, char *userdata)
+print_attributes (gchar *key, gchar *value, gchar *userdata)
 {
-	if (key && value)
-		g_print ("\t|-------%s = %s\n", key, value);
+	if (!key || !value)
+		return;
+	g_print ("\t|-------%s = %s\n", key, value);
 }
 
 void
-print_component (char *key, GHashTable *component, char *userdata)
+print_component (gchar *key, GHashTable *component, gchar *userdata)
 {
-	if (key)
-		g_print ("|-------%s\n", key);
+	if (!key || !component)
+		return;
+	g_print ("|-------%s\n", key);
 	g_hash_table_foreach (component, (GHFunc)&print_attributes, userdata);
 }
 
 void
-print_context (char *key, GHashTable *context, char *userdata)
+print_context (gchar *key, GHashTable *context, gchar *userdata)
 {
-	if (key)
-		g_print (":%s:\n", key);
+	if (!key || !context || !ldtp_debug)
+		return;
+	g_print (":%s:\n", key);
 	g_hash_table_foreach (context, (GHFunc)&print_component, userdata);
 }
 
@@ -140,12 +143,12 @@ print_context (char *key, GHashTable *context, char *userdata)
   Initialize application map
 */
 GHashTable*
-appmap_init (char *gui_map_filename, FILE *log_fp)
+appmap_init (gchar *gui_map_filename, FILE *log_fp)
 {
 	int fd;
 	//int quit_flag = 0;
 	FILE *fp;
-	char *cur_entry = NULL;
+	gchar *cur_entry = NULL;
 	GHashTable *appmap;
 	GHashTable *cur_context_table = NULL;
 
@@ -162,13 +165,13 @@ appmap_init (char *gui_map_filename, FILE *log_fp)
 	cur_entry = read_delimiter (fd, '}');
 	while (1) {
 		int cur_entry_len;
-		char *context = NULL;
+		gchar *context = NULL;
 		if (!cur_entry)
 			break;
 		cur_entry_len = strlen (cur_entry);
 		if (cur_entry [0] == '[' && cur_entry [cur_entry_len - 1] == ']') {
 			cur_context_table = g_hash_table_new (&g_str_hash, &g_str_equal);
-			context = (char *) g_new0 (char, sizeof (char) * (cur_entry_len - 1));
+			context = (gchar *) g_new0 (gchar, sizeof (gchar) * (cur_entry_len - 1));
 
 			/* Copy everything except the leading '[' and trailing ']' */
 			memcpy (context, cur_entry+1, cur_entry_len-2);
@@ -189,17 +192,21 @@ appmap_init (char *gui_map_filename, FILE *log_fp)
 }
 
 void
-key_destroy_func (gpointer data)
+destroy_hashtable (gpointer data)
 {
-	if (data)
-		g_free (data);
+	if (data) {
+		g_hash_table_destroy (data);
+		data = NULL;
+	}
 }
 
 void
-value_destroy_func (gpointer data)
+destroy_string (gpointer data)
 {
-	if (data)
+	if (data) {
 		g_free (data);
+		data = NULL;
+	}
 }
 
 static gboolean
@@ -207,7 +214,7 @@ is_remaped (gpointer key, gpointer value, gpointer user_data)
 {
 	if (key == NULL || value == NULL)
 		return FALSE;
-	g_print ("%s - %s ******* DEBUG\n", (char *) key, (char *) value);
+	g_print ("%s - %s ******* DEBUG\n", (gchar *) key, (gchar *) value);
 	if (g_utf8_collate (key, "remap") == 0)
 		return TRUE;
 	return FALSE;
@@ -217,11 +224,12 @@ gboolean
 remove_remapped_entry (gpointer key, gpointer value, gpointer user_data)
 {
 	if (key == NULL || value == NULL)
-		return FALSE;
+		return TRUE;
 	g_hash_table_foreach_remove (value, is_remaped, key);
-	return FALSE;
+	return TRUE;
 }
 
+/*
 gboolean
 remove_context_entries (gpointer key, gpointer value, gpointer context)
 {
@@ -229,13 +237,15 @@ remove_context_entries (gpointer key, gpointer value, gpointer context)
 
 	if (context == NULL || key == NULL)
 		return TRUE;
-	component = g_hash_table_lookup (context, (char *)key);
+	component = g_hash_table_lookup (context, (gchar *)key);
 	if (component) {
 		g_hash_table_destroy (component);
+		g_hash_table_remove (context, component);
 		component = NULL;
 	}
 	return TRUE;
 }
+*/
 
 static gboolean
 remove_appmap_entries (gpointer key, gpointer value, gpointer user_data)
@@ -245,9 +255,10 @@ remove_appmap_entries (gpointer key, gpointer value, gpointer user_data)
 
 	if (!appmap || !key)
 		return TRUE;
-	context = g_hash_table_lookup (appmap, (char *)key);
+	context = g_hash_table_lookup (appmap, (gchar *)key);
 	if (context) {
-		g_hash_table_foreach_remove (context, (GHRFunc)&remove_context_entries, context);
+		//g_hash_table_foreach_remove (context, (GHRFunc)&remove_context_entries, context);
+		g_print ("Context: %s %s\n", (gchar *)key, context);
 		g_hash_table_destroy (context);
 		context = NULL;
 	}
@@ -264,18 +275,40 @@ ldtp_appmap_free (GHashTable *appmap)
 		return;
 
 	pthread_mutex_lock (&mutex);
-	g_hash_table_foreach_remove (appmap, (GHRFunc)&remove_appmap_entries, appmap);
+	//g_hash_table_foreach_remove (appmap, (GHRFunc)&remove_appmap_entries, appmap);
 	g_hash_table_destroy (appmap);
 	pthread_mutex_unlock (&mutex);
 	appmap = NULL;
 }
 
+static gboolean
+search_key_based (gpointer key, gpointer value, gpointer user_data)
+{
+	OBJInfo *obj = (OBJInfo *) user_data;
+	if (!key || !user_data || !obj->key) {
+		return FALSE;
+	}
+	if (g_pattern_match_simple (obj->key, key)) {
+		if (ldtp_debug && obj->key && key) {
+			g_print ("glob- key: %s %s\n",
+				 (gchar *) key,
+				 obj->key);
+		}
+		if (obj->parent_name && value) {
+			gchar *parent = get_property (value, "parent", NULL);
+			if (parent && g_pattern_match_simple (obj->parent_name, parent))
+				return TRUE;
+		}
+	}
+	return FALSE;
+}
+
 static gboolean
 search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 {
-	char *tmp;
+	gchar *tmp;
 	OBJInfo *obj;
-	if (!key && !user_data) {
+	if (!key || !user_data) {
 		return FALSE;
 	}
 	/*
@@ -288,48 +321,104 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			 obj->obj_is_window,
 			 g_pattern_match_simple ("frm*", obj->key),
 			 g_pattern_match_simple ("dlg*", obj->key),
-			 obj->key, (char *) key, g_utf8_strlen (key, -1),
+			 obj->key, (gchar *) key, g_utf8_strlen (key, -1),
 			 g_utf8_strlen (obj->key, -1));
 	}
 	if (obj->obj_is_window) {
-		if (obj->key && g_utf8_collate (key, obj->key) == 0)
-			return TRUE;
-		if (obj->pattern) {
-			if (g_pattern_match_string (obj->pattern, key))
+		if (obj->key && g_utf8_collate (key, obj->key) == 0) {
+			if (obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
 				return TRUE;
 		}
+		if (obj->pattern) {
+			if (g_pattern_match_string (obj->pattern, key)) {
+				if (obj->parent_name && value) {
+					gchar *parent = get_property (value, "parent", NULL);
+					if (parent && g_pattern_match_simple (obj->parent_name, parent))
+						return TRUE;
+				} else
+					return TRUE;
+			}
+		}
 		tmp = g_strdup_printf ("frm%s", (gchar *)key);
 		if (tmp && g_pattern_match_simple (tmp, key)) {
 			g_free (tmp);
-			return TRUE;
+			tmp = NULL;
+			if (obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
+				return TRUE;
 		}
-		g_free (tmp);
+		if (tmp)
+			g_free (tmp);
 		tmp = g_strdup_printf ("dlg%s", obj->key);
 		if (tmp && g_pattern_match_simple (tmp, key)) {
 			g_free (tmp);
-			return TRUE;
+			tmp = NULL;
+			if (obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
+				return TRUE;
 		}
-		g_free (tmp);
+		if (tmp)
+			g_free (tmp);
 		tmp = g_strdup_printf ("frm%s*", obj->key);
 		if (tmp && g_pattern_match_simple (tmp, key)) {
 			g_free (tmp);
-			return TRUE;
+			tmp = NULL;
+			if (obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
+				return TRUE;
 		}
-		g_free (tmp);
+		if (tmp)
+			g_free (tmp);
 		tmp = g_strdup_printf ("dlg%s*", obj->key);
 		if (tmp && g_pattern_match_simple (tmp, key)) {
 			g_free (tmp);
-			return TRUE;
+			tmp = NULL;
+			if (obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
+				return TRUE;
 		}
-		g_free (tmp);
+		if (tmp)
+			g_free (tmp);
 		return FALSE;
 	}
 	if (obj->pattern && !obj->obj_is_window) {
-		return g_pattern_match_string (obj->pattern, key);
+		gboolean flag = g_pattern_match_string (obj->pattern, key);
+		if (flag && obj->parent_name && value) {
+			gchar *parent = get_property (value, "parent", NULL);
+			if (parent && g_pattern_match_simple (obj->parent_name, parent))
+				return TRUE;
+		} else
+			return flag;
 	}
 	return FALSE;
 }
 
+static void
+search_window_key_glob_based (gpointer key, gpointer value, gpointer user_data)
+{
+	if (search_key_glob_based (key, value, user_data)) {
+		OBJInfo *obj;
+		obj = (OBJInfo *) user_data;
+		g_hash_table_insert (obj->ht_data_list, g_strdup ((gchar *) key), value);
+	}
+}
+
 static gboolean
 search_label_based (gpointer key, gpointer value, gpointer user_data)
 {
@@ -342,7 +431,7 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 	gboolean flag = FALSE;
 	GPatternSpec *pattern = NULL;
 
-	if (!value && !user_data) {
+	if (!value || !user_data) {
 		return FALSE;
 	}
 	obj = (OBJInfo *) user_data;
@@ -367,10 +456,16 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 	*/
 	if (label && tmp_data) {
 		if ((gchar *)key && label && tmp_data)
-			g_print ("Label: %s - %s - %s\n", (gchar *)key, (char *)tmp_data, label);
+			g_print ("Label: %s - %s - %s\n", (gchar *)key, (gchar *)tmp_data, label);
 		if (!obj->obj_is_window || flag)
-			if (g_utf8_collate (label, tmp_data) == 0)
-				return TRUE;
+			if (g_utf8_collate (label, tmp_data) == 0) {
+				if (obj->parent_name && value) {
+					gchar *parent = get_property (value, "parent", NULL);
+					if (parent && g_pattern_match_simple (obj->parent_name, parent))
+						return TRUE;
+				} else
+					return TRUE;
+			}
 		// Search for mnemonics, if available then remove just _
 		if (g_utf8_strchr (label, -1, '_') == NULL)
 			return FALSE;
@@ -378,18 +473,33 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 		if (tmp && tmp_data)
 			if (g_utf8_collate (tmp, tmp_data) == 0) {
 				g_free (tmp);
-				return TRUE;
+				tmp = NULL;
+				if (obj->parent_name && value) {
+					gchar *parent = get_property (value, "parent", NULL);
+					if (parent)
+						g_print ("Parent: %s - %s\n", parent, obj->parent_name);
+					if (parent && g_pattern_match_simple (obj->parent_name, parent))
+						return TRUE;
+				} else
+					return TRUE;
 			}
-		g_free (tmp);
+		if (tmp)
+			g_free (tmp);
 		return FALSE;
 	}
 	g_hash_table_lookup_extended (value, "label_by", NULL, (gpointer) &label_by);
 	if (label_by && tmp_data) {
 		if ((gchar *)key && label_by && tmp_data)
-			g_print ("LabelBy: %s - %s - %s\n", (char *)key, (char *)tmp_data, label_by);
+			g_print ("LabelBy: %s - %s - %s\n", (gchar *)key, (gchar *)tmp_data, label_by);
 		if (!obj->obj_is_window || flag)
-			if (g_utf8_collate (label_by, tmp_data) == 0)
-				return TRUE;
+			if (g_utf8_collate (label_by, tmp_data) == 0) {
+				if (obj->parent_name && value) {
+					gchar *parent = get_property (value, "parent", NULL);
+					if (parent && g_pattern_match_simple (obj->parent_name, parent))
+						return TRUE;
+				} else
+					return TRUE;
+			}
 		// Search for mnemonics, if available then remove just _
 		if (g_utf8_strchr (label_by, -1, '_') == NULL)
 			return FALSE;
@@ -397,25 +507,42 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 		if (tmp && tmp_data)
 			if (g_utf8_collate (tmp, tmp_data) == 0) {
 				g_free (tmp);
-				return TRUE;
+				tmp = NULL;
+				if (obj->parent_name && value) {
+					gchar *parent = get_property (value, "parent", NULL);
+					if (parent && g_pattern_match_simple (obj->parent_name, parent))
+						return TRUE;
+				} else
+					return TRUE;
 			}
-		g_free (tmp);
+		if (tmp)
+			g_free (tmp);
 		return FALSE;
 	}
 	return FALSE;
 }
 
+static void
+search_window_label_based (gpointer key, gpointer value, gpointer user_data)
+{
+	if (search_label_based (key, value, user_data)) {
+		OBJInfo *obj;
+		obj = (OBJInfo *) user_data;
+		g_hash_table_insert (obj->ht_data_list, g_strdup ((gchar *) key), value);
+	}
+}
+
 static gboolean
 search_label_glob_based (gpointer key, gpointer value, gpointer user_data)
 {
 	OBJInfo *obj;
-	char *class = NULL;
-	char *tmp_label = NULL;
-	char *tmp_label_by = NULL;
+	gchar *class = NULL;
+	gchar *tmp_label = NULL;
+	gchar *tmp_label_by = NULL;
 	GPatternSpec *pattern = NULL;
 	gboolean flag = FALSE;
 
-	if (!value && !user_data)
+	if (!value || !user_data)
 		return FALSE;
 	/*
 	  FIXME: Remove under score from label or label_by and do a pattern match too
@@ -435,43 +562,67 @@ search_label_glob_based (gpointer key, gpointer value, gpointer user_data)
 		g_pattern_spec_free (pattern);
 	if (g_hash_table_lookup_extended (value, "label", NULL, (gpointer) &tmp_label)) {
 		if (key && value)
-			g_print ("Label glob: %s - %s\n", (char *)key, (char *)value);
-		if (obj->pattern && (!obj->obj_is_window || flag == TRUE))
-			return g_pattern_match_string (obj->pattern, tmp_label);
+			g_print ("Label glob: %s - %s\n", (gchar *)key, (gchar *)value);
+		if (obj->pattern && (!obj->obj_is_window || flag == TRUE)) {
+			gboolean tmp_flag = g_pattern_match_string (obj->pattern, tmp_label);
+			if (tmp_flag && obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
+				return tmp_flag;
+		}
 	}
 
 	if (g_hash_table_lookup_extended (value, "label_by", NULL, (gpointer) &tmp_label_by)) {
 		g_print ("Label_By glob: %s\n", tmp_label_by);
-		if (obj->pattern && (!obj->obj_is_window || flag))
-			return g_pattern_match_string (obj->pattern, tmp_label_by);
+		if (obj->pattern && (!obj->obj_is_window || flag)) {
+			gboolean tmp_flag = g_pattern_match_string (obj->pattern, tmp_label_by);
+			if (tmp_flag && obj->parent_name && value) {
+				gchar *parent = get_property (value, "parent", NULL);
+				if (parent && g_pattern_match_simple (obj->parent_name, parent))
+					return TRUE;
+			} else
+				return tmp_flag;
+		}
 	}
 	return FALSE;
 }
 
+static void
+search_window_label_glob_based (gpointer key, gpointer value, gpointer user_data)
+{
+	if (search_label_glob_based (key, value, user_data)) {
+		OBJInfo *obj;
+		obj = (OBJInfo *) user_data;
+		g_hash_table_insert (obj->ht_data_list, g_strdup ((gchar *) key), value);
+	}
+}
+
 /*
 static gboolean 
 search_label_name (gpointer key, gpointer value, gpointer user_data)
 {
-	char *child_index = NULL;
+	gchar *child_index = NULL;
 	UnknLabelProperty *tmp_data = (UnknLabelProperty *) user_data;
 	if (!value && !tmp_data && !key) {
 		return FALSE;
 	}
 	if (g_hash_table_lookup_extended (value, "child_index", NULL, (gpointer) &child_index)) {
-		if ((char *)key && tmp_data->str_child_index && tmp_data->parent_name)
+		if ((gchar *)key && tmp_data->str_child_index && tmp_data->parent_name)
 			g_print ("Key - Child index - Parent: %s - %s - %s\n",
-				 (char *)key, tmp_data->str_child_index,
+				 (gchar *)key, tmp_data->str_child_index,
 				 tmp_data->parent_name);
 		if (child_index && tmp_data->str_child_index &&
 		    g_utf8_collate (child_index, tmp_data->str_child_index) == 0) {
-			char *parent_name = NULL;
+			gchar *parent_name = NULL;
 			g_hash_table_lookup_extended (value, "parent", NULL, (gpointer) &parent_name);
 			g_print ("Key - Parent: %s - %s\n",
-				 (char *)key,
+				 (gchar *)key,
 				 parent_name);
 			if (parent_name && tmp_data->parent_name &&
 			    g_utf8_collate (parent_name, tmp_data->parent_name) == 0) {
-				tmp_data->obj_name = (char *) key;
+				tmp_data->obj_name = (gchar *) key;
 				return TRUE;
 			}
 		}
@@ -483,7 +634,7 @@ search_label_name (gpointer key, gpointer value, gpointer user_data)
 static gboolean
 search_obj_after_stripping_space (gpointer key, gpointer value, gpointer user_data)
 {
-	char *tmp;
+	gchar *tmp;
 	if (!key && !user_data)
 		return FALSE;
 	if (g_utf8_strchr (user_data, -1, ' ') == NULL)
@@ -491,19 +642,19 @@ search_obj_after_stripping_space (gpointer key, gpointer value, gpointer user_da
 	tmp = escape_character (user_data, ' ');
 	if (!tmp)
 		return FALSE;
-	g_print ("DEBUG: %s - %s - %s\n", tmp, (char *)user_data, (char *)key);
+	g_print ("DEBUG: %s - %s - %s\n", tmp, (gchar *)user_data, (gchar *)key);
 	if (g_utf8_collate (key, tmp) == 0 || g_utf8_collate (key, user_data) == 0) {
 		g_free (tmp);
 		return TRUE;
 	}
 	else {
-		char *glob_str = NULL;
+		gchar *glob_str = NULL;
 		/*
 		  FIXME: Use get_object_info function to get the the type of object
 		  and based on that use the convention, instead of directly using *
 		*/
 		glob_str = g_strdup_printf ("*%s", tmp);
-		g_print ("Glob str: %s - %s - %s\n", glob_str, (char *)key, tmp);
+		g_print ("Glob str: %s - %s - %s\n", glob_str, (gchar *)key, tmp);
 		if (g_pattern_match_simple (glob_str, key) ||
 		    g_pattern_match_simple (key, tmp)) {
 			g_print ("search_obj_after_stripping_space - matched\n");
@@ -517,15 +668,159 @@ search_obj_after_stripping_space (gpointer key, gpointer value, gpointer user_da
 	return FALSE;
 }
 
+static void
+search_window_after_stripping_space (gpointer key, gpointer value, gpointer user_data)
+{
+	OBJInfo *obj;
+	if (!key || !user_data || !value)
+		return;
+	obj = (OBJInfo *) user_data;
+	if (search_obj_after_stripping_space (key, value, obj->key)) {
+		if (obj && obj->ht_data_list && key && value)
+			g_hash_table_insert (obj->ht_data_list, g_strdup ((gchar *) key), value);
+	}
+}
+
+GHashTable*
+get_all_matching_def (GHashTable *ht, gchar *context, gboolean obj_is_window, FILE *log_fp)
+{
+	GHashTable *ht_data_list = NULL;
+	LDTPErrorCode err;
+
+	OBJInfo obj;
+	GPatternSpec *pattern = NULL;
+	if (ht == NULL) {
+		err =  (LDTP_ERROR_APPMAP_NOT_INITIALIZED);
+		g_print ("%s - %d - %s\n", __FILE__, __LINE__, ldtp_error_get_message (err));
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (err), log_fp);
+		return NULL;
+	}
+	if (context == NULL) {
+		err =  (LDTP_ERROR_ARGUMENT_NULL);
+		g_print ("%s\n", ldtp_error_get_message (err));
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (err), log_fp);
+		return NULL;
+	}
+	/*
+	  Search key based on glob expression
+	*/
+	g_print ("Search key based on glob expression: %s\n", context);
+	if (context)
+		pattern = g_pattern_spec_new ((const gchar *)context);
+
+	ht_data_list = g_hash_table_new_full (&g_str_hash, &g_str_equal,
+						 destroy_string, NULL);
+	obj.obj_is_window = obj_is_window;
+	obj.pattern = pattern;
+	obj.key = context;
+	obj.ht_data_list = ht_data_list;
+	g_hash_table_foreach (ht, search_window_key_glob_based, &obj);
+	if (pattern)
+		g_pattern_spec_free (pattern);
+	if (!g_hash_table_size (ht_data_list)) {
+		/*
+		  Search label based
+		*/
+		g_print ("Search label based: %s\n", context);
+
+		obj.pattern = NULL;
+		g_hash_table_foreach (ht, search_window_label_based, &obj);
+	}
+	if (!g_hash_table_size (ht_data_list)) {
+		/*
+		  Search label based on glob expression
+		*/
+		OBJInfo obj;
+		GPatternSpec *pattern = NULL;
+
+		g_print ("Search label based on glob expression: %s\n", context);
+		if (context)
+			pattern = g_pattern_spec_new (context);
+
+		obj.pattern = pattern;
+		g_hash_table_foreach (ht, search_window_label_glob_based, &obj);
+		if (pattern)
+			g_pattern_spec_free (pattern);
+	}
+	if (!g_hash_table_size (ht_data_list)) {
+		/*
+		  Search key after stripping space
+		*/
+		g_print ("Search key after stripping space: %s\n", context);
+		g_hash_table_foreach (ht, search_window_after_stripping_space, &obj);
+	}
+	return ht_data_list;
+}
+
+gboolean
+match_object_def (gchar *key, gchar *value, gboolean obj_is_window)
+{
+	OBJInfo obj;
+	gchar msg [256];
+	GPatternSpec *pattern = NULL;
+	/*
+	  Search key based on glob expression
+	*/
+	g_print ("Search key based on glob expression: %s\n", key);
+	if (key)
+		pattern = g_pattern_spec_new (/*(const ggchar *)*/key);
+
+	obj.obj_is_window = obj_is_window;
+	obj.pattern = pattern;
+	obj.key = key;
+	if (search_key_glob_based (value, NULL, &obj)) {
+		if (pattern)
+			g_pattern_spec_free (pattern);
+		return TRUE;
+	}
+	if (pattern)
+		g_pattern_spec_free (pattern);
+
+	g_print ("Search label based: %s - %d\n", value, obj_is_window);
+
+	obj.obj_is_window = obj_is_window;
+	obj.pattern = NULL;
+	obj.key = key;
+	if (search_label_based (NULL, value, &obj))
+		return TRUE;
+
+	g_print ("Search label based on glob expression\n");
+	if (key)
+		pattern = g_pattern_spec_new (key);
+
+	obj.obj_is_window = obj_is_window;
+	obj.pattern = pattern;
+	obj.key = key;
+	if (search_label_glob_based (NULL, value, &obj)) {
+		if (pattern)
+			g_pattern_spec_free (pattern);
+		return TRUE;
+	}
+	if (pattern)
+		g_pattern_spec_free (pattern);
+	/*
+	  Search key after stripping space
+	*/
+	g_print ("Search key after stripping space\n");
+	if (search_obj_after_stripping_space (key, NULL, value))
+		return TRUE;
+
+	g_sprintf (msg, "Object definition %s not match", key);
+	g_print ("%s\n", msg);
+	return FALSE;
+}
+
 /*
   Get window definition
 */
 GHashTable*
-get_object_def (GHashTable *ht, char *context, FILE *log_fp, gboolean obj_is_window)
+get_object_def (GHashTable *ht, gchar *context, gchar *parent, FILE *log_fp, gboolean obj_is_window)
 {
 	GHashTable *ht_context = NULL;
 	LDTPErrorCode err;
-	char *msg = NULL;
+	gchar msg [256];
+	OBJInfo obj;
+	GPatternSpec *pattern = NULL;
 
 	if (ht == NULL) {
 		err =  (LDTP_ERROR_APPMAP_NOT_INITIALIZED);
@@ -542,12 +837,13 @@ get_object_def (GHashTable *ht, char *context, FILE *log_fp, gboolean obj_is_win
 	/*
 	  Search given context in hash table
 	*/
-	g_hash_table_lookup_extended (ht, (gconstpointer) context, NULL, (gpointer) ht_context);
+	//g_hash_table_lookup_extended (ht, (gconstpointer) context, NULL, (gpointer) ht_context);
+	obj.key = context;
+	obj.parent_name = parent;
+	ht_context = g_hash_table_find (ht, search_key_based, &obj);
 	if (ht_context)
 		return ht_context;
 	if (!ht_context) {
-		OBJInfo obj;
-		GPatternSpec *pattern = NULL;
 		/*
 		  Search key based on glob expression
 		*/
@@ -557,6 +853,7 @@ get_object_def (GHashTable *ht, char *context, FILE *log_fp, gboolean obj_is_win
 
 		obj.obj_is_window = obj_is_window;
 		obj.pattern = pattern;
+		obj.parent_name = parent;
 		obj.key = context;
 		ht_context = g_hash_table_find (ht, search_key_glob_based, &obj);
 		if (pattern)
@@ -572,6 +869,7 @@ get_object_def (GHashTable *ht, char *context, FILE *log_fp, gboolean obj_is_win
 
 		obj.obj_is_window = obj_is_window;
 		obj.pattern = NULL;
+		obj.parent_name = parent;
 		obj.key = context;
 		ht_context = g_hash_table_find (ht, search_label_based, &obj);
 	}
@@ -588,6 +886,7 @@ get_object_def (GHashTable *ht, char *context, FILE *log_fp, gboolean obj_is_win
 
 		obj.obj_is_window = obj_is_window;
 		obj.pattern = pattern;
+		obj.parent_name = parent;
 		obj.key = context;
 		ht_context = g_hash_table_find (ht, search_label_glob_based, &obj);
 		if (pattern)
@@ -598,24 +897,39 @@ get_object_def (GHashTable *ht, char *context, FILE *log_fp, gboolean obj_is_win
 		  Search key after stripping space
 		*/
 		g_print ("Search key after stripping space: %s\n", context);
+		obj.parent_name = parent;
 		ht_context = g_hash_table_find (ht, search_obj_after_stripping_space, context);
 	}
 	if (!ht_context) {
-		msg = g_strdup_printf ("Object definition %s not found in appmap", context);
+		g_sprintf (msg, "Object definition %s not found in appmap", context);
 		g_print ("%s\n", msg);
 		log_msg (LDTP_LOG_DEBUG, msg, log_fp);
-		g_free (msg);
 	}
 	return ht_context;
 }
 
-char*
-get_property (GHashTable *ht, char *property, FILE *log_fp)
+static gboolean
+find_property (gpointer key, gpointer value, gpointer user_data)
 {
-	char *value = NULL;
-	char *msg = NULL;
+	if (!key || !value || !user_data)
+		return FALSE;
+	if (ldtp_debug) {
+		g_print ("User data: %s\n", (gchar *) user_data);
+		//g_print ("Value: %s\n", (gchar *) value);
+		g_print ("Key: %s\n", (gchar *) key);
+	}
+
+	if (g_utf8_collate (key, user_data) == 0)
+		return TRUE;
+	return FALSE;
+}
+
+gchar*
+get_property (GHashTable *ht, gchar *property, FILE *log_fp)
+{
+	gchar *value = NULL;
+	gchar msg [256];
 	LDTPErrorCode err;
-	gboolean flag;
 
 	if (ht == NULL) {
 		err =  (LDTP_ERROR_APPMAP_NOT_INITIALIZED);
@@ -629,13 +943,11 @@ get_property (GHashTable *ht, char *property, FILE *log_fp)
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (err), log_fp);
 		return NULL;
 	}
-	flag = g_hash_table_lookup_extended (ht, property, NULL, (gpointer) &value);
-
-	if (!flag || !value) {
-		msg = g_strdup_printf ("Property %s not found in appmap", property);
+	value = (gchar *) g_hash_table_find (ht, find_property, (gpointer) property);
+	if (!value) {
+		g_sprintf (msg, "Property %s not found in appmap", property);
 		g_print ("%s\n", msg);
 		log_msg (LDTP_LOG_DEBUG, msg, log_fp);
-		g_free (msg);
 	}
 	else
 		g_print ("Property: %s - Value: %s\n", property, value);
@@ -645,14 +957,14 @@ get_property (GHashTable *ht, char *property, FILE *log_fp)
 gboolean
 search_title_based (gpointer key, gpointer value, gpointer user_data)
 {
-	char *tmp_key = NULL;
+	gchar *tmp_key = NULL;
 	if (!key && !user_data)
 		return FALSE;
 	if (g_utf8_collate (key, user_data) == 0)
 		return TRUE;
 	if (g_pattern_match_simple (key, user_data))
 		return TRUE;
-	tmp_key = g_strdup_printf ("*%s", (char *)key);
+	tmp_key = g_strdup_printf ("*%s", (gchar *)key);
 	if (tmp_key && g_pattern_match_simple (tmp_key, user_data)) {
 		g_free (tmp_key);
 		return TRUE;
