@@ -75,7 +75,7 @@ ldtp_error_get_message (LDTPErrorCode error)
 		msg = "Warning!! Partial data sent";
 		break;
 	case LDTP_ERROR_INVALID_COMMAND:
-		msg = "Invalid command";
+		msg = "Invalid command - Welcome contribution ;)";
 		break;
 	case LDTP_ERROR_INVALID_STATE:
 		msg = "Invalid state";
@@ -123,7 +123,7 @@ ldtp_error_get_message (LDTPErrorCode error)
 		msg = "Object information does not match with application map entry";
 		break;
 	case LDTP_ERROR_COMMAND_NOT_IMPLEMENTED:
-		msg = "Requested action on mentioned object is not implemented";
+		msg = "Requested action on mentioned object is not implemented - Welcome contribution ;)";
 		break;
 	case LDTP_ERROR_GETTEXTVALUE_FAILED:
 		msg = "GetTextValue action on mentioned object failed";
@@ -220,6 +220,9 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_INVALID_OBJECT_STATE:
 		msg = "Invalid object state";
 		break;
+	case LDTP_ERROR_CHECK_BOX_STATE_NOT_ENABLED:
+		msg = "Check box state not enabled";
+		break;
 	case LDTP_ERROR_CHECK_ACTION_FAILED:
 		msg = "Check action failed";
 		break;
@@ -307,6 +310,12 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_PANEL_COUNT_LESS_THAN_TOTAL_PANEL:
 		msg = "Panels count less than total panel number";
 		break;
+	case LDTP_ERROR_PUSH_BUTTON_STATE_NOT_ENABLED:
+		msg = "Push button state not enabled";
+		break;
+	case LDTP_ERROR_TOGGLE_BUTTON_STATE_NOT_ENABLED:
+		msg = "Toggle button state not enabled";
+		break;
 	case LDTP_ERROR_RADIO_BUTTON_ALREADY_CHECKED:
 		msg = "Radio button already checked";
 		break;
@@ -565,6 +574,11 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE:
 		msg = "Unable to get child with provided role";
 		break;
+	case LDTP_ERROR_UNABLE_TO_GET_PAGE_TAB_NAME:
+		msg = "Unable to get page tab name";
+		break;
+	case LDTP_ERROR_UNABLE_TO_VERIFY_PAGE_TAB_NAME:
+		msg = "Unable to verify page tab name";
 	default:
 		msg = "Error code not found";
 		break;
