@@ -79,6 +79,9 @@ LDTPErrorCode radio_menu_item_main (LDTPClientContext* cctxt, int command);
 // scroll-bar.c
 LDTPErrorCode scroll_bar_main (LDTPClientContext* cctxt, int command);
 
+// scroll-pane.c
+LDTPErrorCode scroll_pane_main (LDTPClientContext* cctxt, int command);
+
 // status-bar.c
 LDTPErrorCode status_bar_main (LDTPClientContext* cctxt, int command);
 
