@@ -3,9 +3,9 @@
  * Linux Desktop Testing Project http://ldtp.freedesktop.org
  *
  * Author:
+ *    Premkumar J <jpremkumar@novell.com>
  *    Nagappan A <nagappan@gmail.com>
  *    Poornima <pnayak@novell.com>
- *    Premkumar J <jpremkumar@novell.com>
  *
  * Copyright 2004 - 2006 Novell, Inc.
  *
@@ -143,7 +143,7 @@ static struct {
 
 	{7, {SPI_STATE_EDITABLE, SPI_STATE_ENABLED, SPI_STATE_FOCUSABLE, SPI_STATE_MULTI_LINE, SPI_STATE_SENSITIVE, SPI_STATE_SHOWING, SPI_STATE_VISIBLE }}, //TEXT 60
 
-	{2, {SPI_STATE_ENABLED, SPI_STATE_FOCUSABLE}},//TOGGLE_BUTTON 61
+	{1, {SPI_STATE_FOCUSABLE}},//TOGGLE_BUTTON 61
 
 	{0, {SPI_STATE_ENABLED,SPI_STATE_SENSITIVE, SPI_STATE_SHOWING, SPI_STATE_VISIBLE}},//TOOL_BAR 62
 	{0, {0}},//TOOL_TIP 63
@@ -382,9 +382,9 @@ window_info_added_hashtable (char *window_name, LDTPClientContext* cctxt, LDTPEr
 		*err = LDTP_ERROR_ARGUMENT_NULL;
 
 	if (!client_context)
-		client_context = g_hash_table_new_full (&g_str_hash, &g_str_equal, key_destroy_func, NULL);
+		client_context = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, NULL);
 
-	g_hash_table_insert (client_context, g_strdup ((gchar *)window_name), cctxt);
+	g_hash_table_replace (client_context, g_strdup ((gchar *)window_name), cctxt);
 	*err = LDTP_ERROR_SUCCESS;
 }
 
@@ -485,7 +485,7 @@ get_window_list (void)
 {
 	long i, num_apps;
 	Accessible *desktop;
-	GHashTable *table = g_hash_table_new (&g_str_hash, &g_str_equal);
+	GHashTable *table = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, NULL);
 
 	/*
 	  Get SPI handle of desktop 0
@@ -576,7 +576,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 		g_print ("Child count: %ld of %s\n", child_count, name);
 	SPI_freeString (name);
 	if (child_count > 0) {
-		tmpTable = g_hash_table_new (&g_str_hash, &g_str_equal);
+		tmpTable = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, NULL);
 		for (i = 0; i < child_count; i++) {
 			child = Accessible_getChildAtIndex (app_handle, i);
 			if (!child)
@@ -639,6 +639,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 							g_pattern_spec_free (last_existing_context_pattern);
 						if (context_pattern)
 							g_pattern_spec_free (context_pattern);
+						g_hash_table_destroy (tmpTable);
 						return child;
 					}
 #else
@@ -653,6 +654,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 							g_pattern_spec_free (last_existing_context_pattern);
 						if (context_pattern)
 							g_pattern_spec_free (context_pattern);
+						g_hash_table_destroy (tmpTable);
 						return child;
 					}
 					g_free (tmp);
@@ -670,6 +672,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 					g_pattern_spec_free (last_existing_context_pattern);
 				if (context_pattern)
 					g_pattern_spec_free (context_pattern);
+				g_hash_table_destroy (tmpTable);
 				return child;
 			}
 #else
@@ -687,6 +690,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 					g_pattern_spec_free (last_existing_context_pattern);
 				if (context_pattern)
 					g_pattern_spec_free (context_pattern);
+				g_hash_table_destroy (tmpTable);
 				return child;
 			}
 #endif
@@ -702,6 +706,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 		g_pattern_spec_free (last_existing_context_pattern);
 	if (context_pattern)
 		g_pattern_spec_free (context_pattern);
+	g_hash_table_destroy (tmpTable);
 	return NULL;
 }
 
@@ -784,7 +789,6 @@ get_relation_name (Accessible *object, long *len)
 			    relation_type == SPI_RELATION_LABEL_FOR) {
 				char *name = NULL;
 				Accessible *tmp_obj;
-				//tmp_obj = AccessibleRelation_getTarget (relation[i], i);
 				tmp_obj = AccessibleRelation_getTarget (relation[i], j);
 				if (tmp_obj)
 					name = Accessible_getName (tmp_obj);
@@ -935,6 +939,7 @@ does_window_exist (char *context, char *name, char *window_name, GPatternSpec *p
 	return FALSE;
 }
 
+/*
 static gboolean
 remove_tmp_entries (gpointer key, gpointer value, gpointer user_data)
 {
@@ -944,6 +949,7 @@ remove_tmp_entries (gpointer key, gpointer value, gpointer user_data)
 	}
 	return TRUE;
 }
+*/
 
 void
 print_tmp_table (char *key, char *value, char *userdata)
@@ -984,8 +990,7 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 		tmp = NULL;
 	}
 
-	*window_name = NULL;
-	tmpTable = g_hash_table_new (&g_str_hash, &g_str_equal);
+	tmpTable = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, NULL);
 	for (i = 0; i < child_count; i++) {
 		child = Accessible_getChildAtIndex (app_handle, i);
 		if (!child)
@@ -1018,7 +1023,7 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 			} else {
 				if (name)
 					tmp = g_strdup_printf ("%s%ld", name, k++);
-				if (*window_name) {
+				if (window_name) {
 					g_free (*window_name);
 					*window_name = NULL;
 				}
@@ -1028,7 +1033,7 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 					tmp = NULL;
 				}
 				if (*window_name && g_hash_table_lookup_extended (tmpTable,
-										  *window_name,
+										 *window_name,
 										  NULL, NULL) == FALSE) {
 					g_hash_table_insert (tmpTable, g_strdup (*window_name), NULL);
 					*flag = TRUE;
@@ -1044,7 +1049,7 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 				g_pattern_spec_free (pattern);
 			if (tmp_pattern)
 				g_pattern_spec_free (tmp_pattern);
-			g_hash_table_foreach_remove (tmpTable, (GHRFunc)&remove_tmp_entries, NULL);
+			//g_hash_table_foreach_remove (tmpTable, (GHRFunc)&remove_tmp_entries, NULL);
 			g_hash_table_destroy (tmpTable);
 			return child;
 		}
@@ -1055,12 +1060,12 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 		g_pattern_spec_free (pattern);
 	if (tmp_pattern)
 		g_pattern_spec_free (tmp_pattern);
-	g_hash_table_foreach_remove (tmpTable, (GHRFunc)&remove_tmp_entries, NULL);
+	//g_hash_table_foreach_remove (tmpTable, (GHRFunc)&remove_tmp_entries, NULL);
 	g_hash_table_destroy (tmpTable);
 	return NULL;
 }
 
-static Accessible*
+Accessible*
 get_window_handle (Accessible *app_handle, char *context, char **window_name, gboolean *flag)
 {
 	char *name = NULL;
@@ -1140,7 +1145,7 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 		g_print ("%s", ldtp_error_get_message (*err));
 		return;
 	}
-	child = get_window_handle (cctxt->app_handle, context, &(cctxt->window_name), &flag);
+	child = get_window_handle (cctxt->app_handle, context, &window_name, &flag);
 	if (!child) {
 		g_print ("%s - %d - Window %s not open\n", __FILE__, __LINE__, context);
 		*err = LDTP_ERROR_WIN_NOT_OPEN;
@@ -1148,7 +1153,9 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 	}
 
 	/* Unable to find using the new context based on the dynamic context generated */
-	window_name = cctxt->window_name;
+	if (cctxt->window_name)
+		g_free (cctxt->window_name);
+	cctxt->window_name = g_strdup (window_name);
 	parent = Accessible_getParent (child);
 	if (flag == FALSE && parent) {
 		AccessibleRole role;
@@ -1156,6 +1163,8 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 		if (ldtp_debug && parent_name)
 			g_print ("Parent name: %s\n", parent_name);
 		role = Accessible_getRole (parent) == SPI_ROLE_APPLICATION ? SPI_ROLE_APPLICATION : Accessible_getRole (child);
+		if (window_name)
+			g_free (window_name);
 		window_name = get_window_name_in_appmap_format (parent_name, role);
 		if (ldtp_debug && window_name && parent_name)
 			g_print ("Window name - Stripped: %s - %s\n", window_name, parent_name);
@@ -1166,12 +1175,15 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 	if (parent)
 		Accessible_unref (parent);
 
+	if (ldtp_debug && cctxt->window_name && window_name)
+		g_print ("%s %d %s %s\n", __FILE__, __LINE__, cctxt->window_name, window_name);
 	pthread_mutex_lock (&mutex);
-	if (ldtp_debug && cctxt->window_name)
-		g_print ("%s %d %s\n", __FILE__, __LINE__, cctxt->window_name);
 	new_hashtable = do_remap (child, window_name, NULL, NULL, cctxt->locale_set, flag, FALSE);
 	pthread_mutex_unlock (&mutex);
 
+	if (ldtp_debug && cctxt->window_name && window_name)
+		g_print ("DEBUG: %s %d %s %s\n", __FILE__, __LINE__, cctxt->window_name, window_name);
+
 	if (flag == FALSE && window_name) {
 		g_free (window_name);
 		window_name = NULL;
@@ -1182,7 +1194,7 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 
 		if (!cctxt->app_map) {
 			g_print ("Appmap hashtable not initalized\n");
-			cctxt->app_map = g_hash_table_new (&g_str_hash, &g_str_equal);
+			cctxt->app_map = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, destroy_hashtable);
 		}
 		name = Accessible_getName (child);
 
@@ -1228,6 +1240,7 @@ update_cur_context_appmap_handle (LDTPClientContext *cctxt,
 				  LDTPErrorCode *err)
 {
 	char *parent_name  = NULL;
+	GHashTable *new_hashtable   = NULL;
 	GHashTable *context_table   = NULL;
 	GHashTable *component_table = NULL;
 	LDTPGuiHandle *gui_handle   = NULL;
@@ -1242,13 +1255,13 @@ update_cur_context_appmap_handle (LDTPClientContext *cctxt,
 		g_print ("%s - %d - %s\n", __FILE__, __LINE__, ldtp_error_get_message (*err));
 		return;
 	}
-	context_table = get_object_def (cctxt->app_map, cctxt->req->context, cctxt->log_fp, TRUE);
+	context_table = get_object_def (cctxt->app_map, cctxt->req->context, NULL, cctxt->log_fp, TRUE);
 	if (!context_table) {
 		*err = LDTP_ERROR_WIN_NAME_NOT_FOUND_IN_APPMAP;
 		g_print ("%s", ldtp_error_get_message (*err));
 		return;
 	}
-	component_table = get_object_def (context_table, cctxt->req->component, cctxt->log_fp, FALSE);
+	component_table = get_object_def (context_table, cctxt->req->component, cctxt->parent_name, cctxt->log_fp, FALSE);
 	if (!component_table) {
 		*err = LDTP_ERROR_OBJ_NAME_NOT_FOUND_IN_APPMAP;
 		g_print ("%s", ldtp_error_get_message (*err));
@@ -1266,10 +1279,34 @@ update_cur_context_appmap_handle (LDTPClientContext *cctxt,
 	}
 	pthread_mutex_lock (&mutex);
 	g_hash_table_foreach_remove (context_table, remove_remapped_entry, NULL);
-	do_remap (gui_handle->handle, parent_name, context_table, NULL, cctxt->locale_set, FALSE, TRUE);
+	new_hashtable = do_remap (gui_handle->handle, parent_name, context_table, NULL, cctxt->locale_set, FALSE, TRUE);
 	pthread_mutex_unlock (&mutex);
+	if (new_hashtable) {
+		char *name = NULL;
+
+		if (!cctxt->app_map) {
+			g_print ("Appmap hashtable not initalized\n");
+			cctxt->app_map = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, destroy_hashtable);
+		}
+		name = Accessible_getName (gui_handle->handle);
+
+		SPI_freeString (name);
+		Accessible_unref (gui_handle->handle);
+		if (cctxt->window_name) {
+			g_print ("cctxt->window_name: %s\n", cctxt->window_name);
+			pthread_mutex_lock (&mutex);
+			g_hash_table_replace (cctxt->app_map, g_strdup (cctxt->window_name), new_hashtable);
+			pthread_mutex_unlock (&mutex);
+			pthread_mutex_lock (&cb_mutex);
+			window_info_added_hashtable (cctxt->window_name, cctxt, err);
+			pthread_mutex_unlock (&cb_mutex);
+			*err = LDTP_ERROR_SUCCESS;
+			return;
+		}
+	}
 	Accessible_unref (gui_handle->handle);
-	*err = LDTP_ERROR_SUCCESS;
+	*err = LDTP_ERROR_UNABLE_TO_UPDATE_APPMAP;
+	g_print ("DEBUG: Window name NULL\n");
 }
 
 static Accessible*
@@ -1315,8 +1352,8 @@ ldtp_get_component_handle (LDTPClientContext *cctxt, char *window_prop, gchar *c
 			if (name) {
 				char *tmp_context = get_window_name_in_appmap_format (name, Accessible_getRole (context_handle));
 				if (tmp_context) {
-					cur_window = get_object_def (cctxt->app_map, tmp_context, cctxt->log_fp, TRUE);
-					cur_component = get_object_def (cur_window, component, cctxt->log_fp, FALSE);
+					cur_window = get_object_def (cctxt->app_map, tmp_context, NULL, cctxt->log_fp, TRUE);
+					cur_component = get_object_def (cur_window, component, cctxt->parent_name, cctxt->log_fp, FALSE);
 					head = trace_path_to_parent (cur_window, tmp_context, cur_component,
 								     &class_type, cctxt->log_fp, cctxt, err);
 					component_handle = get_accessible_component_handle (head, context_handle, cctxt->log_fp);
@@ -1390,6 +1427,83 @@ ldtp_get_component_handle (LDTPClientContext *cctxt, char *window_prop, gchar *c
 	return component_handle;
 }
 
+static gboolean
+get_matching_component_def (gpointer key, gpointer value, gpointer user_data)
+{
+	if (!key || !value || !user_data)
+		return FALSE;
+	if (get_object_def (value, (gchar *) user_data, NULL, NULL, FALSE))
+		return TRUE;
+	return FALSE;
+}
+
+static gboolean
+get_matching_all_component_def (gpointer key, gpointer value, gpointer user_data)
+{
+	gchar *role = NULL;
+	gchar *label = NULL;
+	gchar *parent = NULL;
+	OBJProperty *obj_prop = user_data;
+	if (!key || !value || !user_data)
+		return FALSE;
+	if (obj_prop->label) {
+		label = get_property (value, "label_by", NULL);
+		if (!label)
+			label = get_property (value, "label", NULL);
+		if (!label || (g_utf8_collate (label, obj_prop->label) &&
+			       match_object_def (obj_prop->label, label, FALSE) == FALSE))
+			return FALSE;
+	}
+	if (obj_prop->parent_name) {
+		parent = get_property (value, "parent", NULL);
+		if (!parent || (g_utf8_collate (parent, obj_prop->parent_name) &&
+				match_object_def (obj_prop->parent_name, parent, FALSE) == FALSE))
+			return FALSE;
+	}
+	if (obj_prop->class_name) {
+		role = get_property (value, "class", NULL);
+		if (!role || g_utf8_collate (role, obj_prop->class_name))
+			return FALSE;
+	}
+	return TRUE;
+}
+
+static GHashTable*
+get_context_def (LDTPClientContext *cctxt, gchar *context, gchar *component)
+{
+	GHashTable *ht;
+	GHashTable *tmp_ht = NULL;
+	if (!cctxt || !context || !component)
+		return NULL;
+	ht = get_all_matching_def (cctxt->app_map, context, TRUE, cctxt->log_fp);
+	if (ht && g_hash_table_size (ht) > 1) {
+		tmp_ht = g_hash_table_find (ht, get_matching_component_def, component);
+	}
+	if (ht)
+		g_hash_table_destroy (ht);
+	return tmp_ht;
+}
+
+static GHashTable*
+get_component_def (GHashTable *ht, gchar *component, gchar *parent, gchar *role, gchar *label)
+{
+	GHashTable *tmp_ht = NULL;
+	GHashTable *component_ht = NULL;
+	OBJProperty obj_prop;
+	if (!ht || !component)
+		return NULL;
+	tmp_ht = get_all_matching_def (ht, component, TRUE, NULL);
+	if (tmp_ht && g_hash_table_size (tmp_ht) > 1) {
+		obj_prop.parent_name = parent;
+		obj_prop.class_name = role;
+		obj_prop.label = label;
+		component_ht = g_hash_table_find (tmp_ht, get_matching_all_component_def, &obj_prop);
+	}
+	if (tmp_ht)
+		g_hash_table_destroy (tmp_ht);
+	return component_ht;
+}
+
 /*
   Get gui handle based on context and compoment
 */
@@ -1442,7 +1556,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 		}
 	}
 
-	cur_window = get_object_def (cctxt->app_map, context, cctxt->log_fp, TRUE);
+	cur_window = get_object_def (cctxt->app_map, context, NULL, cctxt->log_fp, TRUE);
 	if (context)
 		g_print ("context: %s - cur_window: %d\n", context, cur_window == NULL ? 0 : 1);
 	/*
@@ -1460,7 +1574,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			g_sprintf (msg, "Unable to update context: %s in appmap", context);
 			goto error;
 		}
-		cur_window = get_object_def (cctxt->app_map, context, cctxt->log_fp, TRUE);
+		cur_window = get_object_def (cctxt->app_map, context, NULL, cctxt->log_fp, TRUE);
 		if (!cur_window) {
 			Accessible *child;
 
@@ -1502,7 +1616,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 				if (tmpflag)
 					component = context;
 				if (context)
-					cur_window = get_object_def (cctxt->app_map, context, cctxt->log_fp, TRUE);
+					cur_window = get_object_def (cctxt->app_map, context, NULL, cctxt->log_fp, TRUE);
 				//g_free (window_name);
 				//window_name = NULL;
 			}
@@ -1513,7 +1627,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			goto error;
 		}
 	}
-	cur_component = get_object_def (cur_window, context, cctxt->log_fp, TRUE);
+	cur_component = get_object_def (cur_window, context, NULL, cctxt->log_fp, TRUE);
 	if (!cur_component) {
 		g_sprintf (msg, "%s - %d - Unable to find context name: %s in appmap", __FILE__, __LINE__, context);
 		*err = LDTP_ERROR_WIN_NAME_NOT_FOUND_IN_APPMAP;
@@ -1528,21 +1642,17 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 
 	if (context && component &&
 	    g_utf8_collate ((const gchar *)context, (const gchar *)component)) {
-		cur_component = get_object_def (cur_window, component, cctxt->log_fp, FALSE);
-
+		cur_component = get_object_def (cur_window, component, cctxt->parent_name, cctxt->log_fp, FALSE);
 		if (!cur_component) {
 			int time_wait = ldtp_obj_timeout;
 			time_t start, cur;
-			gboolean flag = FALSE;
+			gboolean tmp_flag = FALSE;
 
 			g_print ("Unable to get component\n");
 			if (cctxt->window_name) {
 				g_free (cctxt->window_name);
 				cctxt->window_name = NULL;
 			}
-			/*
-			  Copied from LTFX source code
-			*/
 			start = cur = time (NULL);
 
 			if (!ldtp_obj_timeout) {
@@ -1550,22 +1660,50 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			}
 
 			while (difftime (cur, start) < time_wait) {
+				GHashTable *tmp_context = NULL;
+				GHashTable *tmp_component = NULL;
+				if (!cur_component) {
+					tmp_context = get_context_def (cctxt, context, component);
+					if (tmp_context) {
+						tmp_component = get_object_def (tmp_context, component, NULL, cctxt->log_fp, FALSE);
+						if (tmp_component) {
+							cur_window = tmp_context;
+							cur_component = tmp_component;
+							tmp_flag = TRUE;
+							tmp_component = get_object_def (cur_window, context, cctxt->parent_name, cctxt->log_fp, TRUE);
+							app_name = get_property (tmp_component, "parent", cctxt->log_fp);
+							if (app_name)
+								g_print ("app_name: %s\n", app_name);
+							window_prop = get_property (tmp_component, "label", cctxt->log_fp);
+							if (ldtp_debug && window_prop)
+								g_print ("window_prop: %s\n", window_prop);
+							break;
+						}
+					}
+				}
 				g_print ("Updating appmap - context\n");
 				update_cur_window_appmap_handle (cctxt, err);
 				updated_appmap = TRUE;
-				cur_window = get_object_def (cctxt->app_map, context, cctxt->log_fp, TRUE);
-				cur_component = get_object_def (cur_window, component, cctxt->log_fp, FALSE);
+				cur_window = get_object_def (cctxt->app_map, context, NULL, cctxt->log_fp, TRUE);
+				cur_component = get_object_def (cur_window, component, cctxt->parent_name, cctxt->log_fp, FALSE);
 
 				if (!cur_component) {
 					sleep (1);
 
 					cur = time (NULL);
 				} else {
-					flag = TRUE;
+					tmp_flag = TRUE;
+					tmp_component = get_object_def (cur_window, context, NULL, cctxt->log_fp, TRUE);
+					app_name = get_property (tmp_component, "parent", cctxt->log_fp);
+					if (app_name)
+						g_print ("app_name: %s\n", app_name);
+					window_prop = get_property (tmp_component, "label", cctxt->log_fp);
+					if (ldtp_debug && window_prop)
+						g_print ("window_prop: %s\n", window_prop);
 					break;
 				}
 			}
-			if (flag == FALSE) {
+			if (tmp_flag == FALSE) {
 				g_sprintf (msg, "%s - %d - Unable to find object name: %s in appmap", __FILE__, __LINE__, component);
 				*err = LDTP_ERROR_OBJ_NAME_NOT_FOUND_IN_APPMAP;
 				goto error;
@@ -1601,7 +1739,8 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 		if (window_prop)
 			cctxt->window_name = g_strdup (window_prop);
 	}
-	context_handle = get_accessible_context_handle (cctxt->app_handle, window_prop);
+	if (window_prop)
+		context_handle = get_accessible_context_handle (cctxt->app_handle, window_prop);
 	if (!context_handle) {
 		context_handle = get_accessible_context_handle (cctxt->app_handle, context);
 	}
@@ -1686,9 +1825,16 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 	}
 
 	if (!component_handle || Accessible_getRole (component_handle) == SPI_ROLE_UNKNOWN) {
-		if (component_handle)
+		if (component_handle) {
 			Accessible_unref (component_handle);
-		component_handle = ldtp_get_component_handle (cctxt, window_prop, context, component, err);
+			component_handle = NULL;
+		}
+		if (window_prop) {
+			component_handle = ldtp_get_component_handle (cctxt, window_prop, context, component, err);
+			updated_appmap = TRUE;
+			cur_window = get_object_def (cctxt->app_map, context, NULL, cctxt->log_fp, TRUE);
+			cur_component = get_object_def (cur_window, component, cctxt->parent_name, cctxt->log_fp, FALSE);
+		}
 	}
 
 	if (!component_handle) {
@@ -1709,6 +1855,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			SPI_freeString (name);
 		}
 		Accessible_unref (component_handle);
+		component_handle = NULL;
 		g_print ("Let us try rescan\n");
 		context_handle = get_accessible_context_handle (cctxt->app_handle, window_prop);
 		if (!context_handle) {
@@ -1728,8 +1875,8 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 					goto error;
 				}
 			}
-			cur_window = get_object_def (cctxt->app_map, tmp_context, cctxt->log_fp, TRUE);
-			cur_component = get_object_def (cur_window, component, cctxt->log_fp, FALSE);
+			cur_window = get_object_def (cctxt->app_map, tmp_context, NULL, cctxt->log_fp, TRUE);
+			cur_component = get_object_def (cur_window, component, cctxt->parent_name, cctxt->log_fp, FALSE);
 			g_free (tmp_context);
 			if (!is_object_matching (component_handle, cur_component, cctxt->log_fp)) {
 				name = Accessible_getName (component_handle);
@@ -1738,14 +1885,17 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 					g_print ("%s\n", msg);
 					SPI_freeString (name);
 				}
-				if (component_handle)
+				if (component_handle) {
 					Accessible_unref (component_handle);
+					component_handle = NULL;
+				}
 				*err = LDTP_ERROR_OBJ_INFO_MISMATCH;
 				Accessible_unref (context_handle);
 				goto error;
 			}
 		}
 		Accessible_unref (context_handle);
+		context_handle = NULL;
 	}
 	ctxt_handle->class_id = 0;
 	class = 0;
@@ -1766,6 +1916,12 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 
 	g_print ("Class id: %d\n", ctxt_handle->class_id);
   
+	if (cctxt->req->component) {
+		g_free (cctxt->req->component);
+		cctxt->req->component = NULL;
+		cctxt->req->component = g_strdup (get_property (cur_component, "key", NULL));
+	}
+
 	ctxt_handle->handle = component_handle;
 	*err = LDTP_ERROR_SUCCESS;
 	return ctxt_handle;
@@ -1877,10 +2033,10 @@ get_child_object_type (Accessible *accessible)
 	num_child = Accessible_getChildCount (accessible);
 	if (ldtp_debug) {
 		role_name = Accessible_getRoleName (accessible);
-		g_print ("Child object type: %s\n", role_name);
+		g_print ("Child object type: %s - %ld\n", role_name, num_child);
 		SPI_freeString (role_name);
 	}
-                                                  
+
 	for (i = 0; i < num_child; i++) {
 		child = Accessible_getChildAtIndex (accessible, i);
 		if (!child)
@@ -2014,7 +2170,9 @@ ldtp_gui_wait_till_gui_not_exist (LDTPClientContext* cctxt, LDTPErrorCode* err)
 		time_wait = 30; // Max wait for 30 seconds
 	}
 
+	pthread_mutex_lock (&cb_mutex);
 	accessible = ldtp_gui_get_gui_handle (cctxt, err);
+	pthread_mutex_unlock (&cb_mutex);
 
 	while ((difftime (cur, start) < time_wait) && (accessible != NULL)) {
 		sleep (1);
@@ -2024,7 +2182,9 @@ ldtp_gui_wait_till_gui_not_exist (LDTPClientContext* cctxt, LDTPErrorCode* err)
 			g_free (accessible);
 			accessible = NULL;
 		}
+		pthread_mutex_lock (&cb_mutex);
 		accessible = ldtp_gui_get_gui_handle (cctxt, err);
+		pthread_mutex_unlock (&cb_mutex);
 	}
 
 	if (accessible == NULL)
