@@ -46,9 +46,11 @@ ldtp_request_init (LDTPRequest* req)
 }
 
 /* Finalize handler for the ldtp request component object */
-static void
+void
 ldtp_request_free (LDTPRequest* req, int finalize)
 {
+	if (!req)
+		return;
 	if (req->arg_list) {
 		g_slist_foreach (req->arg_list, (GFunc)g_free, NULL);
 		g_slist_free (req->arg_list);
@@ -57,17 +59,26 @@ ldtp_request_free (LDTPRequest* req, int finalize)
 
 	req->request_type = 0;
 
-	g_free (req->context);
-	req->context = NULL;
+	if (req->context) {
+		g_free (req->context);
+		req->context = NULL;
+	}
   
-	g_free (req->component);
-	req->component = NULL;
+	if (req->component) {
+		g_free (req->component);
+		req->component = NULL;
+	}
 
-	g_free (req->action_name);
-	req->action_name = NULL;
+	if (req->action_name) {
+		g_free (req->action_name);
+		req->action_name = NULL;
+	}
 
-	g_free (req->request_id);
-	req->request_id = NULL;
+	if (req->request_id) {
+		g_free (req->request_id);
+		req->request_id = NULL;
+	}
+	req = NULL;
 }
 
 /**
@@ -90,6 +101,10 @@ ldtp_request_fill_request (LDTPRequest* req, gchar* packet, size_t len, LDTPErro
 	}
 
 	doc = xmlParseMemory (packet, len);
+	if (!doc) {
+		ldtp_log ("Unable to parse XML in memory\n");
+		goto error;
+	}
 	node = xmlDocGetRootElement (doc);
 	if (node == NULL) {
 		ldtp_log ("Empty request\n");
@@ -224,17 +239,15 @@ ldtp_request_fill_request (LDTPRequest* req, gchar* packet, size_t len, LDTPErro
 	   desired order of arguments.
 	*/
 	req->arg_list = g_slist_reverse (req->arg_list);
-	goto success;
+	*err = LDTP_ERROR_SUCCESS;
+	goto cleanup;
 
  error:
 	*err = LDTP_ERROR_PACKET_INVALID;
 	ldtp_request_free (req, 0);
 
-	goto cleanup;
-
- success:
-	*err = LDTP_ERROR_SUCCESS;
  cleanup:
+	xmlCleanupParser ();
 	if (doc)
 		xmlFreeDoc (doc);
 }
