@@ -65,7 +65,7 @@ init_ldtp_server (int server_type)
 	extern gboolean ldtp_script_service;
 
 	if (server_type == LDTP_SCRIPT_SERVER &&
-	    (ldtp_script_service || ldtp_script_port)) {
+	    (ldtp_script_service)) {
 		// get the listener
 		if ((listener = socket (PF_INET, SOCK_STREAM, 0)) == -1) {
 			ldtp_log ("ERROR:socket() failed with \"%s\"\n", strerror(errno));
@@ -87,7 +87,7 @@ init_ldtp_server (int server_type)
 		exit (-1);
 	}
 	if (server_type == LDTP_SCRIPT_SERVER &&
-	    (ldtp_script_service || ldtp_script_port)) {
+	    (ldtp_script_service)) {
 		/*
 		  Puneet Mishra: Palm Source Inc
 		 */
