@@ -19,16 +19,15 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #ifndef _LDTP_SERVER_H
 #define _LDTP_SERVER_H
 
 typedef enum _LDTPServerCode {
-	LDTP_SCRIPT_SERVER,
-	LDTP_RECORD_SERVER
+	LDTP_SCRIPT_SERVER
 } LDTPServerCode;
 
 int init_ldtp_server (int);
