@@ -47,15 +47,23 @@ get_radio_button_state (Accessible *object)
 static gboolean
 is_radio_button_enabled (Accessible *object)
 {
+	AccessibleStateSet *state;
+
 	if (!object)
 		return FALSE;
 	if (wait_till_object_state_contains (object, RADIO_BUTTON, NULL) == -1) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), NULL);
 		return FALSE;
 	}
-	return TRUE;
+	state = Accessible_getStateSet (object);
+
+	/* Verifies it is enabled or not */
+	if (AccessibleStateSet_contains (state, SPI_STATE_ENABLED) == TRUE)
+		return TRUE;
+	else
+		return FALSE;
 }
 
 static LDTPErrorCode
@@ -66,14 +74,14 @@ check_radio_button (Accessible *object, FILE *log_fp)
 	SPIBoolean flag;
 
 	if (wait_till_object_state_contains (object, RADIO_BUTTON, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
  
 	/* Pre verification */
 	if (get_radio_button_state (object) == TRUE) {
-		error =  (LDTP_ERROR_RADIO_BUTTON_ALREADY_CHECKED);
+		error = LDTP_ERROR_RADIO_BUTTON_ALREADY_CHECKED;
 		log_msg (LDTP_LOG_WARNING, ldtp_error_get_message (error), log_fp);
 		return  (LDTP_ERROR_SUCCESS);
 	}
@@ -83,7 +91,7 @@ check_radio_button (Accessible *object, FILE *log_fp)
 	Accessible_unref (action);
 
 	if (flag == FALSE) {
-		error =  (LDTP_ERROR_RADIO_BUTTON_NOT_CHECKED);
+		error = LDTP_ERROR_RADIO_BUTTON_NOT_CHECKED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -94,12 +102,12 @@ check_radio_button (Accessible *object, FILE *log_fp)
 
 	/* Post verification*/
 	if (get_radio_button_state (object) == FALSE) {
-		error =  (LDTP_ERROR_RADIO_BUTTON_NOT_CHECKED);
+		error = LDTP_ERROR_RADIO_BUTTON_NOT_CHECKED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	else
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -107,14 +115,14 @@ verify_check_radio_button (Accessible *object, FILE *log_fp)
 {
 	LDTPErrorCode error;
 	if (wait_till_object_state_contains (object, RADIO_BUTTON, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	if (get_radio_button_state (object))
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_RADIO_BUTTON_NOT_CHECKED);
+		return LDTP_ERROR_RADIO_BUTTON_NOT_CHECKED;
 }
 
 static LDTPErrorCode
@@ -122,14 +130,14 @@ verify_uncheck_radio_button (Accessible *object, FILE *log_fp)
 {
 	LDTPErrorCode error;
 	if (wait_till_object_state_contains (object, RADIO_BUTTON, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	if (get_radio_button_state (object))
-		return  (LDTP_ERROR_RADIO_BUTTON_CHECKED);
+		return LDTP_ERROR_RADIO_BUTTON_CHECKED;
 	else
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 }
 
 /*
@@ -143,7 +151,7 @@ click (Accessible *object, FILE *log_fp)
 	AccessibleAction *action;
 
 	if (wait_till_object_state_contains (object, RADIO_BUTTON, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -153,9 +161,9 @@ click (Accessible *object, FILE *log_fp)
 	Accessible_unref (action);
 
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
-		error =  (LDTP_ERROR_CLICK_FAILED);
+		error = LDTP_ERROR_CLICK_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -171,9 +179,9 @@ radio_button_main (LDTPClientContext* cctxt, int command)
 		break;
 	case LDTP_CMD_STATEENABLED:
 		if (is_radio_button_enabled (cctxt->gui_handle->handle))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_RADIO_BUTTON_STATE_NOT_ENABLED);
+			error = LDTP_ERROR_RADIO_BUTTON_STATE_NOT_ENABLED;
 		break;
 	case LDTP_CMD_CHECK:
 	case LDTP_CMD_MENUCHECK:
@@ -186,8 +194,7 @@ radio_button_main (LDTPClientContext* cctxt, int command)
 		error = verify_uncheck_radio_button (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
