@@ -31,6 +31,24 @@
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
+static LDTPErrorCode
+is_menu_item_enabled (Accessible *object, FILE *log_fp)
+{
+	SPIBoolean enabled;
+	AccessibleStateSet *state;
+
+	state = Accessible_getStateSet (object);
+	enabled = AccessibleStateSet_contains (state, SPI_STATE_SENSITIVE);
+	if (enabled)
+		return LDTP_ERROR_SUCCESS;
+	else {
+		LDTPErrorCode error;
+		error = LDTP_ERROR_MENU_ITEM_STATE_DISABLED;
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+		return error;
+	}
+}
+
 /*
   Get the state of given object
 */
@@ -60,7 +78,7 @@ click (Accessible *object, FILE *log_fp)
 	AccessibleAction *action;
 	
 	if (wait_till_object_state_contains (object, RADIO_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -70,10 +88,10 @@ click (Accessible *object, FILE *log_fp)
 	Accessible_unref (action);
 
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
 		{
-			error =  (LDTP_ERROR_CLICK_FAILED);
+			error = LDTP_ERROR_CLICK_FAILED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
@@ -86,7 +104,7 @@ check_radio_menu_item (Accessible *object, FILE *log_fp)
 	AccessibleAction *action;
 
 	if (wait_till_object_state_contains (object, RADIO_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -99,16 +117,16 @@ check_radio_menu_item (Accessible *object, FILE *log_fp)
 		flag = AccessibleAction_doAction (action, 0);
 		Accessible_unref (action);
 		if (flag == FALSE) {
-			error =  (LDTP_ERROR_RADIO_MENU_ITEM_NOT_CHECKED);
+			error = LDTP_ERROR_RADIO_MENU_ITEM_NOT_CHECKED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
 	}
 	else {
-		error =  (LDTP_ERROR_RADIO_MENU_ITEM_ALREADY_CHECKED);
+		error = LDTP_ERROR_RADIO_MENU_ITEM_ALREADY_CHECKED;
 		log_msg (LDTP_LOG_WARNING, ldtp_error_get_message (error), log_fp);
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -116,7 +134,7 @@ verify_check_radio_menu_item (Accessible *object, FILE *log_fp)
 {
 	LDTPErrorCode error;
 	if (wait_till_object_state_contains (object, RADIO_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -124,11 +142,11 @@ verify_check_radio_menu_item (Accessible *object, FILE *log_fp)
 	  If state is not checked then check it
 	*/
 	if (get_state (object) == FALSE) {
-		error =  (LDTP_ERROR_RADIO_MENU_ITEM_NOT_CHECKED);
+		error = LDTP_ERROR_RADIO_MENU_ITEM_NOT_CHECKED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -136,7 +154,7 @@ verify_uncheck_radio_menu_item (Accessible *object, FILE *log_fp)
 {
 	LDTPErrorCode error;
 	if (wait_till_object_state_contains (object, RADIO_MENU_ITEM, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -144,11 +162,11 @@ verify_uncheck_radio_menu_item (Accessible *object, FILE *log_fp)
 	  If state is not checked then check it
 	*/
 	if (get_state (object) == TRUE) {
-		error =  (LDTP_ERROR_RADIO_MENU_ITEM_ALREADY_CHECKED);
+		error = LDTP_ERROR_RADIO_MENU_ITEM_ALREADY_CHECKED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 LDTPErrorCode
@@ -159,6 +177,9 @@ radio_menu_item_main (LDTPClientContext* cctxt, int command)
 	case LDTP_CMD_CLICK:
 		error = click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
+	case LDTP_CMD_MENUITEMENABLED:
+		error = is_menu_item_enabled (cctxt->gui_handle->handle, cctxt->log_fp);
+		break;
 	case LDTP_CMD_SELECTMENUITEM:
 		error = click (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
@@ -172,8 +193,7 @@ radio_menu_item_main (LDTPClientContext* cctxt, int command)
 		error = verify_uncheck_radio_menu_item (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
