@@ -230,6 +230,7 @@ search_reverse (const gchar *text, gchar delimiter)
 static char*
 get_keybinding (Accessible *object)
 {
+	char *tmp = NULL;
 	char *binding = NULL;
 	char *key_binding = NULL;
 	AccessibleAction *action = NULL;
@@ -239,10 +240,16 @@ get_keybinding (Accessible *object)
 	action = Accessible_getAction (object);
 	if (!action)
 		return NULL;
-	binding = g_strdup (AccessibleAction_getKeyBinding (action, 0l));
+	tmp = AccessibleAction_getKeyBinding (action, 0l);
+	if (tmp) {
+		binding = g_strdup (tmp);
+		SPI_freeString (tmp);
+	}
 	Accessible_unref (action);
 
-	if (!binding || g_utf8_collate (binding, "") == 0) {
+	if (!binding)
+		return NULL;
+	if (g_utf8_collate (binding, "") == 0) {
 		g_free (binding);
 		return NULL;
 	}
@@ -734,7 +741,7 @@ get_object_info (Accessible *accessible)
  * This function creates entry in the Appmap file corresponding to the object passed to it
  */
 static char*
-add_appmap_data (Accessible *accessible, char *parent_name, int child_index,
+add_appmap_data (Accessible *accessible, char *parent_name, long child_index,
 		 GHashTable *current_context, gboolean overloadedWindowName,
 		 gboolean remap_context)
 {
@@ -767,8 +774,10 @@ add_appmap_data (Accessible *accessible, char *parent_name, int child_index,
 		accessible_name = g_strdup (parent_name);
 	} else {
 		char *tmp_accessible_name = Accessible_getName (accessible);
-		accessible_name = g_strdup (tmp_accessible_name);
-		SPI_freeString (tmp_accessible_name);
+		if (tmp_accessible_name) {
+			accessible_name = g_strdup (tmp_accessible_name);
+			SPI_freeString (tmp_accessible_name);
+		}
 	}
 
 	accessible_desc = Accessible_getDescription (accessible);
@@ -999,8 +1008,12 @@ add_appmap_data (Accessible *accessible, char *parent_name, int child_index,
 	}
 	if (filter_appmap_data (accessible, cur_obj_info, name)) {
 		hash_attributes = g_hash_table_new_full (&g_str_hash, &g_str_equal,
-							 key_destroy_func, value_destroy_func);
+							 destroy_string, destroy_string);
 		if (hash_attributes) {
+			GHashTable *tmp_parent_table = NULL;
+			g_hash_table_insert (hash_attributes,
+					     g_strdup ("key"),
+					     g_strdup (name));
 			if (cur_obj_info->object_type)
 				g_hash_table_insert (hash_attributes,
 						     g_strdup ("class"),
@@ -1009,9 +1022,27 @@ add_appmap_data (Accessible *accessible, char *parent_name, int child_index,
 				g_hash_table_insert (hash_attributes,
 						     g_strdup ("parent"),
 						     g_strdup (tmp_parent_name));
+			if ((tmp_parent_table = g_hash_table_lookup (current_context, tmp_parent_name)) != NULL) {
+				if (tmp_parent_table) {
+					gchar *childrens = NULL;
+					if (g_hash_table_lookup_extended (tmp_parent_table, "childrens", NULL, (gpointer) &childrens)) {
+						childrens = g_strdup_printf ("%s %s", childrens, name);
+						if (childrens) {
+							g_print ("Childrens: %s\n", childrens);
+							//g_hash_table_remove (tmp_parent_table, "childrens");
+							g_hash_table_replace (tmp_parent_table, g_strdup ("childrens"), childrens);
+						} else
+							g_print ("Unable to create childrens");
+					} else {
+						g_hash_table_insert (tmp_parent_table, g_strdup ("childrens"), g_strdup (name));
+					}
+				} else
+					g_print ("Parent table NULL\n");
+			} else
+				g_print ("Unable to find parent\n");
 			g_hash_table_insert (hash_attributes,
 					     g_strdup ("child_index"),
-					     g_strdup_printf ("%d", child_index));
+					     g_strdup_printf ("%ld", child_index));
 			if (g_ascii_strcasecmp (label, "") != 0 && cur_obj_info->object_type &&
 			    (g_ascii_strcasecmp (cur_obj_info->object_type,
 						 "combo_box") != 0 &&
@@ -1021,7 +1052,7 @@ add_appmap_data (Accessible *accessible, char *parent_name, int child_index,
 						     g_strdup ("label"),
 						     g_strdup (label));
 			} else {
-				if (label_by) {
+				if (label_by && g_ascii_strcasecmp (label_by, "") != 0 ) {
 					g_hash_table_insert (hash_attributes, g_strdup ("label_by"), g_strdup (label_by));
 				}
 			}
@@ -1041,7 +1072,8 @@ add_appmap_data (Accessible *accessible, char *parent_name, int child_index,
 				g_hash_table_insert (current_context, g_strdup (name), hash_attributes);
 			}
 			g_print ("Added: %s to current_context\n", name);
-		}
+		} else
+			g_hash_table_destroy (hash_attributes);
 		g_free (label);
 		g_free (label_by);
 		g_free (cur_obj_info->object_type);
@@ -1131,7 +1163,8 @@ accessible_object_handle (Accessible *accessible, char *parent_name,
 						  remap_context);
 			Accessible_unref (child);
 		}
-		g_free (current_parent);
+		if (current_parent && parent_name && current_parent != parent_name)
+			g_free (current_parent);
 	}
 }
 
@@ -1167,8 +1200,10 @@ get_window_name_in_appmap_format (char *window_name, AccessibleRole role)
 		}
 		if (type && stripped_data)
 			retval = g_strdup_printf ("%s%s", type, stripped_data);
-		g_free (type);
-		g_free (stripped_data);
+		if (type)
+			g_free (type);
+		if (stripped_data)
+			g_free (stripped_data);
 		return retval;
 	}
 	g_free (type);
@@ -1192,7 +1227,7 @@ GHashTable *do_remap (Accessible *accessible_context, char *name, GHashTable *co
 					  context, overloadedWindowName, remap_context);
 		return NULL;
 	}
-	current_context = g_hash_table_new (&g_str_hash, &g_str_equal);
+	current_context = g_hash_table_new_full (&g_str_hash, &g_str_equal, destroy_string, destroy_hashtable);
 	if (context_attributes) {
 		if (ldtp_debug)
 			g_print ("Context Attributes NOT NULL - FLAG: %d\n", overloadedWindowName);
