@@ -37,7 +37,7 @@ is_object_scroll_bar (Accessible *object, FILE *log_fp)
 {
 	if (wait_till_object_state_contains (object, SCROLL_BAR, log_fp) != 0) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return FALSE;
 	}
@@ -100,7 +100,7 @@ scroll_up (Accessible *object, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -114,10 +114,10 @@ scroll_up (Accessible *object, FILE *log_fp)
 	Accessible_unref (value);
 	Accessible_unref (child);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE);
+		error = LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -153,7 +153,7 @@ scroll_down (Accessible *object, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -168,10 +168,10 @@ scroll_down (Accessible *object, FILE *log_fp)
 	Accessible_unref (value);
 	Accessible_unref (child);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE);
+		error = LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -207,7 +207,7 @@ scroll_left (Accessible *object, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -223,10 +223,10 @@ scroll_left (Accessible *object, FILE *log_fp)
 	Accessible_unref (child);
 
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE);
+		error = LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -263,7 +263,7 @@ scroll_right (Accessible *object, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -282,10 +282,10 @@ scroll_right (Accessible *object, FILE *log_fp)
 	Accessible_unref (child);
 
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE);
+		error = LDTP_ERROR_UNABLE_TO_SCROLL_WITH_GIVEN_VALUE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -323,7 +323,7 @@ one_down (Accessible *object, int num, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -339,7 +339,7 @@ one_down (Accessible *object, int num, FILE *log_fp)
 		val = val + max;
 		if (val > (max * 8)) {
 			LDTPErrorCode error;
-			error =  (LDTP_ERROR_SCROLL_BAR_MAX_REACHED);
+			error = LDTP_ERROR_SCROLL_BAR_MAX_REACHED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			Accessible_unref (value);
 			Accessible_unref (child);
@@ -356,7 +356,7 @@ one_down (Accessible *object, int num, FILE *log_fp)
 	}
 	Accessible_unref (value);
 	Accessible_unref (child);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -390,7 +390,7 @@ one_up (Accessible *object, int num, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -400,12 +400,12 @@ one_up (Accessible *object, int num, FILE *log_fp)
 	max = AccessibleValue_getMaximumValue (value);
 	max = max / 8;
 
-	while(j <= num) {   
+	while (j <= num) {
 		val = AccessibleValue_getCurrentValue (value);
 		val = val - max;
 		if (val < 0) {
 			LDTPErrorCode error;
-			error =  (LDTP_ERROR_SCROLL_BAR_MIN_REACHED);
+			error = LDTP_ERROR_SCROLL_BAR_MIN_REACHED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			Accessible_unref (value);
 			Accessible_unref (child);
@@ -422,7 +422,7 @@ one_up (Accessible *object, int num, FILE *log_fp)
 	}
 	Accessible_unref (value);
 	Accessible_unref (child);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -457,7 +457,7 @@ one_right (Accessible *object, int num, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -473,7 +473,7 @@ one_right (Accessible *object, int num, FILE *log_fp)
 		val = val + max;
 		if (val > (max * 8)) {
 			LDTPErrorCode error;
-			error =  (LDTP_ERROR_SCROLL_BAR_MAX_REACHED);
+			error = LDTP_ERROR_SCROLL_BAR_MAX_REACHED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			Accessible_unref (value);
 			Accessible_unref (child);
@@ -491,7 +491,7 @@ one_right (Accessible *object, int num, FILE *log_fp)
 
 	Accessible_unref (value);
 	Accessible_unref (child);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -525,7 +525,7 @@ one_left (Accessible *object, int num, FILE *log_fp)
 
 	if (changeflag == FALSE) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR);
+		error = LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		if (child)
 			Accessible_unref (child);
@@ -541,7 +541,7 @@ one_left (Accessible *object, int num, FILE *log_fp)
 		val = val - max;
 		if (val < 0) {
 			LDTPErrorCode error;
-			error =  (LDTP_ERROR_SCROLL_BAR_MIN_REACHED);
+			error = LDTP_ERROR_SCROLL_BAR_MIN_REACHED;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			Accessible_unref (value);
 			Accessible_unref (child);
@@ -558,7 +558,7 @@ one_left (Accessible *object, int num, FILE *log_fp)
 	}
 	Accessible_unref (value);
 	Accessible_unref (child);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 LDTPErrorCode
@@ -568,32 +568,32 @@ scroll_bar_main (LDTPClientContext* cctxt, int command)
 	switch (command) {
 	case LDTP_CMD_VERIFYSCROLLBAR:
 		if (is_object_scroll_bar (cctxt->gui_handle->handle, cctxt->log_fp))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+			error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		break;
 	case LDTP_CMD_VERIFYSCROLLBARVERTICAL:
 		if (is_scroll_bar_vertical (cctxt->gui_handle->handle))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR);
+			error = LDTP_ERROR_NOT_VERTICAL_SCROLL_BAR;
 		break;
 	case LDTP_CMD_VERIFYSCROLLBARHORIZONTAL:
 		if (is_scroll_bar_horizontal (cctxt->gui_handle->handle))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR);
+			error = LDTP_ERROR_NOT_HORIZONTAL_SCROLL_BAR;
 		break;
-	case LDTP_CMD_SCROLLUP: 
+	case LDTP_CMD_SCROLLUP:
 		error = scroll_up (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
-	case LDTP_CMD_SCROLLDOWN: 
+	case LDTP_CMD_SCROLLDOWN:
 		error = scroll_down (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
-	case LDTP_CMD_SCROLLLEFT: 
+	case LDTP_CMD_SCROLLLEFT:
 		error = scroll_left (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
-	case LDTP_CMD_SCROLLRIGHT: 
+	case LDTP_CMD_SCROLLRIGHT:
 		error = scroll_right (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	case LDTP_CMD_ONEUP: {
@@ -625,8 +625,7 @@ scroll_bar_main (LDTPClientContext* cctxt, int command)
 		break;
 	}
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
