@@ -37,7 +37,7 @@ is_object_slider (Accessible *object, FILE *log_fp)
 {
 	if (wait_till_object_state_contains (object, SLIDER, log_fp) != 0) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return FALSE;
 	}
@@ -85,7 +85,7 @@ set_max (Accessible *object, FILE *log_fp)
 		val = AccessibleValue_getMaximumValue (value); 
 	}
 	else {
-		error =  (LDTP_ERROR_SLIDER_SET_MAX_FAILED);
+		error = LDTP_ERROR_SLIDER_SET_MAX_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -96,9 +96,9 @@ set_max (Accessible *object, FILE *log_fp)
 	flag = AccessibleValue_setCurrentValue (value, val);
 	Accessible_unref (value);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
-		error =  (LDTP_ERROR_SLIDER_SET_MAX_FAILED);
+		error = LDTP_ERROR_SLIDER_SET_MAX_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -113,7 +113,7 @@ set_min (Accessible *object, FILE *log_fp)
 	SPIBoolean flag;
 
 	if (is_object_slider (object, log_fp) == FALSE) {
-		error =  (LDTP_ERROR_SLIDER_SET_MIN_FAILED);
+		error = LDTP_ERROR_SLIDER_SET_MIN_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -126,9 +126,9 @@ set_min (Accessible *object, FILE *log_fp)
 	flag = AccessibleValue_setCurrentValue (value, val);
 	Accessible_unref (value);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
-		error =  (LDTP_ERROR_SLIDER_SET_MIN_FAILED);
+		error = LDTP_ERROR_SLIDER_SET_MIN_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -168,7 +168,7 @@ decrease (Accessible *object, int num, FILE *log_fp)
 			if (val < min) {
 				log_msg (LDTP_LOG_CAUSE, "Reached minimum limit", log_fp);
 				Accessible_unref (value);
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 			}
 			/*
 			  Decrease the value of the slider
@@ -181,10 +181,10 @@ decrease (Accessible *object, int num, FILE *log_fp)
 	}
 	Accessible_unref (value);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_UNABLE_TO_DECREASE_SLIDER_VALUE);
+		error = LDTP_ERROR_UNABLE_TO_DECREASE_SLIDER_VALUE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -209,7 +209,7 @@ increase (Accessible *object, int num, FILE *log_fp)
 			if (val > (max * 8)) {
 				log_msg (LDTP_LOG_WARNING, "Reached maximum limit", log_fp);
 				Accessible_unref (value);
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 			}
 			/*
 			  Increase the value of the slider
@@ -222,10 +222,10 @@ increase (Accessible *object, int num, FILE *log_fp)
 	}
 	Accessible_unref (value);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_UNABLE_TO_INCREASE_SLIDER_VALUE);
+		error = LDTP_ERROR_UNABLE_TO_INCREASE_SLIDER_VALUE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -238,21 +238,21 @@ slider_main (LDTPClientContext* cctxt, int command)
 	switch (command) {
 	case LDTP_CMD_VERIFYSLIDER:
 		if (is_object_slider (cctxt->gui_handle->handle, cctxt->log_fp))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+			error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		break;
 	case LDTP_CMD_VERIFYSLIDERVERTICAL:
 		if (is_slider_vertical (cctxt->gui_handle->handle))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_NOT_VERTICAL_SLIDER);
+			error = LDTP_ERROR_NOT_VERTICAL_SLIDER;
 		break;
 	case LDTP_CMD_VERIFYSLIDERHORIZONTAL:
 		if (is_slider_horizontal (cctxt->gui_handle->handle))
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		else
-			error =  (LDTP_ERROR_NOT_HORIZONTAL_SLIDER);
+			error = LDTP_ERROR_NOT_HORIZONTAL_SLIDER;
 		break;
 	case LDTP_CMD_SETMAX:
 		error = set_max (cctxt->gui_handle->handle, cctxt->log_fp);
@@ -266,10 +266,10 @@ slider_main (LDTPClientContext* cctxt, int command)
 		if (current_val != -1) {
 			cctxt->resp->data = g_strdup_printf ("%lf", current_val);
 			cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		}
 		else {
-			error =  (LDTP_ERROR_UNABLE_TO_GET_SLIDER_VALUE);
+			error = LDTP_ERROR_UNABLE_TO_GET_SLIDER_VALUE;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		}
 		break;
@@ -289,7 +289,7 @@ slider_main (LDTPClientContext* cctxt, int command)
 		break;
 	}
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
