@@ -38,9 +38,9 @@ is_text_state_enabled (Accessible *object, FILE *log_fp)
 	state = Accessible_getStateSet (object);
 
 	if (AccessibleStateSet_contains (state, SPI_STATE_EDITABLE))
-		error =  (LDTP_ERROR_SUCCESS);
+		error = LDTP_ERROR_SUCCESS;
 	else
-		error = (LDTP_ERROR_TEXT_STATE_NOT_ENABLED);
+		error = LDTP_ERROR_TEXT_STATE_NOT_ENABLED;
 	log_msg (LDTP_LOG_INFO, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -63,16 +63,17 @@ set_text_value (Accessible *object, char *text, FILE *log_fp)
 		Accessible_unref (editableText);
 		if (flag == FALSE) {
 			g_print ("%s - %d\n", __FILE__, __LINE__);
-			error =  (LDTP_ERROR_UNABLE_TO_SET_TEXT);
+			error = LDTP_ERROR_UNABLE_TO_SET_TEXT;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
+	} else {
+		g_print ("%s - %d\n", __FILE__, __LINE__);
+		error = LDTP_ERROR_UNABLE_TO_SET_TEXT;
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+		return error;
 	}
-	g_print ("%s - %d\n", __FILE__, __LINE__);
-	error =  (LDTP_ERROR_UNABLE_TO_SET_TEXT);
-	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
-	return error;
 }
 
 static LDTPErrorCode
@@ -94,21 +95,21 @@ cut_text (Accessible *object, int startpos, int endpos, FILE *log_fp)
 				}
 				else {
 					Accessible_unref (editableText);
-					return  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+					return LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 				}					
 			}
 			flag = AccessibleEditableText_cutText (editableText, startpos, endpos);
 			Accessible_unref (editableText);
 			if (flag)
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 			else {
-				error =  (LDTP_ERROR_UNABLE_TO_CUT_TEXT);
+				error = LDTP_ERROR_UNABLE_TO_CUT_TEXT;
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 				return error;
 			}
 		}
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_CUT_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_CUT_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 } 
@@ -155,11 +156,11 @@ activate_text (Accessible *object, FILE *log_fp)
 	if (result)
 		g_print ("Activate: success\n");
 	else {
-		error =  (LDTP_ERROR_UNABLE_TO_ACTIVATE_TEXT);
+		error = LDTP_ERROR_UNABLE_TO_ACTIVATE_TEXT;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -174,14 +175,14 @@ paste_text (Accessible *object, long pos, FILE *log_fp)
 		flag = AccessibleEditableText_pasteText (editableText, pos);
 		Accessible_unref (editableText);
 		if (flag)
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 		else {
-			error =  (LDTP_ERROR_UNABLE_TO_PASTE_TEXT);
+			error = LDTP_ERROR_UNABLE_TO_PASTE_TEXT;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_PASTE_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_PASTE_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -205,21 +206,21 @@ delete_text (Accessible *object, long startpos, long endpos, FILE *log_fp)
 				}
 				else {
 					Accessible_unref (editableText);
-					return  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+					return LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 				}
 			}
 			flag = AccessibleEditableText_deleteText (editableText, startpos, endpos);
 			Accessible_unref (editableText);
 			if (flag)
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 			else {
-				error =  (LDTP_ERROR_UNABLE_TO_DELETE_TEXT);
+				error = LDTP_ERROR_UNABLE_TO_DELETE_TEXT;
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 				return error;
 			}
 		}
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_DELETE_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_DELETE_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -245,21 +246,21 @@ select_text_by_index_and_region (Accessible *object, long startpos,
 				}
 				else {
 					Accessible_unref (editableText);
-					return  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+					return LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 				}
 			}
 			flag = AccessibleText_setSelection (editableText, selection_num, startpos, endpos);
 			Accessible_unref (editableText);
 			if (flag)
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 			else {
-				error =  (LDTP_ERROR_UNABLE_TO_SELECT_TEXT);
+				error = LDTP_ERROR_UNABLE_TO_SELECT_TEXT;
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 				return error;
 			}
 		}
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_SELECT_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_SELECT_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -273,15 +274,15 @@ select_text_by_name (Accessible *object, FILE *log_fp)
 
 	text = Accessible_getText (object);
 	if (!text) {
-		error =  (LDTP_ERROR_UNABLE_TO_SELECT_TEXT);
+		error = LDTP_ERROR_UNABLE_TO_SELECT_TEXT;
 		return error;
 	}
 	flag = AccessibleText_addSelection (text, 0,
 					    AccessibleText_getCharacterCount (text));
 	if (flag)
-		error =  (LDTP_ERROR_SUCCESS);
+		error = LDTP_ERROR_SUCCESS;
 	else {
-		error = (LDTP_ERROR_UNABLE_TO_SELECT_TEXT_ITEM);
+		error = LDTP_ERROR_UNABLE_TO_SELECT_TEXT_ITEM;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	}
 	Accessible_unref (text);
@@ -314,13 +315,13 @@ append_text (Accessible *object, char *text, FILE *log_fp)
 	LDTPErrorCode error;
 	char *available_text = NULL;
 	if (text == NULL) {
-		error =  (LDTP_ERROR_ARGUMENT_NULL);
+		error = LDTP_ERROR_ARGUMENT_NULL;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	available_text = get_text_value (object);
 	if (!available_text) {
-		error =  (LDTP_ERROR_UNABLE_TO_APPEND_TEXT);
+		error = LDTP_ERROR_UNABLE_TO_APPEND_TEXT;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -330,7 +331,7 @@ append_text (Accessible *object, char *text, FILE *log_fp)
 	free (tmp);
 	if (error == LDTP_ERROR_SUCCESS)
 		return error;
-	error =  (LDTP_ERROR_UNABLE_TO_APPEND_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_APPEND_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -349,7 +350,7 @@ verify_set_text_value (Accessible *object, char *verify_text, FILE *log_fp)
 		g_print ("Text: %s\n", text);
 	}
 	else {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -358,13 +359,13 @@ verify_set_text_value (Accessible *object, char *verify_text, FILE *log_fp)
 	    g_utf8_collate (verify_text, text) != 0) {
 		LDTPErrorCode error;
 		SPI_freeString (text);
-		error =  (LDTP_ERROR_VERIFY_SET_TEXT_FAILED);
+		error = LDTP_ERROR_VERIFY_SET_TEXT_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	else
 		SPI_freeString (text);
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -378,7 +379,7 @@ verify_partial_match (Accessible *object, char *textvalue, FILE *log_fp)
 	sub = textvalue;
 	accessibleText = Accessible_getText (object);
 	if (accessibleText == NULL) {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -390,9 +391,9 @@ verify_partial_match (Accessible *object, char *textvalue, FILE *log_fp)
 		for(j = i, k=0; sub && sub[k] != '\0' && tmp[j] == sub[k] ; j++ , k++) 
 			; /* Do nothing */
 		if( k > 0 && sub[k] == '\0')
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 	}
-	error =  (LDTP_ERROR_VERIFY_PARTIAL_MATCH_FAILED);
+	error = LDTP_ERROR_VERIFY_PARTIAL_MATCH_FAILED;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -409,7 +410,7 @@ get_text (Accessible *object, GSList **l)
 	
 	accessibleText = Accessible_getText (object);
 	if (accessibleText == NULL) {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		return error;
 	}
 
@@ -429,10 +430,10 @@ get_text (Accessible *object, GSList **l)
 		*l = g_slist_prepend (*l, g_strdup (tmp));
 		g_print ("GetTextValue: %s\n", tmp);
 		SPI_freeString (tmp);
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	}
 	else
-		return  (LDTP_ERROR_GETTEXTVALUE_FAILED);
+		return LDTP_ERROR_GETTEXTVALUE_FAILED;
 }
 
 static long
@@ -476,34 +477,34 @@ set_cursor_position (LDTPClientContext *cctxt)
 	FILE *log_fp = cctxt->log_fp;
 
 	if (!cctxt->req->arg_list || !cctxt->req->arg_list->data) {
-		error =  (LDTP_ERROR_ARGUMENT_NULL);
+		error = LDTP_ERROR_ARGUMENT_NULL;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	offset = atol (cctxt->req->arg_list->data);
 	count = get_character_count (cctxt->gui_handle->handle);
 	if (count < offset) {
-		error =  (LDTP_ERROR_OFFSET_OUT_OF_BOUND);
+		error = LDTP_ERROR_OFFSET_OUT_OF_BOUND;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 
 	accessibleText = Accessible_getText (cctxt->gui_handle->handle);
 	if (accessibleText == NULL) {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	
 	flag = AccessibleText_setCaretOffset (accessibleText, offset);
 	if (flag == FALSE) {
-		error =  (LDTP_ERROR_UNABLE_TO_SET_CARET);
+		error = LDTP_ERROR_UNABLE_TO_SET_CARET;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	Accessible_unref (accessibleText);
 
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -525,21 +526,21 @@ copy_text (Accessible *object, int startpos, int endpos, FILE *log_fp)
 				}
 				else {
 					Accessible_unref (editableText);
-					return  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+					return LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 				}					
 			}
 			flag = AccessibleEditableText_copyText (editableText, startpos, endpos);
 			Accessible_unref (editableText);
 			if (flag)
-				return  (LDTP_ERROR_SUCCESS);
+				return LDTP_ERROR_SUCCESS;
 			else {
-				error =  (LDTP_ERROR_UNABLE_TO_COPY_TEXT);
+				error = LDTP_ERROR_UNABLE_TO_COPY_TEXT;
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 				return error;
 			}
 		}
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_COPY_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_COPY_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -553,7 +554,7 @@ insert_text (Accessible *object, char *text, int pos, FILE *log_fp)
 	long present_length = 0;
 	
 	if (text == NULL) {
-		error =  (LDTP_ERROR_TEXT_TO_INSERT_IS_EMPTY);
+		error = LDTP_ERROR_TEXT_TO_INSERT_IS_EMPTY;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -569,9 +570,9 @@ insert_text (Accessible *object, char *text, int pos, FILE *log_fp)
 		flag = AccessibleEditableText_insertText (editableText, pos, text, len);
 		Accessible_unref (editableText);
 		if (flag == TRUE)
-			return  (LDTP_ERROR_SUCCESS);
+			return LDTP_ERROR_SUCCESS;
 	}
-	error =  (LDTP_ERROR_UNABLE_TO_INSERT_TEXT);
+	error = LDTP_ERROR_UNABLE_TO_INSERT_TEXT;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -589,7 +590,7 @@ get_text_property (Accessible *object, GSList **l, FILE *log_fp)
 	
 	accessibleText = Accessible_getText (object);
 	if (accessibleText == NULL) {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -617,7 +618,7 @@ get_text_property (Accessible *object, GSList **l, FILE *log_fp)
 		*l = g_slist_prepend (*l, g_strdup (text_prop));
 		SPI_freeString (text_prop);
 		Accessible_unref (accessibleText);
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	}
 	else {
 		LDTPErrorCode error;
@@ -626,7 +627,7 @@ get_text_property (Accessible *object, GSList **l, FILE *log_fp)
 		   to actual parameters in LDTPRequest structure.
 		*/
 		Accessible_unref (accessibleText);
-		error =  (LDTP_ERROR_UNABLE_TO_GET_TEXT_PROPERTY);
+		error = LDTP_ERROR_UNABLE_TO_GET_TEXT_PROPERTY;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -650,7 +651,7 @@ compare_text_property (Accessible *object, GSList *l, FILE *log_fp)
 
 	accessibleText = Accessible_getText (object);
 	if (accessibleText == NULL) {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -713,14 +714,14 @@ compare_text_property (Accessible *object, GSList *l, FILE *log_fp)
 		Accessible_unref (accessibleText);
 
 		if (total == 0 && flag == FALSE)
-			return  (LDTP_ERROR_SUCCESS);
-		error =  (LDTP_ERROR_ONE_OR_MORE_PROPERTIES_DOES_NOT_MATCH);
+			return LDTP_ERROR_SUCCESS;
+		error = LDTP_ERROR_ONE_OR_MORE_PROPERTIES_DOES_NOT_MATCH;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 	g_free (specimen_prop);
 	Accessible_unref (accessibleText);
-	error =  (LDTP_ERROR_UNABLE_TO_GET_TEXT_PROPERTY);
+	error = LDTP_ERROR_UNABLE_TO_GET_TEXT_PROPERTY;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -742,7 +743,7 @@ contains_text_property (Accessible *object, GSList *l, FILE *log_fp)
 
 	accessibleText = Accessible_getText (object);
 	if (accessibleText == NULL) {
-		error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+		error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -786,7 +787,7 @@ contains_text_property (Accessible *object, GSList *l, FILE *log_fp)
 					g_hash_table_destroy (property_table);
 					SPI_freeString (text_prop);
 					log_msg (LDTP_LOG_INFO, "Property matches", log_fp);
-					return  (LDTP_ERROR_SUCCESS);
+					return LDTP_ERROR_SUCCESS;
 				}
 				else {
 					g_free (property);
@@ -794,7 +795,7 @@ contains_text_property (Accessible *object, GSList *l, FILE *log_fp)
 					Accessible_unref (accessibleText);
 					g_hash_table_destroy (property_table);
 					SPI_freeString (text_prop);
-					error =  (LDTP_ERROR_TEXT_OBJECT_VALUE_CONTAINS_DIFF_PROEPRTY);
+					error = LDTP_ERROR_TEXT_OBJECT_VALUE_CONTAINS_DIFF_PROEPRTY;
 					log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 					return error;
 				}
@@ -804,7 +805,7 @@ contains_text_property (Accessible *object, GSList *l, FILE *log_fp)
 				g_free (prop_key);
 				Accessible_unref (accessibleText);
 				SPI_freeString (text_prop);
-				error =  (LDTP_ERROR_TEXT_OBJECT_DOES_NOT_CONTAIN_PROEPRTY);
+				error = LDTP_ERROR_TEXT_OBJECT_DOES_NOT_CONTAIN_PROEPRTY;
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 				return error;
 			}
@@ -813,7 +814,7 @@ contains_text_property (Accessible *object, GSList *l, FILE *log_fp)
 			g_free (property);
 			Accessible_unref (accessibleText);
 			SPI_freeString (text_prop);
-			error =  (LDTP_ERROR_TEXT_PROEPRTY_VALUE_PAIR_IS_INVALID);
+			error = LDTP_ERROR_TEXT_PROEPRTY_VALUE_PAIR_IS_INVALID;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 			return error;
 		}
@@ -821,7 +822,7 @@ contains_text_property (Accessible *object, GSList *l, FILE *log_fp)
 	else {
 		g_free (property);
 		Accessible_unref (accessibleText);
-		error =  (LDTP_ERROR_UNABLE_TO_GET_TEXT_PROPERTY);
+		error = LDTP_ERROR_UNABLE_TO_GET_TEXT_PROPERTY;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -846,9 +847,9 @@ right_click (Accessible *object)
 		Accessible_unref (accessible_component);
 	}
 	if (flag && SPI_generateMouseEvent (x + width / 2, y + height / 2, "b3c"))
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else
-		return  (LDTP_ERROR_RIGHT_CLICK_FAILED);
+		return LDTP_ERROR_RIGHT_CLICK_FAILED;
 }
 
 LDTPErrorCode
@@ -927,10 +928,9 @@ text_main (LDTPClientContext* cctxt, int command)
 							 endpos, cctxt->log_fp);
 		break;
 	}
-	case LDTP_CMD_SELECTTEXTBYNAME: {
+	case LDTP_CMD_SELECTTEXTBYNAME:
 		error = select_text_by_name (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
-	}
 	case LDTP_CMD_APPENDTEXT:
 		if (cctxt->req->arg_list == NULL || cctxt->req->arg_list->data == NULL)
 			error = append_text (cctxt->gui_handle->handle,
@@ -956,7 +956,7 @@ text_main (LDTPClientContext* cctxt, int command)
 				cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
 				cctxt->req->arg_list = g_slist_remove (cctxt->req->arg_list, cctxt->req->arg_list->data);
 			} else {
-				error =  (LDTP_ERROR_GETTEXTVALUE_FAILED);
+				error = LDTP_ERROR_GETTEXTVALUE_FAILED;
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 				return error;
 			}
@@ -1038,12 +1038,11 @@ text_main (LDTPClientContext* cctxt, int command)
 		error = right_click (cctxt->gui_handle->handle);
 		break;
         case LDTP_CMD_MOUSELEFTCLICK:
-        case LDTP_CMD_MOUSERIGHTCLICK: {
+        case LDTP_CMD_MOUSERIGHTCLICK:
 		error = is_text_state_enabled (cctxt->gui_handle->handle, cctxt->log_fp);
                 if (error != LDTP_ERROR_SUCCESS)
                         error = device_main (cctxt, command);
                 break;
-        }
         case LDTP_CMD_MOUSEMOVE:
                 error = device_main (cctxt, command);
                 break;
@@ -1057,16 +1056,16 @@ text_main (LDTPClientContext* cctxt, int command)
 		glong position;
 		position = get_cursor_position (cctxt->gui_handle->handle);
 		if (position == -1)
-			error =  (LDTP_ERROR_TEXT_NOT_ACCESSIBLE);
+			error = LDTP_ERROR_TEXT_NOT_ACCESSIBLE;
 		else {
 			cctxt->resp->data = g_strdup_printf ("%ld", position);
 			cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
-			error =  (LDTP_ERROR_SUCCESS);
+			error = LDTP_ERROR_SUCCESS;
 		}
 		break;
 	}
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
