@@ -45,6 +45,27 @@ get_state (Accessible *object)
 		return FALSE; // Unchecked state
 }
 
+static gboolean
+is_toggle_button_state_enabled (Accessible *object)
+{
+	AccessibleStateSet *state;
+	if (!object)
+		return FALSE;
+	if (wait_till_object_state_contains (object, TOGGLE_BUTTON, NULL) == -1) {
+		LDTPErrorCode error;
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), NULL);
+		return FALSE;
+	}
+	
+	state = Accessible_getStateSet (object);
+
+	if (AccessibleStateSet_contains (state, SPI_STATE_ENABLED))
+		return TRUE; // Enabled
+	else
+		return FALSE; // Disabled
+}
+
 static LDTPErrorCode
 toggle (Accessible *object, FILE *log_fp)
 {
@@ -54,7 +75,7 @@ toggle (Accessible *object, FILE *log_fp)
 	if (wait_till_object_state_contains (object, TOGGLE_BUTTON, log_fp) != 0) {
 		LDTPErrorCode error;
 
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -62,10 +83,10 @@ toggle (Accessible *object, FILE *log_fp)
 	flag = AccessibleAction_doAction (action, 0);
 	Accessible_unref (action);
 	if (flag == TRUE)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_TOGGLE_ACTION_FAILED);
+		error = LDTP_ERROR_TOGGLE_ACTION_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -80,7 +101,7 @@ press (Accessible *object, FILE *log_fp)
 	if (wait_till_object_state_contains (object, TOGGLE_BUTTON, log_fp) != 0) {
 		LDTPErrorCode error;
 
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -88,10 +109,10 @@ press (Accessible *object, FILE *log_fp)
 	flag = AccessibleAction_doAction (action, 1);
 	Accessible_unref (action);
 	if (flag)
-		return  (LDTP_ERROR_SUCCESS);
+		return LDTP_ERROR_SUCCESS;
 	else {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_TOGGLE_ACTION_FAILED);
+		error = LDTP_ERROR_TOGGLE_ACTION_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -102,17 +123,17 @@ verify_toggled (Accessible *object, FILE *log_fp)
 {
 	LDTPErrorCode error;
 	if (wait_till_object_state_contains (object, TOGGLE_BUTTON, log_fp) != 0) {
-		error =  (LDTP_ERROR_INVALID_OBJECT_STATE);
+		error = LDTP_ERROR_INVALID_OBJECT_STATE;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
 
 	if (get_state (object) == FALSE) {
-		error =  (LDTP_ERROR_TOGGLE_NOT_CHECKED);
+		error = LDTP_ERROR_TOGGLE_NOT_CHECKED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
         
 LDTPErrorCode
@@ -126,6 +147,12 @@ toggle_button_main (LDTPClientContext* cctxt, int command)
 	case LDTP_CMD_PRESS:
 		error = press (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
+	case LDTP_CMD_STATEENABLED:
+		if (is_toggle_button_state_enabled (cctxt->gui_handle->handle))
+			error = LDTP_ERROR_SUCCESS;
+		else
+			error = LDTP_ERROR_TOGGLE_BUTTON_STATE_NOT_ENABLED;
+		break;
 	case LDTP_CMD_VERIFYTOGGLED:
 		error = verify_toggled (cctxt->gui_handle->handle,
 					cctxt->log_fp);
@@ -134,7 +161,7 @@ toggle_button_main (LDTPClientContext* cctxt, int command)
 		error = device_main (cctxt, command);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
