@@ -72,11 +72,11 @@ verify_visible_button_count (Accessible *object, long expected_button_count, FIL
 	g_print ("Expected: %ld - Actual: %ld\n", expected_button_count, visible_button_count);
 	if (visible_button_count != expected_button_count) {
 		LDTPErrorCode error;
-		error =  (LDTP_ERROR_TOOLBAR_VISIBLE_BUTTON_COUNT_FAILED);
+		error = LDTP_ERROR_TOOLBAR_VISIBLE_BUTTON_COUNT_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }	
 
 static LDTPErrorCode
@@ -112,11 +112,11 @@ verify_button_count (Accessible *object, long expected_button_count, FILE *log_f
 	}
 	g_print ("Child: %ld - Expected: %ld - Actual - %ld\n", child_count, expected_button_count, actual_button_count);
 	if (actual_button_count != expected_button_count) {
-		error =  (LDTP_ERROR_TOOLBAR_BUTTON_COUNT_FAILED);
+		error = LDTP_ERROR_TOOLBAR_BUTTON_COUNT_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }	
 
 LDTPErrorCode
@@ -140,8 +140,7 @@ tool_bar_main (LDTPClientContext* cctxt, int command)
 						     cctxt->log_fp);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
-		break;
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
