@@ -623,7 +623,7 @@ select_row_partial_match (Accessible *object, char *row_text, FILE *log_fp)
 }
 
 static LDTPErrorCode
-get_row_index (Accessible *object, GSList **l, FILE *log_fp)
+get_current_row_index (Accessible *object, GSList **l, FILE *log_fp)
 {
 	long i, j;
 	long n_rows, n_cols;
@@ -780,8 +780,8 @@ double_click_row (Accessible *object, char *row_text, FILE *log_fp)
 	return error;
 }
 
-static LDTPErrorCode
-select_row_index (Accessible *object, long row, FILE *log_fp)
+static Accessible*
+get_row_index (Accessible *object, long index, FILE *log_fp)
 {
 	long n_rows, n_cols;
 	LDTPErrorCode error;
@@ -789,26 +789,87 @@ select_row_index (Accessible *object, long row, FILE *log_fp)
 	AccessibleTable *table;
 
 	table = Accessible_getTable (object);
+	if (!table)
+		return NULL;
 	n_rows = AccessibleTable_getNRows (table);
 	n_cols = AccessibleTable_getNColumns (table);
 	g_print ("Tree table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
 
-	if (row < 0 || row >= n_rows) {
-		char msg[256];
-		g_sprintf (msg, "Row %ld doesnot exist in table", row);
+	if (index < 0 || index >= n_rows) {
+		char msg [256];
+		g_sprintf (msg, "Row %ld doesnot exist in table", index);
 		log_msg (LDTP_LOG_CAUSE, msg, log_fp);
 		Accessible_unref (table);
 		error =  (LDTP_ERROR_ROW_DOES_NOT_EXIST);
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
-		return error;
+		return NULL;
 	}
 
 	/*
 	  FIXME: Column value should be dynamic instead of static value
 	*/
-	cell = AccessibleTable_getAccessibleAt (table, row, 0);
-  
-	if (Accessible_isComponent (cell)) {
+	cell = AccessibleTable_getAccessibleAt (table, index, 0);
+	Accessible_unref (table);
+	return cell;
+}
+
+/*
+  Double click row
+*/
+static LDTPErrorCode
+double_click_row_index (Accessible *object, long index, FILE *log_fp)
+{
+	long x, y, height, width;
+	SPIBoolean flag = FALSE;
+	LDTPErrorCode error;
+	Accessible *cell;
+
+	cell = get_row_index (object, index, log_fp);
+	if (cell) {
+		AccessibleComponent *component;
+		if (Accessible_isComponent (cell))
+			component = Accessible_getComponent (cell);
+		else {
+			Accessible_unref (cell);
+			error =  (LDTP_ERROR_OBJ_NOT_COMPONENT_TYPE);
+			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+			return error;
+		}
+		AccessibleComponent_getExtents (component, &x, &y, &width, &height, SPI_COORD_TYPE_SCREEN);
+		/* NOTE: Some widgets doesnot sense the double click event if they are performed exactly on the 
+		 * border. In order to take care of those situtations also we make adjustments in the x and y value
+		 * to fire the event at the center of the object.
+		 */
+		x = x + width / 2;
+		y = y + height / 2;
+		flag = AccessibleComponent_grabFocus (component);
+		Accessible_unref (cell);
+		Accessible_unref (component);
+		if (!flag) {
+			error =  (LDTP_ERROR_UNABLE_TO_GRAB_FOCUS);
+			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+			return error;
+		}
+		flag = SPI_generateMouseEvent (x, y, "b1d");
+		if (flag)
+			return  (LDTP_ERROR_SUCCESS);
+		else {
+			error =  (LDTP_ERROR_DOUBLE_CLICK_FAILED);
+			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+			return error;
+		}
+	}
+	error = LDTP_ERROR_UNABLE_TO_GET_CELL_HANDLE_FAILED;
+	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+	return error;
+}
+
+static LDTPErrorCode
+select_row_index (Accessible *object, long row, FILE *log_fp)
+{
+	LDTPErrorCode error;
+	Accessible *cell = get_row_index (object, row, log_fp);
+	if (cell && Accessible_isComponent (cell)) {
 		SPIBoolean flag;
 		AccessibleComponent *accessible_component;
 
@@ -817,7 +878,6 @@ select_row_index (Accessible *object, long row, FILE *log_fp)
 
 		Accessible_unref (accessible_component);
 		Accessible_unref (cell);
-		Accessible_unref (table);
 		if (flag)
 			return  (LDTP_ERROR_SUCCESS);
 		error =  (LDTP_ERROR_UNABLE_TO_GRAB_FOCUS);
@@ -825,8 +885,8 @@ select_row_index (Accessible *object, long row, FILE *log_fp)
 		return error;
 	}
 	else {
-		Accessible_unref (cell);
-		Accessible_unref (table);
+		if (cell)
+			Accessible_unref (cell);
 		log_msg (LDTP_LOG_CAUSE, "Object is not accessible component", log_fp);
 		error =  (LDTP_ERROR_OBJ_NOT_COMPONENT_TYPE);
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
@@ -892,7 +952,7 @@ right_click (Accessible *object, GSList *l, FILE *log_fp)
 	if (l && l->data)
 		row_text = l->data;
 	else {
-		error =  (LDTP_ERROR_RIGHT_CLICK_FAILED);
+		error = LDTP_ERROR_RIGHT_CLICK_FAILED;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
@@ -987,7 +1047,7 @@ right_click (Accessible *object, GSList *l, FILE *log_fp)
 		if (SPI_generateMouseEvent (x, y, "b3c"))
 			return  (LDTP_ERROR_SUCCESS);
 	}
-	error =  (LDTP_ERROR_RIGHT_CLICK_FAILED);
+	error = LDTP_ERROR_RIGHT_CLICK_FAILED;
 	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 	return error;
 }
@@ -1428,7 +1488,7 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 			row = atol (cctxt->req->arg_list->data);
 		g_print ("Select index: %ld\n", row);
 		error = select_row_index (cctxt->gui_handle->handle, row, cctxt->log_fp);
-				break;
+		break;
 	}
 	case LDTP_CMD_SELECTROW:
 		error = select_row (cctxt->gui_handle->handle, cctxt->req->arg_list, cctxt->log_fp);
@@ -1441,12 +1501,21 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 		error = double_click_row (cctxt->gui_handle->handle,
 					  cctxt->req->arg_list->data, cctxt->log_fp);
 		break;
+	case LDTP_CMD_DOUBLECLICKROWINDEX: {
+		long row_index = 0;
+		if (cctxt->req->arg_list && cctxt->req->arg_list->data)
+			row_index = atol (cctxt->req->arg_list->data);
+		g_print ("Select index: %ld\n", row_index);
+		error = double_click_row_index (cctxt->gui_handle->handle,
+						row_index, cctxt->log_fp);
+		break;
+	}
 	case LDTP_CMD_DOUBLECLICK:
 		error = double_click (cctxt->gui_handle->handle,
 				      cctxt->log_fp);
 		break;
 	case LDTP_CMD_GETTREETABLEROWINDEX:
-		error = get_row_index (cctxt->gui_handle->handle, &cctxt->req->arg_list, cctxt->log_fp);
+		error = get_current_row_index (cctxt->gui_handle->handle, &cctxt->req->arg_list, cctxt->log_fp);
 		if (error == LDTP_ERROR_SUCCESS) {
 			cctxt->resp->data = cctxt->req->arg_list->data;
 			cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
@@ -1591,7 +1660,7 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 		error = device_main (cctxt, command);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 	}
 	return error;
 }
